% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: constraints.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:15 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: This file contains the constraints of a TRALE grammar 
%%             which is an improved reimplemetation of the Babel grammar.
%%             See Mller (2002) for further documentation.
%%   Language: Trale
%      System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Revision 1.2  2003/04/08 08:57:20  stefan
%% Initial revision
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile if/2.
:- multifile macro/2.
:- multifile ':='/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.


fun nfp(+,+,-).
nfp(LDtr,RDtr,Mother) if
  que(LDtr,RDtr,Mother),
  rel(LDtr,RDtr,Mother),
  slash(LDtr,RDtr,Mother),
  extra(LDtr,RDtr,Mother),
  anchors(LDtr,RDtr,Mother).


rel(synsem:nonloc:rel:Rel1,     synsem:nonloc:rel:Rel2,synsem:nonloc:rel:RelM   ) if
  nl(Rel1,Rel2,RelM).

% only one element in REL (Relative Uniqueness Principle)

fun nl(+,+,-).
nl(Slash1,Slash2,SlashM) if
  when(Slash1=(e_list;ne_list)                   % this is to delay the constraint application since otherwise          
      ,undelayed_nl(Slash1,Slash2,SlashM)).      % it is folded into the rules and we get a multiplication of all rules.

undelayed_nl([],Rel2,Rel2) if true.
undelayed_nl([RelEl],[],[RelEl]) if true.


% This is append of slash values restricted for the case that there
% is at most one element in SLASH  (This is not what Babel does!)
% Speed-up by 27%

slash(synsem:nonloc:slash:Slash1,   synsem:nonloc:slash:Slash2, synsem:nonloc:slash:SlashM) if
  nl(Slash1,Slash2,SlashM).

% This treatment of extraposition is due to Berthold Crysmann:
% http://www.coli.uni-sb.de/~crysmann/papers/bc-ESSLLI03-pres.pdf
%
% Extraposed elements are inert until something to their right is found.
% this can be a verbal complex or another constituent as in:
%
% Maria gibt dem Mann den Mantel, den sie kennt. (Mller99a:211)
%


% for reasons I do not understand, PHON never becomes instantiated in a way that triggers the constraint
extra(LDtr,RDtr,Mother) if
   when(RDtr=(word;phrase)
       ,undelayed_extra(LDtr,RDtr,Mother)).

undelayed_extra(synsem:nonloc:(active_extra:AExtraL,
                               inert_extra:IExtraL), (phon:ne_list,
                                                      synsem:nonloc:(active_extra:AExtraR,
                                                                     inert_extra:IExtraR)), synsem:nonloc:(active_extra:AExtraM,
                                                                                                           inert_extra:IExtraR)) if
  append(AExtraL,IExtraL,ExtraL), 
  nl(ExtraL,AExtraR,AExtraM),
  at_most_one(append(AExtraM,IExtraR)).  % otherwise we could get two extraposed modifiers `der Mann das Buch'

% in the case the right hand side daughter is a trace, nothing gets activated
% all traces have active_extra:[]
undelayed_extra(synsem:nonloc:(active_extra:AExtraL,
                               inert_extra:IExtraL), (phon:e_list,
                                                      synsem:nonloc:inert_extra:IExtraR), synsem:nonloc:(active_extra:AExtraL,
                                                                                                         inert_extra:IExtraM)) if
  nl(IExtraL,IExtraR,IExtraM),
  at_most_one(append(AExtraL,IExtraM)).


fun anchors(+,+,-).
% this anchor activation works only in non-nominal enviroments, if we activated anchors in nominal environments
% we woul dactivate the anchor of 'Bild' in 'das Bild von ihr' and would get spurious ambiguities for
% 'das Bild von ihr, das ich kenne' since the relative clause could either attach to the N' or as an
% extraposed constituent.                23.02.2004

anchors(LDtr,RDtr,Mother) if
   when(RDtr=(word;phrase)
       ,undelayed_anchors(LDtr,RDtr,Mother)).


clausal_sign :=
  synsem:(loc:cat:(head:clausal_head,
                   subcat:[]),
          trace:minus).

% if the non-head-dtr is clausal, we throw away all its anchors.
% We have to check for the status as non-head-daughter since otherwise we would throw away
% the anchors of `Es fiel dem Grammatiker auf' when we combine it with `da der Satz grammatisch ist'
% but this is wrong, since we need the anchors for:
%
% Es fiel dem Grammatiker auf, da der Satz grammatisch ist, der den Satz untersuchte.
%
undelayed_anchors((LDtr,
                   @clausal_sign),                % without this the head_value of a trace may be wrongly instantiated
                  (synsem:(active_anchors:AAnchorsR,
                           inert_anchors:IAnchorsR)),
                  (synsem:(active_anchors:AAnchorsR,
                           inert_anchors:IAnchorsR),
                   non_head_dtr:NHD)) if LDtr =@ NHD,!.


undelayed_anchors((synsem:(active_anchors:AAnchorsL,
                           inert_anchors:IAnchorsL)),
                  (RDtr,
                   @clausal_sign),
                  (synsem:(active_anchors:AAnchorsM,
                           inert_anchors:[]),
                   non_head_dtr:NHD)) if RDtr =@ NHD,!,append(AAnchorsL,IAnchorsL,AAnchorsM).

% Do we need this case?
% undelayed_anchors((synsem:(active_anchors:AAnchorsL,
%                            inert_anchors:IAnchorsL)),
%                   (phon:e_list,
%                    synsem:loc:cat:(head:clausal_head,
%                                    subcat:[])),
%                   (synsem:(active_anchors:AAnchorsL,
%                            inert_anchors:IAnchorsL))) if !.

undelayed_anchors(synsem:(active_anchors:AAnchorsL,
                          inert_anchors:IAnchorsL), (phon:ne_list,
                                                     synsem:(active_anchors:AAnchorsR,
                                                             inert_anchors:IAnchorsR)), synsem:(loc:cat:head:(@not(noun)),
                                                                                                active_anchors:AAnchorsM,
                                                                                                inert_anchors:IAnchorsR)) if
  append(AAnchorsL,IAnchorsL,AnchorsL), 
  append(AnchorsL,AAnchorsR,AAnchorsM).

% in nominal environments everything stays inert
undelayed_anchors(synsem:(active_anchors:AAnchorsL,
                          inert_anchors:IAnchorsL), (phon:ne_list,
                                                     synsem:(active_anchors:AAnchorsR,
                                                             inert_anchors:IAnchorsR)), synsem:(loc:cat:head:noun,
                                                                                                active_anchors:AAnchorsM,
                                                                                                inert_anchors:IAnchorsM)) if
  append(AAnchorsL,AAnchorsR,AAnchorsM), 
  append(IAnchorsL,IAnchorsR,IAnchorsM).




% in the case the right hand side daughter is a trace, nothing gets activated
% all traces have active_anchors:[]
undelayed_anchors(synsem:(active_anchors:AAnchorsL,
                          inert_anchors:IAnchorsL), (phon:e_list,
                                                     synsem:inert_anchors:IAnchorsR), synsem:(active_anchors:AAnchorsL,
                                                                                              inert_anchors:IAnchorsM)) if
  append(IAnchorsL,IAnchorsR,IAnchorsM).


% only the leftmost Que is relevant for w-questions
que(synsem:nonloc:que:Que1,   _, synsem:nonloc:que:Que1) if true.
%  nl(Que1,Que2,QueM).

/*

Is done in subject_verb_agreement

% case(synsem:loc:cat:(head:fin_verb,
%                      subcat:Subcat)) if
%   when(Subcat=(e_list;ne_list)
%       ,case_fin(Subcat)).

%case_fin(X) if prolog((write(X),nl,nl)).

case_fin((Subcat,
          hd:loc:cat:head:Head)) if
   when(Head=(noun;no_noun)
       ,undelayed_case_fin(Subcat)).

undelayed_case_fin([loc:cat:head:case:(case_type:Str,
                                       syn_case:nom)|Tl]) % assign nominative
                   if when((Str=str,Tl=e_list)
                          ,true).                

undelayed_case_fin([loc:cat:head:case:(case_type:Str,
                                       syn_case:acc)|Tl]) % assign accusative
                   if when((Str=str,Tl=ne_list)
                          ,true).                

undelayed_case_fin(hd:loc:cat:head:case:case_type:Lex)    % do nothing
                   if when(Lex=lex
                         ,true).                 
undelayed_case_fin(hd:loc:cat:head:no_noun)               % do nothing
         if true.                 


*/

% *****************************
%   list manipulation utilities
% *****************************

% append(+,+,-)
% This append assumes that the first or the third argument
% are known to be non_empty or empty lists. 
%

/*
fun append(+,+,-).
append(X,Y,Z) if 
   when( (X=(e_list;ne_list);
          Z=(e_list;ne_list))       % without the ne_list constraint on Z we have 8 solutions instead of 2 for Karl hat geschlafen
       , append2(X,Y,Z)
       ).

append2(X,L,L) if
  when( (X=e_list;
         L=e_list)
      , X = []
      ).

append2([H|T],Y,Z) if 
   when( (T=(e_list;ne_list);
          Z=(e_list;ne_list))       % without the ne_list constraint on Z we have 8 solutions instead of 2 for Karl hat geschlafen
       , undelayed_append([H|T],Y,Z)
       ).

%undelayed_append([],L,L) if true.
undelayed_append(([H|T1],=\=T1),L,[H|T2]) if append(T1,L,T2).
*/

fun append(+,+,-).
append(X,Y,Z) if 
   when( (X=(e_list;ne_list);
          Z=(e_list;ne_list))       % without the ne_list constraint on Z we have 8 solutions instead of 2 for Karl hat geschlafen
       , undelayed_append(X,Y,Z)
       ).

undelayed_append([],L,L) if true.
% prohibition on cycles prevents looping for "werden ist" with werden-passive + PP and sein-passive + PP
undelayed_append([H|T1],L,[H|T2]) if append(T1,L,T2).



% If the next version of del/3 is used one gets infinite loops with "bekommen hat"
% SUBCAT lists are unified. promote_dative/3 fires, append/3 fires for
% appending the SUBCAT and SUBJ of the verb embedded under hat.
% There is a complex interaction of these constraints which I do not fully
% understand.

fun del(+,+,-).
del(El,Y,Z) if
  when( (Y=(e_list;ne_list);
	 Z=(e_list;ne_list))
       , del2(El,Y,Z)
       ).

del2(El,[H|T],Z) if
  when( (T=(e_list;ne_list);
	 Z=(e_list;ne_list))
       , undelayed_del(El,[H|T],Z)
       ).


undelayed_del(El,[El|R],R) if  true.
undelayed_del(El,[H|T1],[H|T2]) if del(El,T1,T2).



/*

% a special version of del/3 that copes with partially instantiated
% valence lists
fun del(+,+,-).
del(El,Y,Z) if
  when( (Y=(e_list;ne_list)
	;Z=(e_list;ne_list))
       , undelayed_del(El,Y,Z)
       ).


undelayed_del(El,[El|R],R) if
%  prolog((write(user_error,'del succeeded'),nl(user_error))),
  true.
undelayed_del(El,[H|T1],[H|T2]) if del(El,T1,T2).

*/

fun delete(+,+,-).
delete(El,Y,Z) if
   when( El=synsem
       , undelayed_delete(El,Y,Z)
       ).

undelayed_delete(El,[El|R],R) if true.
undelayed_delete(El,[H|T1],[H|T2]) if undelayed_delete(El,T1,T2).


/*

This version is not correct since it fires for [X|_] and returns X.

fun last(+,-).
last(X,L) if
  when( X=(e_list;ne_list)
      , undelayed_last(X,L)
      ).

undelayed_last([L],L) if true.
undelayed_last(tl:T1,L) if last(T1,L).

*/


fun last(+,-).
last(X,L) if
  when( X=(e_list;ne_list)
      , last2(X,L)
      ).

last2([H|T],L) if
  when( T=(e_list;ne_list)
      , undelayed_last([H|T],L)
      ).

undelayed_last([L],L) if
%prolog((write(user_error,'last succeeded'),nl(user_error))),
  true.
undelayed_last(tl:T1,L) if last(T1,L).


fun member(-,+).  % returns a member
member(El,List) if 
   when( List=(e_list;ne_list)
       , undelayed_member(El,List)
       ).

undelayed_member(El,hd:El)  if true.
undelayed_member(El,tl:T1) if member(El,T1).

fun contains(+,-). % returns a list
contains(List,El) if
  member(El,List).

%% Type negation - delay until type T and then die.

% does not work
% not(T) macro not_type(a_ T).
% fun not_type(+,-).
% not_type((a_ T),FS) if when(FS=T,fail).

% does work
not(Type) macro not_type(a_ Type).
fun not_type(+,-).
( not_type((a_ Type),FS) if
      when(FS=Type,prolog(fail)) ) :-
        type(Type).


% used for prenominal adjectives
% neither relative pronouns, nor extraction nor extraposition
% is possible. For exceptions see Mller, 1999.
fun list_of_non_move_synsems(-).
list_of_non_move_synsems(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_move_synsems(L) ).

undelayed_list_of_non_move_synsems([]) if true.

undelayed_list_of_non_move_synsems([nonloc:(@empty_nonloc)|T]) if
   list_of_non_move_synsems(T).



fun add_at_most_two(+,-).
add_at_most_two(L,LP) if
  append(L,X,LP),
  at_most_two(X).

fun at_most_four(-).
at_most_four(X) if 
   when( X=(e_list;ne_list)
       , undelayed_at_most_four(X)
       ).

undelayed_at_most_four([]) if true.
undelayed_at_most_four(tl:Z) if
  at_most_three(Z).

fun at_most_three(-).
at_most_three(X) if 
   when( X=(e_list;ne_list)
       , undelayed_at_most_three(X)
       ).

undelayed_at_most_three([]) if true.
undelayed_at_most_three(tl:Z) if
  at_most_two(Z).

fun at_most_two(-).
at_most_two(X) if 
   when( X=(e_list;ne_list)
       , undelayed_at_most_two(X)
       ).

undelayed_at_most_two([]) if true.
undelayed_at_most_two(tl:Z) if
  at_most_one(Z).

fun at_most_one(-).
at_most_one(X) if 
   when( X=(e_list;ne_list)
       , undelayed_at_most_one(X)
       ).

undelayed_at_most_one([]) if true.
undelayed_at_most_one(tl:e_list) if true.

fun at_least_one(-).
at_least_one(X) if 
   when( X=(e_list;ne_list)
       , undelayed_at_least_one(X)
       ).

undelayed_at_least_one(hd:bot) if true.

% This has to be delayed, since otherwise it would run
% in the rule compilation. But it has to be delayed only
% on the first instantiation of X. Once X is a list, it is
% fully instantiated.
fun a_list_of_length_x_plus_two(+,-).
a_list_of_length_x_plus_two(X,Y) if 
 when( X=(e_list;ne_list)
       , undelayed_a_list_of_length_x_plus_two(X,Y)
       ).

undelayed_a_list_of_length_x_plus_two([],[_,_]) if true.
undelayed_a_list_of_length_x_plus_two(tl:T1,[_|T2]) if
  undelayed_a_list_of_length_x_plus_two(T1,T2).
                            

% this functional specification is a real hack
% to be able to use the call on subcat lists
% in macros.
fun subj_verb_agreement(-,+,+).
subj_verb_agreement(X,Per,Num) if
  when( X=(e_list;ne_list)
      , subj_verb_agreement1(X,Per,Num)
      ).

% subject verb agreement and
% case assignment
% [np_lex]          drsten
% [np_str]          schlafen
% [np_lex, np_str]  helfen
% [cp]              stimmen
% [np_lex, cp]      auffallen


% there is no argument at all
subj_verb_agreement1([],third,sg) if
    prolog((chart_debug(on) ->
            write(user_error,'SV Agreement succeeded! Default Agreement.'),
            nl(user_error)
           ;true
         )),
  true.

% there is a list of arguments
% the last one may be a subject. If it is a subject, i.e. np_str_nom
% it has to agree with the verb.
% If the last element is not a noun or has lexical case, the verb
% has to be third sg.
% As a side effect the constraint assigns accusative to all nouns
% that are not initial
subj_verb_agreement1([H|T],Per,Num) if
  when( T=(e_list;ne_list)
      , undelayed_subj_verb_agreement_([H|T],Per,Num)
      ).

undelayed_subj_verb_agreement_([@np_str_nom(Per,Num)],Per,  Num) if
%     prolog((chart_debug(on) ->
%             write(user_error,'Structural Nominativ + Agreement.'),
%             nl(user_error)
%            ;true
%          )),
true.
undelayed_subj_verb_agreement_([@np_lex],                  third,sg)  if true.
undelayed_subj_verb_agreement_([loc:cat:head:(@not(noun))],third,sg)  if true.
%undelayed_subj_verb_agreement_([_],third,sg)  if !, true.
undelayed_subj_verb_agreement_([El|T1],Per,Num) if
  prolog((chart_debug(on) ->
          write(user_error,'Trying to assign accusative.'),
          nl(user_error)
%          ,portray_cat('Passive Edge',bot,_,[El|T1],_Residue)
%          ,write(user_error,El),nl(user_error)
%          ,trace
         ;true
         )),
  assign_acc(El),
  prolog((chart_debug(on) ->
          write(user_error,'Succeded to assign accusative.'),
          nl(user_error)
         ;true
         )),
  subj_verb_agreement2(T1,Per,Num).

% subj_verb_agreement2(X,Per,Num) if
%   when( X=(e_list;ne_list)
%       , undelayed_subj_verb_agreement_(X,Per,Num)
%       ).
subj_verb_agreement2([H|T],Per,Num) if
  when( T=(e_list;ne_list)
      , undelayed_subj_verb_agreement_([H|T],Per,Num)
      ).


assign_acc(@np_str_acc) if true.

assign_acc(@np_lex) if true.
assign_acc(loc:cat:head:(@not(noun))) if true.

%assign_acc(_) if true.

fun accusative_assignment(-).
accusative_assignment(Subcat) if
  when( Subcat=(e_list;ne_list)
      , undelayed_accusative_assignment(Subcat)
      ).

undelayed_accusative_assignment([@np_str_acc|Rest]) if
  accusative_assignment(Rest).

undelayed_accusative_assignment([@np_lex|Rest]) if
  accusative_assignment(Rest).

% the inequation does not work here since it is not checked
% maybe this is a bug.
% instead of having a type no_noun which made the type hierarchy
% totally unreadable due to missing glb computation I use
% the cuts in the clauses above. 06.02.2004
undelayed_accusative_assignment([loc:cat:head:(@not(noun))|Rest]) if
%undelayed_accusative_assignment(tl:Rest) if
  accusative_assignment(Rest).


fun promote_dat(+,-).
promote_dat(List,Promoted) if
  del(@np_lex_dat(Ind),List,Rest),
  prolog((chart_debug(on) ->
          write(user_error,'promote_dat: removed NP[dat].'),
          nl(user_error)
         ;true
         )),
  append(Rest,[@np_str(Ind)],Promoted).


% RP_Head, MotherHead
fun free_rc_head(+,-).

free_rc_head(RCHead,MotherHead) if
  when(RCHead=(noun;prep;verb;adv)
      ,undelayed_free_rc_head(RCHead,MotherHead)
      ).

% Wer schlft, sndigt nicht.
% Die da stehen, kennen wir nicht.  NOM > ACC due to case syncretism
undelayed_free_rc_head((noun,
                        mod:Mod,
                        case:morph_case:(nom_or_acc,
                                         Case)),     (noun,
                                                      mod:Mod,
                                                      case:syn_case:Case)) if true.

% Nom < Acc < Dat
undelayed_free_rc_head((noun,
                        mod:Mod,
                        case:morph_case:dat),(noun,
                                              mod:Mod,
                                              case:syn_case:nom_or_dat_or_acc)) if true.


% Nom < Acc < Prep
undelayed_free_rc_head((Prep,
                        prep,
                        mod:none),((Prep
                                   ;noun,
                                    mod:none,
                                    case:syn_case:nom_or_acc))) if true.


%todo
%undelayed_free_rc_head(adv,adv) if true.


fun check_identical_append(+,+,+,-).

check_identical_append(A,B,C,D) if
  when((A = (e_list;ne_list),
        B = (e_list;ne_list),
        C = (e_list;ne_list)),
        
       ( %for participles DA and SUBJ are identical so testing for A =@ B would be sufficient
         % but for bse and zu-infinitivs DA and SUBJ may differ. The elements may be identical
         % but the actual lists are not shared.

         % If either A or B is [] appending it in the next clause does not hurt.
           
           (A = [A1],
            B = [B1],
            A1 =@ B1) ->
           append(B,C,D)
       ;  
           append(A,B,X),
           append(X,C,D)
       )).

fun coord_sem_and_anchors(+,+,+,-).
coord_sem_and_anchors(Rel,(C1,
                           ind:I1),(C2,
                                    ind:I2),Sign3) if
  when((I1=(ref_ind;event),
        I2=(ref_ind;event))
      ,undelayed_coord_sem_and_anchors(Rel,C1,C2,Sign3)).


% coordinated nouns, NPs or PPs
% note that the specification of SPR below excludes the coordination of N' s.
% This also excludes phrases like `dein Freund und Helfer'
% However in cases like `*die Frau und Verfhrerin' and `*eine Frau und Verfhrerin'
% this seems to be correct. Possably possessives are special.  23.03.2004
%
undelayed_coord_sem_and_anchors(und_rel,(ltop:LT1,
                                         ind:(Ind1,
                                              ref_ind,
                                              gen:Gen1,
                                              sort:Sort1)),(ltop:LT2,
                                                            ind:(Ind2,
                                                                 ref_ind,
                                                                 gen:Gen2,
                                                                 sort:Sort2)),(synsem:loc:cat:(head:mod:none,
                                                                                               spr:[],
                                                                                               subcat:[]),
                                                                               c_cont:(ltop:Top,
                                                                                       ind:(IndM,
                                                                                            ref_ind,
                                                                                            per:third,
                                                                                            num:pl,
                                                                                            gen:GenM,
                                                                                            sort:SortM),
                                                                                       key:Key,
                                                                                       liszt:(list:[(Key,
                                                                                                     und_rel,
                                                                                                     lbl:Top,
                                                                                                     c_arg:IndM,
                                                                                                     arg1:Ind1,
                                                                                                     arg2:Ind2,
                                                                                                     l_hand:LT1,
                                                                                                     r_hand:LT2)|Last],
                                                                                              last:Last),
                                                                                       h_cons: @e_diff_list),
                                                                               synsem:active_anchors:[(handle:Top,
                                                                                                       ind:IndM)])) if prolog((mspec_sup_type(Gen1,Gen2,GenM),
                                                                                                                               mspec_sup_type(Sort1,Sort2,SortM))).

% saturated NPs and the relation is not `und'
% -> number and person are taken from the last conjunct
% this should probably be done in syntax and not in the index ... 21.02.2004
undelayed_coord_sem_and_anchors(oder_rel,(ltop:LT1,
                                          ind:(Ind1,
                                               ref_ind,
                                               sort:Sort1)),(ltop:LT2,
                                                             ind:(Ind2,
                                                                  ref_ind,
                                                                  per:Per,
                                                                  num:Num,
                                                                  sort:Sort2)),(synsem:loc:cat:(head:mod:none,
                                                                                                spr:[],
                                                                                                subcat:[]),
                                                                                c_cont:(ltop:Top,
                                                                                        ind:(IndM,
                                                                                             ref_ind,
                                                                                             per:Per,
                                                                                             num:Num,
                                                                                             sort:SortM),
                                                                                        key:Key,
                                                                                        liszt:(list:[(Key,
                                                                                                      oder_rel,
                                                                                                      lbl:Top,
                                                                                                      c_arg:IndM,
                                                                                                      arg1:Ind1,
                                                                                                      arg2:Ind2,
                                                                                                      l_hand:LT1,
                                                                                                      r_hand:LT2)|Last],
                                                                                               last:Last),
                                                                                        h_cons: @e_diff_list),
                                                                                synsem:active_anchors:[])) if prolog(mspec_sup_type(Sort1,Sort2,SortM)).

% coordinated adjectives, noun-modifying prepositions, relative clauses
% In such coordinations no plural index is introduced. Therefore active_anchors is the empty list.
undelayed_coord_sem_and_anchors(und_rel,(ltop:LT1,
                                         ind:(Ind,
                                              ref_ind)),(ltop:LT2,
                                                         ind:Ind),(synsem:loc:cat:(head:mod:synsem,
                                                                                   spr:[],
                                                                                   subcat:[],
                                                                                               % rules out spurious ambiguity in
                                                                                               % schne, kluge und interessante Frau
                                                                                               % where schne is not part of the coordination
                                                                                   left_adj_poss:minus),
                                                                               c_cont:(ltop:Top,
                                                                                       ind:Ind,
                                                                                       key:Key,
                                                                                       liszt:(list:[(Key,
                                                                                                     und_rel,
                                                                                                     lbl:Top,
                                                                                                     c_arg:Ind,
                                                                                                     arg1:Ind,
                                                                                                     arg2:Ind,
                                                                                                     l_hand:LT1,
                                                                                                     r_hand:LT2)|Last],
                                                                                              last:Last),
                                                                                       h_cons: @e_diff_list),
                                                                               synsem:active_anchors:[])) if true.


undelayed_coord_sem_and_anchors(oder_rel,(ltop:LT1,
                                          ind:(Ind,
                                               ref_ind)),(ltop:LT2,
                                                             ind:Ind),(synsem:loc:cat:(head:mod:synsem,
                                                                                                spr:[],
                                                                                                subcat:[],
                                                                                                left_adj_poss:minus),
                                                                                c_cont:(ltop:Top,
                                                                                        ind:Ind,
                                                                                        key:Key,
                                                                                        liszt:(list:[(Key,
                                                                                                      oder_rel,
                                                                                                      lbl:Top,
                                                                                                      c_arg:Ind,
                                                                                                      arg1:Ind,
                                                                                                      arg2:Ind,
                                                                                                      l_hand:LT1,
                                                                                                      r_hand:LT2)|Last],
                                                                                               last:Last),
                                                                                        h_cons: @e_diff_list),
                                                                                synsem:active_anchors:[])) if true.


% the ltops have to be arguments of the conjunction
undelayed_coord_sem_and_anchors(und_rel,(ltop:LT1,
                                         ind:(Ind1,
                                              event,
                                              temo:Temo1,
                                              sort:Sort1)),(ltop:LT2,
                                                            ind:(Ind2,
                                                                 event,
                                                                 temo:Temo2,
                                                                 sort:Sort2)),(c_cont:(ltop:Top,
                                                                                       ind:(IndM,
                                                                                            event,
                                                                                            temo:TemoM,
                                                                                            sort:SortM),
                                                                                       key:Key,
                                                                                       liszt:(list:[(Key,
                                                                                                     und_rel,
                                                                                                     lbl:Top,
                                                                                                     c_arg:IndM,
                                                                                                     arg1:Ind1,
                                                                                                     arg2:Ind2,
                                                                                                     l_hand:LT1,
                                                                                                     r_hand:LT2)|Last],
                                                                                              last:Last),
                                                                                       h_cons: @e_diff_list),
                                                                                synsem:active_anchors:[])) if prolog((mspec_sup_type(Temo1,Temo2,TemoM),
                                                                                                                          mspec_sup_type(Sort1,Sort2,SortM))).




undelayed_coord_sem_and_anchors(oder_rel,(ltop:LT1,
                                          ind:(Ind1,
                                               event,
                                               temo:Temo1,
                                               sort:Sort1)),(ltop:LT2,
                                                             ind:(Ind2,
                                                                  event,
                                                                  temo:Temo2,
                                                                  sort:Sort2)),(c_cont:(ltop:Top,
                                                                                        ind:(IndM,
                                                                                             event,
                                                                                             temo:TemoM,
                                                                                             sort:SortM),
                                                                                        key:Key,
                                                                                        liszt:(list:[(Key,
                                                                                                      oder_rel,
                                                                                                      lbl:Top,
                                                                                                      c_arg:IndM,
                                                                                                      arg1:Ind1,
                                                                                                      arg2:Ind2,
                                                                                                      l_hand:LT1,
                                                                                                      r_hand:LT2)|Last],
                                                                                               last:Last),
                                                                                        h_cons: @e_diff_list),
                                                                                synsem:active_anchors:[])) if prolog((mspec_sup_type(Temo1,Temo2,TemoM),
                                                                                                                            mspec_sup_type(Sort1,Sort2,SortM))).



fun coord_sem_and_anchors(+,+,+,+,-).
coord_sem_and_anchors(Rel1,Rel2,(C1,
                     ind:I1),(C2,
                              ind:I2),C3) if
  when((I1=(ref_ind;event),
        I2=(ref_ind;event))
      ,undelayed_coord_sem_and_anchors(Rel1,Rel2,C1,C2,C3)).

% Sowohl Peter als auch Maria schlft.
% Sowohl Peter als auch die Kinder schlafen.
undelayed_coord_sem_and_anchors(R1,R2,(ltop:LT1,
                                       ind:(Ind1,
                                            ref_ind,
                                            sort:Sort1)),(ltop:LT2,
                                                          ind:(Ind2,
                                                               ref_ind,
                                                               per:Per,
                                                               num:Num,
                                                               sort:Sort2)),(c_cont:(ltop:Top,
                                                                                     ind:(IndM,
                                                                                          ref_ind,
                                                                                          per:Per,
                                                                                          num:Num,
                                                                                          sort:SortM),
                                                                                     key:Key,
                                                                                     liszt:(list:[(Key,
                                                                                                   R1,
                                                                                                   lbl:Top,
                                                                                                   c_arg:IndM,
                                                                                                   arg1:Ind1,
                                                                                                   arg2:Ind2,
                                                                                                   l_hand:LT1,
                                                                                                   r_hand:LT2)|Last],
                                                                                            last:Last),
                                                                                     h_cons: @e_diff_list),
                                                                             synsem:active_anchors:[])) if ((R1=sowohl_als_auch_rel,
                                                                                                                   R2=sowohl_als_auch_rel)
                                                                                                                 ;(R1=entweder_oder_rel,
                                                                                                                   R2=oder_rel)
                                                                                                                 ;(R1=weder_noch_rel,
                                                                                                                   R2=weder_noch_rel)
                                                                                                                 ),
                                                                                                              prolog(mspec_sup_type(Sort1,Sort2,SortM)).
                               
                               
undelayed_coord_sem_and_anchors(R1,R2,(ltop:LT1,
                                       ind:(Ind1,
                                            event,
                                            temo:Temo1,
                                            sort:Sort1)),(ltop:LT2,
                                                          ind:(Ind2,
                                                               event,
                                                               temo:Temo2,
                                                               sort:Sort2)),(c_cont:(ltop:Top,
                                                                                     ind:(IndM,
                                                                                          event,
                                                                                          temo:TemoM,
                                                                                          sort:SortM),
                                                                                     key:Key,
                                                                                     liszt:(list:[(Key,
                                                                                                   R1,
                                                                                                   lbl:Top,
                                                                                                   c_arg:IndM,
                                                                                                   arg1:Ind1,
                                                                                                   arg2:Ind2,
                                                                                                   l_hand:LT1,
                                                                                                   r_hand:LT2)|Last],
                                                                                            last:Last),
                                                                                     h_cons: @e_diff_list),
                                                                             synsem:active_anchors:[])) if ((R1=sowohl_als_auch_rel,
                                                                                                                   R2=sowohl_als_auch_rel)
                                                                                                                 ;(R1=entweder_oder_rel,
                                                                                                                   R2=oder_rel)
                                                                                                                 ;(R1=weder_noch_rel,
                                                                                                                   R2=weder_noch_rel)
                                                                                                                 ),
                                                                                   prolog((mspec_sup_type(Temo1,Temo2,TemoM),
                                                                                           mspec_sup_type(Sort1,Sort2,SortM))).





fun alarm(-).
alarm(L) if
  when(L=(e_list;ne_list)
      ,prolog((write(user_error,'List instanitated.'),nl(user_error),
               write(L),nl,
               trace
              % pp_fs(_-L)
              ))
      ).