
mspec_sup_type(S1,S2,SM) :-
        deref(S1,_Ref1,T1),
        deref(S2,_Ref2,T2),
        findall(A,(sub_type(A,T1),sub_type(A,T2)),X),
        most_specific(X,bot,MT),
        deref(S3,_Ref3,MT),
        ud(SM,S3).

most_specific([],T,T).
most_specific([T1|Rest],TI,TOut) :-
        (sub_type(TI,T1) ->
            most_specific(Rest,T1,TOut)
        ; otherwise ->
            most_specific(Rest,TI,TOut)
        ).



print_hierarchy(Type) :-
   print_hierarchy(Type,false).

print_signature(Type) :-
   print_hierarchy(Type,true).

graphviz_print_option_(Format,Program) :-
   (   current_predicate(graphviz_print_option,graphviz_print_option(_,_)),
       graphviz_print_option(UserFormat,UserProgram)
   ->  ((atom(UserFormat),atom(UserProgram)) 
       ->  UserFormat=Format,UserProgram=Program
       ;   graphviz_print_option_default(Format,Program),
	   format(user_error,'~N**Error: Both arguments of graphviz_option(<format>,<program>) must be atoms!~n(surround ~w and ~w by single quotes to obtain atoms)~nUsing fallback graphviz_option(~w,~w).~n',[UserFormat,UserProgram,Format,Program])
       )
   ;  graphviz_print_option_default(Format,Program)
   ).

%% The default if the user hasn't defined graphviz_print_option/2
graphviz_print_option_default(ps,gv).

print_hierarchy(Type,ShowApprops) :-
	type_hierarchy_compiler:ensure_signature_present,
	type_hierarchy_compiler:ensure_type_defined(Type),
	type_hierarchy_compiler:get_all_subtypes(Type,Result,[],_),
	(Result == [] ->
	    format(user_output,'**Error: Type "~w" has no subtypes.~n',[Type])
	;
	    tmpnam(Filename),
	    format_to_chars('~w.dot',[Filename],DotFilenameS),
	    atom_codes(DotFilename,DotFilenameS),

	    tell(DotFilename),
	    format('digraph ~w {~n',[Type]),

            % horizontal space between nodes in inches:
	    format('ranksep="0.4 equally";~n',[]), 

            % horizontal space between nodes in inches:
	    format('nodesep="0.2 equally";~n',[]), 

	    % justification of labels (relevant if it has more lines)
	    format('labeljust="l";~n',[]),

            % set fontpath
%	    format('fontpath="/usr/share/fonts/default/TrueType/";~n',[]),

	    % font name and size to use
%	    format('node [fontname="helr____"];~n',[]),

	    % nodes are just text and there's no padding around them
	    format('node [height=0,width=0,shape=plaintext];~n',[]),

	    % here we can compress it to a certain size
%	    format('ratio="compress";~nsize="8.5,11";~n',[]),
	    format('ratio="compress";~nsize="17,22";~n',[]),

	    % or one can just specify a certain size, without changing the ratio
%	    format('size="13,10";~n',[]),

            % or one can set size in inches at which to cut into pages, and margins
	    format('page="8.5,11"~numargin="0.1,0.1"~n',[]), 

	    % no arrows at end of edges:
	    format('edge [arrowhead="none"];~n',[]), 

	    draw_hierarchy([Type-Result],_,ShowApprops),

	    format('~N}~n',[]),
	    told,

	    graphviz_print_option_(Format,Program),
	    format_to_chars('dot -T~w ~w > ~w.~w;~w ~w.~w&',[Format,DotFilename,Filename,Format,Program,Filename,Format],String),
	    atom_codes(Command,String),
	    format('~N~p~n',[Command]),	% tell user what we're doing
	    shell(Command)
	).

