% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: le_macros.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:17 $
%%     Author: Stefan Mueller (Stefan.Mueller@uni-bremen.de)
%%    Purpose: macros that are used in the lexicon (lexicon.pl)
%%   Language: Trale
%      System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile macro/2.
:- discontiguous macro/2.
:- multifile ':='/2.
:- discontiguous ':='/2.
:- multifile if/2.
:- discontiguous if/2.
:- multifile fun/1.
:- discontiguous fun/1.


lexical_sign :=
 (synsem:(nonloc:active_extra:[],   % things in extra can only become active in syntax
          active_anchors:[],
          lex:plus)).

overt_sign := 
 (synsem:trace:minus).

overt_lexical_sign :=
  (@lexical_sign,
   @overt_sign).

default_nonloc_lexical_sign :=
 (@lexical_sign,
  synsem:nonloc:(@empty_nonloc,
                 que:[])).

no_anchor :=
 (synsem:inert_anchors:[]).

default_relational_lexical_sign := 
 (@lexical_sign,
  synsem:loc:cont:(ltop:LTop,
                   key:(Key,
                        lbl:LTop),
                   liszt:list:[Key|_])).

default_one_relation_lexical_sign := 
 (@default_relational_lexical_sign,
  synsem:loc:cont:liszt:(list:tl:Last,
                         last:Last)).

default_two_relation_lexical_sign := 
 (@default_relational_lexical_sign,
  synsem:loc:cont:liszt:(list:tl:tl:Last,
                         last:Last)).

no_rel_lexical_sign :=
  (@lexical_sign,
   @no_anchor,
   synsem:loc:cont:(liszt: @e_diff_list,
                    h_cons: @e_diff_list)).

default_nonloc_no_rel_lexical_sign :=
 (@default_nonloc_lexical_sign,
  @no_rel_lexical_sign,
  @non_coord_lexical_sign).

non_coord_lexical_sign :=
  (@lexical_sign,
   synsem:loc:coord:minus).

overt_non_coord_lexical_sign :=
  (@overt_sign,
   @non_coord_lexical_sign).

default_lexical_sign :=
 (@default_nonloc_lexical_sign,
  @default_one_relation_lexical_sign,
  @non_coord_lexical_sign).

% the verb movement trace
% we do not know whether it introduces something into
% liszt. There are mult vorfeld cases where this is not the case.
default_nonloc_non_coord_lexical_sign :=
 (@default_nonloc_lexical_sign,
  @non_coord_lexical_sign).


overt_default_lexical_sign :=
 (@default_lexical_sign,
  @overt_sign).

default_two_rel_lexical_sign :=
 (@default_nonloc_lexical_sign,
  @default_two_relation_lexical_sign,
  @non_coord_lexical_sign).

overt_two_rel_lexical_sign :=
 (@default_two_rel_lexical_sign,
  @overt_sign).

det_synsem :=
( loc:cat:head:det,
  nonloc:(slash:[],
          inert_extra:[])).

lexical_noun :=
  (@overt_non_coord_lexical_sign,
    synsem:loc:(cat:head:noun,
                cont:h_cons:(@e_diff_list))).

relational_noun :=
  (@default_one_relation_lexical_sign,
   @lexical_noun,
   synsem:(loc:cont:(ltop:H,
                     ind:Ind,
                     key:arg1:Ind),
           inert_anchors:[(handle:H,
                           ind:Ind)])).



det_noun(Sort-anything,Gen-gender,DropDet-bool) :=
  (@relational_noun,
   @overt_default_lexical_sign,
   synsem:loc:(cat:(head:case:Case,
                                %head:dtype:DType,
                    spr:[(@det_synsem,
                          loc:(cat:head:(case:Case,
                                         gen:Gen,
                                         num:Num),
                               drop_det:DropDet))]),
               cont:ind:(per:third,
                         gen:Gen,
                         num:Num,
                         sort:Sort))).

% for normal und mass nouns
mass_or_count_noun(Pred-(a_ _),Sort-anything,Gen-gender,DropDet-bool) :=
  (@det_noun(Sort,Gen,DropDet),
   synsem:loc:cont:key:pred:Pred).

comp_noun_synsem :=
  (loc:cat:head:comp_noun).

comp_noun :=
  (synsem:(@comp_noun_synsem)).

/*
non_modifying_mass_or_count_noun :=
  (@mass_or_count_noun,
   @non_modifying).
*/

comp_synsem :=
  (loc:cat:head:mod:none).

complete_comp_sign :=
  (@complete_sign,
   synsem:(@comp_synsem)).

saturated_comp_sign :=
  (@saturated_sign,
   synsem:(@comp_synsem)).

pronoun_noun_y :=
  (@comp_np_synsem).

expl_pronoun_synsem :=
  (@pronoun_noun_y,
   @str_np_synsem,
   loc:cont:ind:expletive).

% Nominative `es' can be in the Vorfeld,
% Accusative `es' cannot. This does not hold for referential pronouns
% although sometimes claimed in the literature, but it does hold for
% expletives. There is probably some more principled way to rule out
% accusative `es' frontings ...
expl_pronoun(Case,VF) macro
  (non_derived_word,
   @lexical_noun,
   @default_nonloc_no_rel_lexical_sign,
   synsem:(@expl_pronoun_synsem,
           loc:cat:head:(case:(syn_case:Case,
                               morph_case:Case),
                         vf:VF))).

r_pronoun :=
  (non_derived_word,
   @default_lexical_sign,
   @no_anchor,
   @complete_sign,
   synsem:loc:(cat:head:r_pron,
               cont:(ind:(ref_ind,
                          Ind),
                     key:(pron_rel,
                          arg1:Ind,
                          vtype:std),
                     h_cons:(@e_diff_list)))).

case_macro(Case) macro
   syn_case:Case, morph_case:Case.

% relative pronouns
pronoun(Case,Per,Num) macro
  (non_derived_word,  % Things that are specified with a case parameter are inflected already.
   @lexical_noun,
   @comp_np,
   synsem:(loc:(cat:head:case:(syn_case:Case,
                               morph_case:Case),
                cont:ind:(per:Per,
                          num:Num)))).

% this includes expletives, which do not have gender
% personal, expletive, and relative pronouns
pronoun(Case,Per,Num,Type) macro
  (@pronoun(Case,Per,Num),
   synsem:(loc:cont:(key:(pron_rel,     % this key is dangling it is not introduced into a liszt                     
                          vtype:Type)   % since I think this is not needed. The vtype is needed for selection though.
                     ))).

pers_pronoun(Case,Per,Num,Gen,Sort,Type) macro
  (@pronoun(Case,Per,Num,Type),
   @overt_default_lexical_sign,
   @no_anchor,
   synsem:loc:cont:(ind:(Ind,
                         gen:Gen,
                         sort:Sort),
                     key:(pron_rel,
                          arg1:Ind))).

% also for possessives whcih introduce relations into liszt
rel_pron :=
  (@overt_lexical_sign,
   @no_anchor,
   synsem:(loc:cont:(ind:(Ind,
                          per:third)),
           nonloc:(que:[],
                   rel:[Ind],
                   slash:[],
                   inert_extra:[]))).

rel_pron(Gen) :=
  (@rel_pron,
   synsem:loc:cont:ind:gen:Gen).


% do they have person values different from third?
% Du, der sich schon lange damit beschftigt hat,
rel_pron_np(Case,Num,Gen) macro
  (@pronoun(Case,_Per,Num),
   @rel_pron(Gen),
   synsem:loc:cont:liszt:(@e_diff_list)).

% for the relative pronouns with `w'
% they have restrictions for animateness
rel_pron_np(Case,Num,Gen,Sort) macro
  (@rel_pron_np(Case,Num,Gen),
   synsem:loc:cont:ind:sort:Sort).


rel_pron_adv(Pred) :=
 (@rel_pron,
%  @general_non_aux_adverb(Pred),
  @intersective_adverb(Pred),
  @default_one_relation_lexical_sign,
  @saturated_sign).


w_pron :=
  (@overt_lexical_sign,
   @no_anchor,
   synsem:(loc:cont:ind:Ind,
           nonloc:(que:[Ind],
                   rel:[],
                   slash:[],
                   inert_extra:[]))).

w_pron(Gen) :=
  (@w_pron,
   synsem:loc:cont:ind:(per:third,
                        gen:Gen)).

w_pron_np(Case-case_val,Num-num,Gen-gender) :=
  (@pronoun(Case,_Per,Num),
   @w_pron(Gen),
   synsem:loc:cont:liszt:(@e_diff_list)).

w_pron_np(Case-case_val,Num-num,Gen-gender,Sort-anything) :=
  (@w_pron_np(Case,Num,Gen),
   synsem:loc:cont:ind:sort:Sort).

w_pron_adv(Pred) :=
 (@w_pron,
  %@general_non_aux_adverb(Pred),
  @intersective_adverb(Pred),
  @default_one_relation_lexical_sign,
  @saturated_sign).

rel_or_w_pron_np(Case,Num,Gen) macro
  @rel_pron_np(Case,Num,Gen).

rel_or_w_pron_np(Case,Num,Gen) macro
  @w_pron_np(Case,Num,Gen).

rel_or_w_pron_np(Case,Num,Gen,Sort) macro
  @rel_pron_np(Case,Num,Gen,Sort).

rel_or_w_pron_np(Case,Num,Gen,Sort) macro
  @w_pron_np(Case,Num,Gen,Sort).


flex_quantifier_np(Pred-quant_rel,Sort-anything,Num-num,Gen-gender) :=
  (@overt_two_rel_lexical_sign,
   @comp_np,
   stem,
   infl:affix:det_i_suffix,
   synsem:loc:cont:(ind:(num:Num,
                         gen:Gen,
                         sort:Sort),
                    key:(Pred,
                         bv:NounInd,
                         restr:Restr),
                    liszt:(list:[Pred,(abstr_nom_rel,
                                       lbl:NLTop,
                                       arg1:NounInd)|LLast],
                           last:LLast),
                    h_cons:(list:[(qeq,
                                   sc_arg:Restr,
                                   outscpd:NLTop)|HLast],
                            last:HLast))).

flex_quantifier_np(Pred-quant_rel,Sort-anything,Num-num) :=
  @flex_quantifier_np(Pred,Sort,Num,gender).

positional_es :=
  (@default_nonloc_no_rel_lexical_sign,
   @overt_sign,
   @no_anchor,
   non_derived_word,
   synsem:(loc:(cat:(head:initial_fin_verb,
                     subcat:[(@complete_synsem,
                              loc:(cat:head:initial_fin_verb,
                                   cont:(gtop:GTop,
                                         ltop:LTop,
                                         ind:Ind,
                                         key:Key)),
                              v2:minus)]),
                cont:(gtop:GTop,
                      ltop:LTop,
                      ind:Ind,
                      key:Key)))).


simple_det_noun(Sort,Gen,DropDet) :=
  (@det_noun(Sort,Gen,DropDet),
   synsem:loc:cat:subcat:[]).

intr_drop_det_proper_noun(Rel,Sort-anything,Gen-gender) :=
  (@simple_det_noun(Sort,Gen,plus),
   @comp_noun,
   infl:affix:fk:nfk_p,
   synsem:loc:cont:key:(named_rel,
                        name:Rel)).


proper_noun_name(Rel,Sort-anything,Gen-gender,_Restriktion) :=
  (@intr_drop_det_proper_noun(Rel,Sort,Gen),
%  Sign:synsem:loc:cat:head:pn        <=> p,
  synsem:loc:(cat:head:case:(syn_case:nom_or_dat_or_acc,
                             morph_case:nom_or_dat_or_acc),           % -> wegen Karl = Dativ
                                                                      % ansonsten 'die Frau Karl'
                                                                      % =         'die Frau des Studenten'
              cont:ind:num:sg)).     

  /*
  Sign:synsem:loc:cont <=> I,
    I isa nomobj,
    I:ind:ref <=> Ref,

    I:restr <=> R1,
       R1:reln     <=> pname,
       R1:location <=> NameRel,
       R1:thema    <=> Ref,
  */

count_noun(Rel-(a_ _),Sort-anything,Gen-gender,DropDet-bool) :=
  (@mass_or_count_noun(Rel,Sort,Gen,DropDet),
   @comp_noun,
   synsem:loc:cat:subcat:[]).

mass_noun(Rel-(a_ _),Sort-anything,Gen-gender) :=
  (@mass_or_count_noun(Rel,Sort,Gen,plus),
   @comp_noun,
   synsem:loc:cat:subcat:[]).

time_mod_noun(Rel-(a_ _),Gen,DropDet) :=
  (@mass_or_count_noun(Rel,time,Gen,DropDet),
   @general_non_aux_adverbial,
   synsem:loc:cat:(head:(mod:loc:cont:ind:aktionsart:durative,
                         case:(syn_case:acc,
                               morph_case:acc)),
                   subcat:[])).

% Montag
% Montag pat mir schlecht.
day_noun(Rel-(a_ _)) :=
  (@count_noun(Rel,time,mas,plus)).

% Ich komme Montag.
day_noun(Rel-(a_ _)) :=
  (@time_mod_noun(Rel,mas,plus)).

% eine Woche
time_noun(Rel-(a_ _),Gen) :=
  (@count_noun(Rel,time,Gen,minus)).

time_noun(Rel-(a_ _),Gen) :=
  (@time_mod_noun(Rel,Gen,minus)).


% one disjunkt is missing
cp_noun(Rel-(a_ _),Sort-anything,Gen-gender,CForm-cform,DropDet-bool) :=
  (@mass_or_count_noun(Rel,Sort,Gen,DropDet),
   @comp_noun,
   synsem:loc:(cat:subcat:([]
                          ;[(@comp_cp_synsem(CForm),
                             loc:cont:ltop:LTop,
                             nonloc:slash:[])]
                          ),
               cont:key:(pred_arg12_rel,
                         arg2:(LTop,
                               handle)))).    % this specification may seem redundant
                                              % however it is needed for the case where the CP-arguemnt is not realized

pp_noun(Rel-(a_ _),Sort-anything,PForm-pform,Case-case_val,ArgSort-anything,Gen-gender,DropDet-bool) :=
  (@mass_or_count_noun(Rel,Sort,Gen,DropDet),
   @comp_noun,
   synsem:loc:(cat:subcat:([]
                          ;[(@ref_comp_pp_synsem(PForm,Case,ArgSort),
                             loc:cont:ind:Ind)]
                          ),
               cont:key:(pred_arg12_rel,
                         arg2:(Ind,
                               ref_ind)))).


np_synsem :=
  (@saturated_synsem,
   loc:cat:head:noun).

np_sign :=
  (synsem:(@np_synsem)).

% NPs with structural case are always complements
str_np_synsem :=
  (@comp_np_synsem,
  loc:cat:head:case:case_type:str).

np_str :=
 (loc:cat:head:(comp_noun,
                case:case_type:str)).

% this has to be fully specified since it is used
% in valence specifications (dative passive)
np_str(Ind) :=
 (@str_ref_comp_np_synsem,
  loc:cont:ind:Ind).

lex_np_synsem :=
  (@np_synsem,
  loc:cat:head:case:case_type:lex).

% minimal information, used in constraints
np_lex :=
  (loc:cat:head:(noun,
                 case:case_type:lex)).

np_lex_dat(Ind) :=
 (@np_lex,
  loc:(cat:head:case:syn_case:dat,
       cont:ind:Ind)).

% used in fin_verb_lr for the enforcement of agreement
% valence information is omitted here, since it is provided
% in the lexical entries.
np_str_nom(Per,Num) :=
  (@np_str,
   loc:(cat:head:case:syn_case:nom,
        cont:ind:(per:Per,
                  num:Num))).

% used in lex rules for case assignment
np_str_acc :=
  (@np_str,
   loc:cat:head:case:syn_case:acc).

% argument prepositions and nouns
% the type is referential and not ref_ind
% this makes it possible to have events as arguments of
% prepositions.
% arbeiten selects an-PP, but the an-PP may have the meaning
% of the sentence:
%
% Peter arbeitet daran, da die Wasserversorgung besser wird.
%
ref_nominal_synsem :=
  (loc:cont:ind:referential).

ref_comp_nominal_synsem :=
  (@ref_nominal_synsem,
   @comp_synsem).

comp_np_synsem :=
  (@np_synsem,
   @comp_noun_synsem).

comp_np :=
  synsem:(@comp_np_synsem).

ref_comp_np_synsem :=
  (@comp_np_synsem,
   @ref_comp_nominal_synsem).

ref_comp_np_synsem(Sort) :=
  (@ref_comp_np_synsem,
   loc:cont:ind:sort:Sort).

% nouns with structural case always have an empty mod value
% modifying nouns have semantic case
str_ref_comp_np_synsem :=
  (@str_np_synsem,
   @ref_comp_np_synsem).

str_ref_comp_np_synsem(Sort) :=
  (@str_ref_comp_np_synsem,
   @ref_comp_np_synsem(Sort)).

lex_ref_comp_np_synsem(Case) :=
  (@lex_np_synsem,
   @ref_comp_np_synsem,
   loc:cat:head:case:syn_case:Case).

lex_ref_comp_np_synsem(Case,Sort) :=
  (@lex_ref_comp_np_synsem(Case),
   @ref_comp_np_synsem(Sort)).

prepositional_synsem(Pform,Case) :=
  (loc:cat:head:(prep,
                 pform:Pform,
                 case:syn_case:Case)).

% for Ps that take a full NP and Ps like `vom' that contain the determiner (vom = von + dem)
p_or_p_det_synsem(Case,Sort) :=
  (loc:cat:(subcat:[(@lex_comp_np_or_n_bar(Case),
                     loc:(cat:head:vf:minus, % pstranding is not possible in German (only with `da')
                          cont:ind:sort:Sort))]
                                %nonloc:slash:[], % [Mit Norwegen]_i befinden wir uns allerdings 
                                % [in [einem langfristigen Stellungskrieg _i]]
           )).

% full Ps
p_synsem(Case,Sort) :=
  (@p_or_p_det_synsem(Case,Sort),
   loc:cat:subcat:[@np_synsem]).

% zum = zu dem (masc), zur = zu der (fem) ...
p_det_synsem(Case,Sort,Gen) :=
  (@p_or_p_det_synsem(Case,Sort),
   loc:cat:subcat:[@n_bar_gen(Gen)]).


% not just the case values but the whole case information is shared
% would also work without this specification, i.e. without CCase
p_or_p_det_synsem(Pform-pform,Case-case_val,Sort) :=
  (@prepositional_synsem(Pform,Case),
   @p_or_p_det_synsem(Case,Sort),
   @ref_comp_nominal_synsem,        
   loc:(cat:(head:(case:CCase,
                   initial:plus),                     % complement propositions are always head initial (da-mit is treated with lexical rule)
             subcat:[(loc:(cat:head:case:CCase,
                           cont:ind:Ind))]),
        cont:ind:Ind)).

p_synsem(Pform-pform,Case-case_val,Sort) :=
  (@p_or_p_det_synsem(Pform,Case,Sort),
   loc:cat:subcat:[@np_synsem]).

p_det_synsem(Pform-pform,Case-case_val,Sort,Gen) :=
  (@p_or_p_det_synsem(Pform,Case,Sort),
   loc:cat:subcat:[@n_bar_gen(Gen)]).


pp_synsem(Pform,Case) :=
  (@saturated_synsem,
   @prepositional_synsem(Pform,Case)).

ref_comp_pp_synsem(Pform,Case) :=
  (@pp_synsem(Pform,Case),
   @ref_comp_nominal_synsem).

% used in adjective templates
% maybe adjectives should be represented with the subject on the subcat list
% this would make simpler linking possible.
ref_comp_pp_synsem(Pform,Case,Sort) :=
  (@ref_comp_pp_synsem(Pform,Case),
   loc:cont:ind:sort:Sort).   

% only comp_preps have pform
preposition(Pform-pform,Case-case_val,Sort-anything) :=
  (@default_nonloc_no_rel_lexical_sign,
   @overt_sign,
   @no_anchor,
   non_derived_word,
   synsem:(@p_synsem(Pform,Case,Sort))).


% modifying prepositions
preposition_or_p_det(Pred-prep_rel,Case-case_val,Sort-anything,Initial-bool) :=
  (@overt_default_lexical_sign,
   @no_anchor,
   @intersective_modifier,  
   non_derived_word,
   synsem:(@p_or_p_det_synsem(Case,Sort),
           ( loc:cat:(head:(noun_mod_prep,
                            mod:loc:(cat:(head:noun,
                                          spr:[_]),
                                     cont:ind:ref_ind)),
                       subcat:[nonloc:rel:[]], % * das Haus, der Aufzug in dem klemmt
                       left_adj_poss:minus)
           ; loc:cat:head:(verb_mod_prep,
                           mod:loc:(cat:head:(a_or_v,
                                              initial:minus),
                                    cont:ind:event)) % needed for extraposition tratement with anchors
           ),
           loc:(cat:(head:initial:Initial,
                     subcat:[loc:cont:ind:Ind2]),
                cont:key:(Pred,
                          arg2:Ind2)))).

preposition(Pred-prep_rel,Case-case_val,Sort-anything) :=
  (@preposition_or_p_det(Pred,Case,Sort,plus),
   synsem:(@p_synsem(Case,Sort))). % adds information that the complement is a full NP

postposition(Pred-prep_rel,Case-case_val,Sort-anything) :=
  (@preposition_or_p_det(Pred,Case,Sort,minus),
   synsem:(@p_synsem(Case,Sort))). % adds information that the complement is a full NP


% things like vom, zum, am
% complements
preposition_det(Pform-pform,Case-case_val,Sort-anything,Gen-gender) :=
  (@default_nonloc_no_rel_lexical_sign,
   @overt_sign,
   @no_anchor,
   non_derived_word,
   synsem:(@p_det_synsem(Pform,Case,Sort,Gen))).


preposition_det(Pred-prep_rel,Case-case_val,Sort-anything,Gen-gender) :=
  (@preposition_or_p_det(Pred,Case,Sort,plus),
   synsem:(@p_det_synsem(Case,Sort,Gen))).

% the von phrase modifies a non finite verb or participle that
% has a blocked argument in the DA list. The blocked argument is
% realized by the von PP. Therefore it has to be ensured that the
% blocked argument is not unblocked by an auxiliary. The
% auxiliaries check the BLOCKED value of DA elements. Only those
% DA elements that are BLOCKED- can be unblocked.
% 01.06.2003
passive_preposition_or_p_det(Case-case_val) :=
  (@default_nonloc_no_rel_lexical_sign,
   @overt_sign,
   @no_anchor,
   non_derived_word,
   synsem:(@p_or_p_det_synsem(Case,_Sort),
           loc:(cat:(head:(verb_mod_prep,
                           initial:plus,
                           mod:loc:cat:head:(participle_or_nonfin_verb,
                                             da:[(loc:cont:(ind:(ref_ind,
                                                                 Ind),
                                                            ltop:LTop),
                                                  blocked:plus)])),
                     subcat:[loc:cont:(ltop:LTop,
                                       ind:Ind)]),
                cont:(ltop:LTop,
                      ind:Ind)))).

passive_preposition(Case-case_val) :=
  (@passive_preposition_or_p_det(Case),
   synsem:(@p_synsem(Case,_Sort))).

passive_preposition_det(Case-case_val,Gen-gender) :=
  (@passive_preposition_or_p_det(Case),
   synsem:(@p_det_synsem(Case,_Sort,Gen))).

general_c_or_wc_synsem :=
  (loc:cat:(spr:[],
            subcat:[(@saturated_synsem, % allows extraction from embedded sentences
                     loc:(cat:head:(fin_verb,
                                    initial:minus,
                                    dsl:none,
                                    vf:minus,
                                    extrap:minus)),
                     nonloc:(@no_extra),
                     trace:minus)])).     % the sentential complement cannot be extracted


c_synsem(CForm) :=
  (@general_c_or_wc_synsem,
   loc:(cat:(head:cform:CForm,
             subcat:[(loc:cont:(gtop:GTop,
                                ind:Ind,
                                key:Key))]),
        cont:(gtop:GTop,
              ind:Ind,
              key:Key))).

comp_cp_synsem(CForm) :=
  (@saturated_synsem,
   loc:cat:head:cform:CForm).

complementizer(CForm-cform) :=
  (non_derived_word,
   @default_nonloc_no_rel_lexical_sign,
   @overt_sign,
   @no_anchor,
   synsem:(@c_synsem(CForm))).

complementizer(Pred-comp_rel) :=
  (non_derived_word,
   @overt_default_lexical_sign,
   @no_anchor,
   @intersective_modifier,
   synsem:(@general_c_or_wc_synsem,
           loc:(cat:(head:(mod_comp,
                           mod:loc:cat:head:(verb,
                                             initial:minus)),
                     subcat:[loc:cont:key:event:Arg2]),
                cont:key:(Pred,
                          arg2:Arg2)))).

% ob
w_complementizer :=
  (non_derived_word,
   @default_one_relation_lexical_sign,
   @w_pron,
   @no_anchor,
   synsem:(@general_c_or_wc_synsem,
           loc:(cat:(head:w_clause,
                     subcat:[loc:cont:ltop:Arg1]),
                cont:(key:(pred:(a_ ob),
                           arg1:Arg1),
                      h_cons: @e_diff_list)))).

w_phrase_synsem :=
 (@saturated_synsem,
  loc:cat:head:w_clause).


general_det(Pred-quant_rel,Num-num,Class-dtype) :=
  (@overt_default_lexical_sign,
   @no_anchor,
   synsem:(@det_synsem,
           @saturated_synsem,
           loc:(cat:head:(num:Num,
                          dtype:Class,
                          spec:loc:cont:(ltop:NLTop,        % may differ from the noun label, since there might be scopal adjectives
                                         ind:NounInd)),
                coord:minus,
                cont:(key:(Pred,
                           bv:NounInd,
                           restr:Restr),
                      h_cons:(list:[(qeq,
                                     sc_arg:Restr,
                                     outscpd:NLTop)|Last],
                              last:Last))))).

% fully inflected determiners with idiosyncratic forms
% specified with case and gender in the lexicon (der,die,das)
det(Pred-quant_rel,Case-case_val,Gen-gender,Num-num,Class-dtype) :=
  (@general_det(Pred,Num,Class),
   word,
   synsem:loc:cat:head:(case:(syn_case:Case,
                              morph_case:Case),
                        gen:Gen)).

% stems that get the case value from the morphology
% number may be specified (alle=pl, jeder=sg)
det(Pred-quant_rel,Num-num,Class-dtype) :=
  (@general_det(Pred,Num,Class),
   stem,
   infl:affix:dtype:strong).

det(Pred-quant_rel,Num-num) :=
  @det(Pred,Num,strong).

det(Pred-quant_rel,Class-dtype) :=
  @det(Pred,num,Class).

det(Pred-quant_rel) :=
  @det(Pred,strong).



weak_det(Pred-quant_rel) :=
  @det(Pred,weak).

weak_det(Pred-quant_rel,Num-num) :=
  @det(Pred,Num,weak).


mixed_det :=
  (stem,
   synsem:loc:cat:head:( dtype:(DType,
                                weak),
                         ( case:morph_case:nom,
                           gen:mas,
                           num:sg
                         ; case:morph_case:nom_or_acc,
                           gen:neu,
                           num:sg
                         )
                       ; dtype:(DType,
                                strong),
                         % either plural or singular and all the other possibilities for sg not covered in the first conjunct
                         ( num:pl
                         ; num:sg,
                           ( gen:fem
                           ; case:morph_case:gen_or_dat,
                             gen:mas_or_neu
                           ; case:morph_case:acc,
                             gen:mas
                           )
                         )),
   infl:affix:dtype:DType).

mixed_det(Pred-quant_rel,Num-num) :=
  (@general_det(Pred,Num,_Class),
   @mixed_det).

mixed_det(Pred-quant_rel) :=
  @mixed_det(Pred,num).


% possesive pronouns and things like `Karls' which are derived by a lexical rule
% list is open, since lexical rule adds a further element (named_rel)
general_poss_det :=
  (synsem:(@det_synsem,
           @saturated_synsem,
           loc:(cat:head:(spec:loc:cont:(ltop:NLTop,
                                         ind:NounInd)),
                coord:minus,
                cont:(liszt:list:[Key,(poss_rel,
                                       lbl:NLTop,
                                       arg1:Ind,
                                       arg2:NounInd)|_],
                      ind:Ind,
                      key:(Key,
                           def_rel,
                           bv:NounInd,
                           restr:Restr,
                           body:handle),
                      h_cons:(list:[(qeq,
                                     sc_arg:Restr,
                                     outscpd:NLTop)|Last],
                              last:Last))))).

% first and second person do not have index gender
poss_pron(Per-per,Num-num) :=
  (@default_nonloc_lexical_sign,
   @overt_sign,
   @no_anchor,
   @general_poss_det,
   @mixed_det,
   synsem:loc:cont:(liszt:(list:tl:tl:Last, %[_,_],
                           last:Last),
                    ind:(per:Per,
                         num:Num))).

poss_pron(Per-per,Num-num,Gen-gender) :=
  (@poss_pron(Per,Num),
   synsem:loc:cont:ind:gen:Gen).

rel_pron_poss_p(Num-num,Gen-gender) :=
  (non_derived_word,
   @general_poss_det,
   @rel_pron(Gen),
   synsem:loc:cont:(liszt:(list:tl:tl:Last, %[_,_],
                           last:Last),
                    ind:(per:third,
                         num:Num))).


np_or_n_bar :=
 (loc:cat:(head:noun,
           subcat:[])).
n_bar :=
 (@np_or_n_bar,
  loc:cat:(head:noun,
           spr:[_])).

n_bar(Ind) :=
 (@n_bar,
  loc:cont:ind:Ind).

n_bar(Ind,Handle) :=
 (@n_bar(Ind),
  loc:cont:ltop:Handle).

n_bar_(Case,Ind) :=
 (@n_bar(Ind),
  loc:cat:head:case:syn_case:Case).

n_bar_gen(Gen) :=
  (@n_bar,
   loc:cont:ind:gen:Gen).

lex_comp_np_or_n_bar(Case) :=
  (@np_or_n_bar,
   @comp_noun_synsem,
   loc:cat:head:case:(case_type:lex,
                      syn_case:Case)).

lex_comp_n_bar(Case) :=
  (@n_bar,
   @comp_noun_synsem,
   loc:cat:head:case:(case_type:lex,
                      syn_case:Case)).


left_modifier :=
  (synsem:loc:cat:head:mod:loc:cat:left_adj_poss:plus).

% also used for participles like `mssende', which have scope constraints
% that come from the verbal part but are otherwise intersective.
% the coindexing with arg1 cannot happen here, since there are intersective
% modifiers like passive participles, where arg2 is linked to the modified element. 
general_intersective_modifier :=
  (synsem:loc:cat:head:mod:loc:cont:ltop:LTop,
   synsem:loc:cont:ltop:LTop).

intersective_modifier :=
  (@general_intersective_modifier,
   synsem:loc:(cat:head:mod:loc:cont:ind:Ind,
               cont:(ind:Ind,
                     key:arg1:Ind,
                     h_cons:(@e_diff_list)))).

scopal_modifier :=
  (synsem:loc:cat:head:mod:loc:cont:ltop:Scoped,
   synsem:loc:cont:(key:arg1:Handle,
                    h_cons:(list:[(qeq,
                                   sc_arg:Handle,
                                   outscpd:Scoped)|Last],
                            last:Last))).


prd_adj_synsem :=
  (loc:cat:head:prd_adj).

% I assume that the lexicon contains lexical entries
% that are stems and that have the form of the predicative
% adjective, these stems undergo zero inflection.
% Mller (2002)

% There are subjectless adjectives.
% The index of adjectives that have a subject is identical to the index of the subject,
% but what about adjectives with an expletive subject or adjectives that govern a dative?

general_adjective(Pred) :=
  (@overt_default_lexical_sign,
   @no_anchor,
   stem,
   synsem:loc:(cat:(head:adj,
                    spr:[]),
               cont:key:pred:Pred)).

general_isec_adjective(Pred) :=
  (@general_adjective(Pred),
   @intersective_modifier).


% the top of intersective adjectives is not linked
% to their modifier but to their subject.
% The reason for this is that the lexical entry for
% the stem is for both the attributive and the predicative
% form. While both forms have a subject, the predicative
% form does not hav a mod value.
general_subj_adjective(Pred,Sort) :=
  (@general_adjective(Pred),
   synsem:loc:(cat:head:subj:[(@str_ref_comp_np_synsem,
                               loc:cont:ind:(Ind,
                                             sort:Sort))],
               cont:(ind:Ind,
                     key:arg1:Ind))).

general_subj_isec_adjective(Pred,Sort) :=
  (@general_isec_adjective(Pred),
   @general_subj_adjective(Pred,Sort)).

% vermeintlich-, mutmalich-
% these only appear attributively
% cont is parallel to scopal_modifier except that the linking
% is to subject. See comment above.
scopal_adjective(Pred) :=
  (@general_adjective(Pred),
   @scopal_modifier,
   synsem:loc:(cat:(head:(attr_adj,
                          mod:loc:cont:ind:Ind),
                    subcat:[]),
               cont:ind:Ind)).


% simple adjectives like `klug'
adjective(Pred-(a_ _),Sort-anything) :=
  (@general_subj_isec_adjective(Pred,Sort),
   synsem:loc:(cat:subcat:[],
               cont:key:pred_arg1_rel)).

% The following specification makes the adjectives incompatible
% with either the attr or the prd inflection lexical rule.
attr_adjective(Pred-(a_ _),Sort-anything) :=
  (@adjective(Pred,Sort),
   @left_modifier,
  synsem:loc:cat:head:attr_adj).

prd_adjective(Pred-(a_ _),Sort-anything) :=
  (@general_subj_adjective(Pred,Sort),
   synsem:loc:cat:(head:prd_adj,
                   subcat:[]),
   synsem:loc:cont:h_cons:(@e_diff_list)).

% schulfrei
subjless_adjective(Pred-(a_ _)) :=
  (@general_adjective(Pred),
   synsem:loc:(cat:(head:(prd_adj,
                          subj:[]),
                    subcat:[]),
               cont:(key:pred_noarg_rel,
                     h_cons:(@e_diff_list)))).

% schlecht (Ihm ist schlecht.)
subjless_np_adjective(Pred-(a_ _),Arg1Sort) :=
  (@general_adjective(Pred),
   @arg1_pred(Arg1Sort),
   synsem:loc:(cat:(head:(prd_adj,
                          subj:[]),
                    subcat:[@lex_ref_comp_np_synsem(dat)]),
               cont:h_cons:(@e_diff_list))).


% warm
non_ref_adjective(Pred-(a_ _)) :=
  (@general_adjective(Pred),
   synsem:loc:(cat:(head:subj:[@expl_pronoun_synsem],
                    subcat:[]),
               cont:(key:pred_noarg_rel,
                     h_cons:(@e_diff_list)))).

np_adjective(Pred-(a_ _),Sort-anything,Case-case_val,Sort2-anything) :=
  (@general_subj_isec_adjective(Pred,Sort),
   synsem:loc:cat:subcat:[@lex_ref_comp_np_synsem(Case,Sort2)]).

pp_adjective(Pred-(a_ _),Sort-anything,PForm-pform,Case-case_val,Sort2-anything) :=
  (@general_subj_isec_adjective(Pred,Sort),
   synsem:loc:cat:subcat:[@ref_comp_pp_synsem(PForm,Case,Sort2)]).



% for modifiying adverbs, nominals
% can be stems or words
general_adverbial :=
  (synsem:loc:cat:head:mod:loc:cat:head:(participle_or_verb,
                                         initial:minus)).

% for all adverbs, except `nicht'
general_non_aux_adverbial :=
  (@general_adverbial,
   synsem:loc:cat:head:mod:loc:cont:key:main_event_rel).


% for all adverbs
% In general even single adverbs may be extraposed:
%
% Er hat geschlafen gestern / darin.
general_adverb(Pred) :=
  (%non_derived_word,
   @general_adverbial,
   word,
   synsem:loc:(cat:head:adv,
               cont:key:pred:Pred)).

% for all adverbs except the relative word `wo'
general_non_rel_adverb(Pred) :=
  (@complete_sign,
   @general_adverb(Pred)).


% for all adverbs, except `nicht'
general_non_aux_adverb(Pred) :=
  (@general_adverb(Pred),
   @general_non_aux_adverbial).

general_non_aux_non_rel_adverb(Pred) :=
  (@complete_sign,
   @general_non_aux_adverb(Pred)).


scopal_adverb(Pred) :=
  (@general_non_aux_non_rel_adverb(Pred),
   @scopal_modifier,
   synsem:loc:cat:head:extrap:minus).

scopal_adverb_lex(Pred) :=
  (@scopal_adverb(Pred),
   @overt_default_lexical_sign,
   @no_anchor).

% nicht
negation_adverb(Pred) :=
  (@overt_default_lexical_sign,
   @no_anchor,
   @general_non_rel_adverb(Pred),
   @scopal_modifier,
   synsem:loc:cat:head:extrap:minus).            % *Er hat geschlafen nicht. / *Er darf [das Buch _i zu kaufen nicht_i] versuchen.


intersective_adverb(Pred) :=
  (@general_non_aux_adverb(Pred),
   @intersective_modifier,
   @no_anchor).

intersective_non_rel_adverb(Pred) :=
  (@complete_sign,
   @intersective_adverb(Pred)).

intersective_adverb_lex(Pred) :=
  (@intersective_non_rel_adverb(Pred),
   @overt_default_lexical_sign).

temp_adverb(Pred) :=
  @intersective_adverb_lex(Pred).

pron_adv(Pred,Sort) :=
 (@intersective_non_rel_adverb(Pred),
  @overt_two_rel_lexical_sign,
  @no_anchor,
  synsem:loc:cont:(ind:(Ind,
                        index,
                        sort:Sort),
                   liszt:(list:[arg2:Ind,(pron_rel,
                                          arg1:Ind)|Last],
                          last:Last))).


verb_y :=
  (loc:(cat:(head:(verb),
                   %dsl:none\),
             spr:[]),
        cont:(ind:(event,Ind),
              ltop:Hand,
              key:(event_rel,
                   event:Ind,
                   lbl:Hand))),
   inert_anchors:[]).            % needed here since irreg_verbs (words) and regular verbs (stems) inherit from verb_y.

nscop_verb_y :=
  (@verb_y,
   loc:cont:h_cons:(@e_diff_list)).

verb := (
   @overt_default_lexical_sign,
    stem,
    synsem:(@verb_y)).

verb(Pred,VerbSort,Aktionsart) :=
 (@verb,
  synsem:loc:cont:(ind:(sort:VerbSort,
                        aktionsart:Aktionsart),
                   key:pred:Pred)).

nscop_verb :=
  (@verb,
   synsem:(@nscop_verb_y)).

nscop_verb(Pred,VerbSort,Aktionsart) :=
  (@verb(Pred,VerbSort,Aktionsart),
   synsem:(@nscop_verb_y)).

% The Subcat-List of the epsilon has to be restricted to be of a certain
% type, since otherwise ALE's computation of EPS combination loops.
%
% In the analysis of multiple frontings it may happen that LISZT is empty,
% therefore the verb movmenet trace cannot be a default_lexical_sign,
% since these introduce something into LISZT.
verb_movement_trace :=
  (@default_nonloc_non_coord_lexical_sign,
   @no_anchor,
    non_derived_word,
    phon:[],
    synsem:(loc:(%Loc,
                 cat:(head:(verb,
                            initial:minus,
                            dsl:(cat:subcat:Subcat,
                                 cont:Cont)),
                           %Loc\),
                      spr:[],
                      subcat:Subcat),
                 cont:Cont),
%                 coord:minus\),
            phrase:minus,
%            lex:plus,          default
            trace:vm)).

% only one of the verb trace macros is used in lexicon.pl
verb_movement_trace_cyclic :=
  (@default_nonloc_non_coord_lexical_sign,
   @no_anchor,
    non_derived_word,
    phon:[],
    synsem:(loc:(Loc,
                 cat:(head:(verb,
                            initial:minus,
                            dsl:Loc),
                      spr:[]
                      ,s_subcat:[_,_,_,_]
                     )),        % speed, restricts the number of arguments
%                 coord:minus),  % speed not needed, follows from coordination rules: TRACE-
            phrase:minus,
%            lex:plus,          default
            trace:vm)).


nonlocal_movement_trace :=
  (@lexical_sign,
    non_derived_word,
    phon:[],
    synsem:(
%            loc:cat:head:(              %major,
%                           dsl:none,       % otherwise [V-DSL Er ihr es]_i gibt _i. would be licensed.
%                         ),
            loc:cont:(liszt:  @e_diff_list,
                      h_cons: @e_diff_list),
            nonloc:(que:[],
                    rel:[]),
            inert_anchors:[]
%            phrase:minus,                        the phrasal status is determined by the context:
%                                                 full XPs are PHRASE+, X are PHRASE-
%            lex:plus,          default
            )).

/*
This would be the sharing of all information under LOC
extraction_trace :=
  (@nonlocal_movement_trace,
    synsem:(loc:(Loc,
                 cat:head:(vf:plus,
                           extrap:minus
                          )  
                ),
            nonloc:(slash:[Loc],
                    inert_extra:[]),
            trace:extraction)).
*/

% evrything but liszt and h_cons is shared.
% the values are provided by the filler. Introducing them here
% breaks the diff_list treatment.  04.03.2004
extraction_trace :=
  (@nonlocal_movement_trace,
    synsem:(loc:(cat:(Cat,
                      head:(vf:plus,
                            extrap:minus
                           )
                     ),
                 cont:(ltop:LTop,
                       gtop:GTop,
                       ind:Ind,
                       key:Key),
                 coord:Coord),
            nonloc:(slash:[(cat:Cat,
                            cont:(ltop:LTop,
                                  gtop:GTop,
                                  ind:Ind,
                                  key:Key),
                            coord:Coord)],
                    inert_extra:[]),
            trace:extraction)).

/*
extraposition_trace :=
  (@nonlocal_movement_trace,
    synsem:(loc:(Loc,
                 cat:(head:(vf:minus,
                            extrap:plus
% N' adjuncts are treated via anchor percolation
% verbal adjuncts have to be treated by movement, since linking of argument adjuncts (Passive-PP)
% is required.
%                            ,mod:none
                           ),
                      subcat:[])                    
                ),
            nonloc:(slash:[],
                    inert_extra:[Loc]),
            phrase:plus,
            trace:extraposition)).

*/

extraposition_trace :=
  (@nonlocal_movement_trace,
    synsem:(loc:(cat:(Cat,
                      head:(vf:minus,
                            extrap:plus
% N' adjuncts are treated via anchor percolation
% verbal adjuncts have to be treated by movement, since linking of argument adjuncts (Passive-PP)
% is required.
%                            ,mod:none
                           ),
                      subcat:[]),
                 cont:(ltop:LTop,
                       gtop:GTop,
                       ind:Ind,
                       key:Key),
                 coord:Coord
                ),
            nonloc:(slash:[],
                    inert_extra:[(cat:Cat,
                                  cont:(ltop:LTop,
                                        gtop:GTop,
                                        ind:Ind,
                                        key:Key),
                                  coord:Coord)]),
            phrase:plus,
            trace:extraposition)).

particle_synsem :=
  (@saturated_synsem,
   loc:cat:head:part).

particle_synsem(Part-(a_ _),Subtype-part) :=
  (@particle_synsem,
   loc:cat:head:(Subtype,
                 form:Part)).

% the default is the particle that is adjacent
% to the verb in verbfinal position
particle_synsem(Part) :=
  @particle_synsem(Part,nsep_part).


% The lexical entry for non-transparent particles. They do not contribute
% anything to the meaning. Their form is selected by the governing verb.
non_trans_particle(Part-(a_ _)) :=
  (@default_nonloc_no_rel_lexical_sign,
   @overt_sign,
   @no_anchor,
   @complete_comp_sign,
    non_derived_word,
    synsem:(@particle_synsem(Part,part))).


non_intransitive_verb :=
  (synsem:phrase:minus).

%% list is open, allows for expletive initial elements
open_arg1_pred(Arg1Sort-anything) :=
  (synsem:loc:(cat:subcat:[(loc:cont:ind:(Arg1,
                                          sort:Arg1Sort))|_],
               cont:key:(arg1_rel,
                         arg1:Arg1))).

arg1_pred(Arg1Sort-anything) :=
  (@open_arg1_pred(Arg1Sort),
   synsem:loc:cat:subcat:[_]).

open_arg1_part_verb(Arg1Sort-anything) :=
  (synsem:loc:(cat:subcat:[_particle,
                           (loc:cont:ind:(Arg1,
                                          sort:Arg1Sort))|_],
               cont:key:(arg1_rel,
                         arg1:Arg1))).

arg1_part_verb(Arg1Sort-anything) :=
  (@open_arg1_part_verb(Arg1Sort),
   synsem:loc:cat:subcat:[_particle,_]).


% this says nothing about where the arguments come from
% could be a particle verb or one without particle.
general_arg12_pred :=
  (synsem:loc:cont:key:arg12_rel).

%% list is open, allows for expletive initial elements
open_arg12_pred(Arg1Sort-anything,Arg2Sort-anything) :=
  (@general_arg12_pred,
   @non_intransitive_verb,   
   synsem:loc:(cat:subcat:[(loc:cont:ind:(Arg2,
                                          sort:Arg2Sort)),
                           (loc:cont:ind:(Arg1,
                                          sort:Arg1Sort))|_],
               cont:key:(arg1:Arg1,
                         arg2:Arg2))).

arg12_pred(Arg1Sort-anything,Arg2Sort-anything) :=
  (@open_arg12_pred(Arg1Sort,Arg2Sort),
   synsem:loc:cat:subcat:[_,_]).

open_arg12_part_verb(Arg1Sort-anything,Arg2Sort-anything) :=
  (@general_arg12_pred,
   @non_intransitive_verb,   
   synsem:loc:(cat:subcat:[_particle,
                           (loc:cont:ind:(Arg2,
                                          sort:Arg2Sort)),
                           (loc:cont:ind:(Arg1,
                                          sort:Arg1Sort))|_],
               cont:key:(arg1:Arg1,
                         arg2:Arg2))).

arg12_part_verb(Arg1Sort-anything,Arg2Sort-anything) :=
  (@open_arg12_part_verb(Arg1Sort,Arg2Sort),
   synsem:loc:cat:subcat:[_,_,_]).

arg123_pred(Arg1Sort,Arg2Sort,Arg3Sort) :=
  (@non_intransitive_verb,
   synsem:loc:(cat:subcat:[(loc:cont:ind:(Arg3,
                                           sort:Arg3Sort)),
                            (loc:cont:ind:(Arg2,
                                           sort:Arg2Sort)),
                            (loc:cont:ind:(Arg1,
                                           sort:Arg1Sort))],
                cont:key:(event_pred_arg123_rel,
                          arg1:Arg1,
                          arg2:Arg2,
                          arg3:Arg3))).

arg123_part_verb(Arg1Sort,Arg2Sort,Arg3Sort) :=
  (@non_intransitive_verb,
   synsem:(loc:(cat:subcat:[_particle,
                            (loc:cont:ind:(Arg3,
                                           sort:Arg3Sort)),
                            (loc:cont:ind:(Arg2,
                                           sort:Arg2Sort)),
                            (loc:cont:ind:(Arg1,
                                           sort:Arg1Sort))],
                cont:key:(event_pred_arg123_rel,
                          arg1:Arg1,
                          arg2:Arg2,
                          arg3:Arg3)),
           phrase:minus)).



subjless_np_verb(Pred-(a_ _),Arg1Sort-anything,Case-case_val,VerbSort-anything) :=
  (@nscop_verb(Pred,VerbSort,aktionsart),
   @open_arg1_pred(Arg1Sort),
   @non_intransitive_verb,   
   synsem:loc:cat:(head:(auxf:haben,
                         da:[]),
                   subcat:([(@lex_ref_comp_np_synsem(Case))]
                          ;[(@lex_ref_comp_np_synsem(Case)),@expl_pronoun_synsem]
                          ))).

subjless_np_pp_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,Case-case_val,PForm-pform,PCase-case_val,VerbSort-anything) :=
  (@nscop_verb(Pred,VerbSort,aktionsart),
   @open_arg12_pred(Arg1Sort,Arg2Sort),
   synsem:loc:cat:(head:(auxf:haben,
                         da:[]),
                   subcat:([(@ref_comp_pp_synsem(PForm,PCase)),(@lex_ref_comp_np_synsem(Case))]
                          ;[(@ref_comp_pp_synsem(PForm,PCase)),(@lex_ref_comp_np_synsem(Case)),@expl_pronoun_synsem]
                          ))).

%% the pp is always optional (drsten nach, grauen vor)
subjless_np_pp_verb(Pred-(a_ _),Arg1Sort-anything,_Arg2Sort-anything,Case-case_val,_PForm-pform,_PCas-case_val,VerbSort-anything) :=
  @subjless_np_verb(Pred,Arg1Sort,Case,VerbSort).
  
general_intrans_verb(Pred-(a_ _),Arg1Sort-anything,AuxF-auxf,VerbSort-situation,Aktionsart-aktionsart) :=
  (@nscop_verb(Pred,VerbSort,Aktionsart),
   @arg1_pred(Arg1Sort),
   synsem:loc:cat:(head:auxf:AuxF,
                   subcat:[(@str_ref_comp_np_synsem)])).

general_intrans_verb(Pred-(a_ _),Arg1Sort-anything,AuxF-auxf,VerbSort-situation,Aktionsart-aktionsart,Part-(a_ _)) :=
  (@nscop_verb(Pred,VerbSort,Aktionsart),
   @arg1_part_verb(Arg1Sort),
   synsem:loc:cat:(head:auxf:AuxF,
                   subcat:[@particle_synsem(Part),
                           @str_ref_comp_np_synsem])).

% The designated argument of unergative verbs is the last element in the
% subcat list. This can be either an NP with structural case or a clausal complement.
nerg_verb :=
  (@verb,
   synsem:loc:cat:(head:da:[last(Subcat)],
                   subcat:Subcat)).

% Auxiliary selection is not regularily tied to the unaccusative/unergative distinction.
% Therefore it is hard coeded in the lexical entries.
% See Mller 2002b for data.
haben_nerg_verb :=
  (@nerg_verb,
   synsem:loc:cat:head:auxf:haben).

intrans_nerg_verb(Pred-(a_ _),Arg1Sort-anything,AuxF-auxf,VerbSort-situation,Aktionsart-aktionsart) :=
  (@general_intrans_verb(Pred,Arg1Sort,AuxF,VerbSort,Aktionsart),
   @nerg_verb).

% particle verbs
intrans_nerg_verb(Pred-(a_ _),Arg1Sort-anything,AuxF-auxf,VerbSort-situation,Aktionsart-aktionsart,Part-(a_ _)) :=
  (@general_intrans_verb(Pred,Arg1Sort,AuxF,VerbSort,Aktionsart,Part),
   @nerg_verb).

% verbs with a separate particle even when the verb is in final position: Karten spielen, Bus fahren
sep_part_intrans_nerg_verb(Pred-(a_ _),Arg1Sort-anything,AuxF-auxf,VerbSort-situation,Aktionsart-aktionsart,Part-(a_ _)) :=
  (@nscop_verb(Pred,VerbSort,Aktionsart),
   @arg1_part_verb(Arg1Sort),
   @nerg_verb,
   synsem:loc:cat:(head:auxf:AuxF,
                   subcat:[@particle_synsem(Part,sep_part),
                           @str_ref_comp_np_synsem])).

refl_pronoun_acc(Ind) :=
  (@pronoun_noun_y,
   @complete_synsem,    % slash = [] -> no extraction of reflexive pronouns of inherent reflexives
   loc:(cat:head:case:(case_type:lex,
                       syn_case:acc),
        cont:(ind:Ind,
             key:(pron_rel,      
                  vtype:refl)))).  


erg_pred :=
 (synsem:loc:cat:head:(da:[],
                       auxf:sein)).

intrans_erg_verb(Pred-(a_ _),Arg1Sort-anything,VerbSort-situation,Aktionsart-aktionsart) :=
  (@general_intrans_verb(Pred,Arg1Sort,_Auxf,VerbSort,Aktionsart),
   @erg_pred).

intrans_erg_verb(Pred-(a_ _),Arg1Sort-anything,VerbSort-situation,Aktionsart-aktionsart,Part-(a_ _)) :=
  (@general_intrans_verb(Pred,Arg1Sort,_Auxf,VerbSort,Aktionsart,Part),
   @erg_pred).


% erholen
intrans_refl_verb(Pred-(a_ _),Arg1Sort-anything,VerbSort,Aktionsart-aktionsart) :=
  (@nscop_verb(Pred,VerbSort,Aktionsart),
   @non_intransitive_verb,
   @haben_nerg_verb,
   synsem:loc:(cat:subcat:[(@refl_pronoun_acc(Arg1)),
                           (@str_ref_comp_np_synsem(Arg1Sort),
                            loc:cont:ind:Arg1)],
               cont:key:(arg1_rel,
                         arg1:Arg1))).

np_np_refl_pp_verb(Pred,Arg1Sort,Arg2Sort,PForm,PCase,VerbSort) :=
  (@nscop_verb(Pred,VerbSort,aktionsart),
   @non_intransitive_verb,
   @haben_nerg_verb,
         synsem:loc:(cat:subcat:[(@ref_comp_pp_synsem(PForm,PCase),
                                  loc:cont:ind:(Arg2,
                                                sort:Arg2Sort)),
                                 (@refl_pronoun_acc(Arg1)),
                                 (@str_ref_comp_np_synsem(Arg1Sort),
                                     loc:cont:ind:Arg1)],
                     cont:key:(arg12_rel,
                               arg1:Arg1,
                               arg2:Arg2))).

arg12_verb(Arg1Sort-anything,Arg2Sort-anything) :=
  (@nscop_verb,
   @arg12_pred(Arg1Sort,Arg2Sort)).

arg12_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Aktionsart) :=
  (@nscop_verb(Pred,VerbSort,Aktionsart),
   @arg12_pred(Arg1Sort,Arg2Sort)).

arg12_part_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Aktionsart) :=
  (@nscop_verb(Pred,VerbSort,Aktionsart),
   @arg12_part_verb(Arg1Sort,Arg2Sort)).


arg123_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,VerbSort) :=
  (@nscop_verb(Pred,VerbSort,aktionsart),
   @arg123_pred(Arg1Sort,Arg2Sort,Arg3Sort)).

arg123_part_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,VerbSort) :=
  (@nscop_verb(Pred,VerbSort,aktionsart),
   @arg123_part_verb(Arg1Sort,Arg2Sort,Arg3Sort)).

% infinitival and sentential complements that are in SUBCAT
scope_arg2_pred(ArgSort) :=
  (@non_intransitive_verb,
   synsem:loc:(cat:subcat:[loc:cont:(ltop:VTop,
                                     ind:sort:ArgSort)|_],
               cont:(key:arg2:Arg2,
                     h_cons:(list:[(qeq,
                                    sc_arg:Arg2,
                                    outscpd:VTop)|Last],
                             last:Last)))).

scope_arg2_part_verb(ArgSort) :=
  (@non_intransitive_verb,
   synsem:loc:(cat:subcat:[_particle,
                           loc:cont:(ltop:VTop,
                                     ind:sort:ArgSort)|_],
               cont:(key:arg2:Arg2,
                     h_cons:(list:[(qeq,
                                    sc_arg:Arg2,
                                    outscpd:VTop)|Last],
                             last:Last)))).


scope_arg3_pred(ArgSort) :=
  (@non_intransitive_verb,
   synsem:loc:(cat:subcat:[loc:cont:(ltop:VTop,
                                     ind:sort:ArgSort)|_],
               cont:(key:arg3:Arg3,
                     h_cons:(list:[(qeq,
                                    sc_arg:Arg3,
                                    outscpd:VTop)|Last],
                             last:Last)))).

scope_arg3_part_verb(ArgSort) :=
  (@non_intransitive_verb,
   synsem:loc:(cat:subcat:[_particle,
                           loc:cont:(ltop:VTop,
                                     ind:sort:ArgSort)|_],
               cont:(key:arg3:Arg3,
                     h_cons:(list:[(qeq,
                                    sc_arg:Arg3,
                                    outscpd:VTop)|Last],
                             last:Last)))).

arg1_scope_2_verb(Pred,Arg1Sort-anything,Arg2Sort-anything,VerbSort) :=
  (@verb(Pred,VerbSort,aktionsart),
   @scope_arg2_pred(Arg2Sort),
   synsem:loc:(cat:subcat:[_,loc:cont:ind:(Ind,
                                           sort:Arg1Sort)],
               cont:key:(event_pred_arg12_rel,
                         arg1:Ind))).

arg1_scope_2_part_verb(Pred,Arg1Sort-anything,Arg2Sort-anything,VerbSort) :=
  (@verb(Pred,VerbSort,aktionsart),
   @scope_arg2_part_verb(Arg2Sort),
   synsem:loc:(cat:subcat:[_,_,loc:cont:ind:(Ind,
                                           sort:Arg1Sort)],
               cont:key:(event_pred_arg12_rel,
                         arg1:Ind))).

arg12_scope_3_verb(Pred,Arg1Sort-anything,Arg2Sort-anything,Arg3Sort-anything,VerbSort) :=
  (@verb(Pred,VerbSort,aktionsart),
   @scope_arg3_pred(Arg3Sort),
   synsem:loc:(cat:subcat:[_,
                           (loc:cont:ind:(Arg2,
                                          sort:Arg2Sort)),
                           (loc:cont:ind:(Arg1,
                                          sort:Arg1Sort))|_],
               cont:key:(event_pred_arg123_rel,
                         arg1:Arg1,
                         arg2:Arg2))).


%% Peter liebt Maria.     % unerg
%% Peter fllt Maria auf. % unacc
np_np_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,AuxF,VerbSort,Aktionsart) :=
 (@arg12_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Aktionsart),
  synsem:loc:cat:(head:auxf:AuxF,
                  subcat:[(@ref_comp_np_synsem),
                          (@ref_comp_np_synsem)])).

np_np_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,AuxF,VerbSort,Aktionsart,Part) :=
 (@arg12_part_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Aktionsart),
  synsem:loc:cat:(head:auxf:AuxF,
                  subcat:[@particle_synsem(Part),
                          (@ref_comp_np_synsem),
                          (@ref_comp_np_synsem)])).

trans_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,AuxF,VerbSort,Aktionsart) :=
 (@np_np_verb(Pred,Arg1Sort,Arg2Sort,AuxF,VerbSort,Aktionsart),
  @nerg_verb,
  synsem:loc:cat:subcat:[(@str_ref_comp_np_synsem),
                         (@str_ref_comp_np_synsem)]).        

trans_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,AuxF,VerbSort-anything,Aktionsart,Part-(a_ _)) :=
  (@np_np_verb(Pred,Arg1Sort,Arg2Sort,AuxF,VerbSort,Aktionsart,Part),
   @nerg_verb,
   synsem:loc:cat:subcat:[_particle,
                          (@str_ref_comp_np_synsem),
                          (@str_ref_comp_np_synsem)]).        


np_np_np_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,Case,VerbSort) :=
 (@arg123_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,VerbSort),
  @haben_nerg_verb,
  synsem:loc:cat:subcat:[(@lex_ref_comp_np_synsem(Case)),
                         (@str_ref_comp_np_synsem),
                         (@str_ref_comp_np_synsem)]).

ditrans_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,VerbSort) :=
 (@np_np_np_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,dat,VerbSort)).

np_np_np_part_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,Case,VerbSort,Part-(a_ _)) :=
 (@arg123_part_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,VerbSort),
  @haben_nerg_verb,
  synsem:loc:cat:subcat:[@particle_synsem(Part),
                         (@lex_ref_comp_np_synsem(Case)),
                         (@str_ref_comp_np_synsem),
                         (@str_ref_comp_np_synsem)]).

ditrans_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,VerbSort,Part-(a_ _)) :=
 (@np_np_np_part_verb(Pred,Arg1Sort,Arg2Sort,Arg3Sort,dat,VerbSort,Part-(a_ _))).


case_agreement_verb(Pred,Arg1Sort,VerbSort) :=
  (@np_np_np_verb(Pred,Arg1Sort,_Arg2Sort,_Arg3Sort,Case,VerbSort),
   synsem:loc:cat:subcat:[(@lex_ref_comp_np_synsem(Case),
                           loc:cont:(ind:num:Num,   % * Er nannte dich Idioten.
                                     key:(@not(pron_rel)))), % rules out pronouns         % * Er nannte den Mann ihn.
                          (@str_ref_comp_np_synsem,
                           loc:(cat:head:case:syn_case:Case,
                                cont:ind:num:Num)),_]).

np_cp_verb(Pred-(a_ _),Arg1Sort,CForm-cform,VerbSort) :=
  (@haben_nerg_verb,
   @arg1_scope_2_verb(Pred,Arg1Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@comp_cp_synsem(CForm),
                          @str_ref_comp_np_synsem]).

np_cp_verb(Pred-(a_ _),Arg1Sort,CForm-cform,VerbSort,Part) :=
  (@haben_nerg_verb,
   @arg1_scope_2_part_verb(Pred,Arg1Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@particle_synsem(Part),
                          @comp_cp_synsem(CForm),
                          @str_ref_comp_np_synsem]).

% dummies should be specified more carefully
np_cp_or_s_verb(Pred-(a_ _),Arg1Sort,CForm-cform,VerbSort) :=
  @np_cp_verb(Pred,Arg1Sort,CForm,VerbSort).

np_cp_or_s_verb(Pred-(a_ _),Arg1Sort,CForm-cform,VerbSort,Part) :=
  @np_cp_verb(Pred,Arg1Sort,CForm,VerbSort,Part).


% fragen
np_int_verb(Pred-(a_ _),Arg1Sort,VerbSort) :=
  (@haben_nerg_verb,
   @arg1_scope_2_verb(Pred,Arg1Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@w_phrase_synsem,
                          @str_ref_comp_np_synsem]).

np_int_verb(Pred-(a_ _),Arg1Sort,VerbSort,Part) :=
  (@haben_nerg_verb,
   @arg1_scope_2_part_verb(Pred,Arg1Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@particle_synsem(Part),
                          @w_phrase_synsem,
                          @str_ref_comp_np_synsem]).
% jemanden fragen
np_np_int_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,VerbSort) :=
  (@haben_nerg_verb,
   @arg12_scope_3_verb(Pred,Arg1Sort,Arg2Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@w_phrase_synsem,
                          @str_ref_comp_np_synsem,
                          @str_ref_comp_np_synsem]).

np_np_int_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,VerbSort,Part) :=
  (@haben_nerg_verb,
   @arg12_scope_3_part_verb(Pred,Arg1Sort,Arg2Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@particle_synsem(Part),
                          @w_phrase_synsem,
                          @str_ref_comp_np_synsem,
                          @str_ref_comp_np_synsem]).

% ich sage ihm, da ...
np_cp_np_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,CForm-cform,VerbSort) :=
  (@haben_nerg_verb,
   @arg12_scope_3_verb(Pred,Arg1Sort,Arg2Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@comp_cp_synsem(CForm),
                          @lex_ref_comp_np_synsem(dat),
                          @str_ref_comp_np_synsem]).

np_cp_np_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,CForm-cform,VerbSort,Part) :=
  (@haben_nerg_verb,
   @arg12_scope_3_verb(Pred,Arg1Sort,Arg2Sort,situation,VerbSort),
   synsem:loc:cat:subcat:[@particle_synsem(Part),
                          @comp_cp_synsem(CForm),
                          @lex_ref_comp_np_synsem(dat),
                          @str_ref_comp_np_synsem]).

% dummies should be specified more carefully
np_cp_or_s_np_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,CForm-cform,VerbSort) :=
  @np_cp_np_verb(Pred,Arg1Sort,Arg2Sort,CForm,VerbSort).

np_cp_or_s_np_verb(Pred-(a_ _),Arg1Sort,Arg2Sort,CForm-cform,VerbSort,Part) :=
  @np_cp_np_verb(Pred,Arg1Sort,Arg2Sort,CForm,VerbSort,Part).



np_np_erg_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,Case-case_val,VerbSort-anything,Aktionsart) :=
  (@np_np_verb(Pred,Arg1Sort,Arg2Sort,sein,VerbSort,Aktionsart),
   @erg_pred,
   synsem:loc:cat:subcat:[@lex_ref_comp_np_synsem(Case),
                          @str_ref_comp_np_synsem]).

% auffallen
np_np_erg_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,Case-case_val,VerbSort-anything,Aktionsart,Part-(a_ _)) :=
  (@np_np_verb(Pred,Arg1Sort,Arg2Sort,sein,VerbSort,Aktionsart,Part),
   @erg_pred,
   synsem:loc:cat:subcat:[_particle,
                          @lex_ref_comp_np_synsem(Case),
                          @str_ref_comp_np_synsem]).

% helfen
np_np_nerg_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,Case-case_val,VerbSort-anything,Aktionsart) :=
  (@np_np_verb(Pred,Arg1Sort,Arg2Sort,haben,VerbSort,Aktionsart),
   @nerg_verb,
   synsem:loc:cat:subcat:[@lex_ref_comp_np_synsem(Case),
                          @str_ref_comp_np_synsem]).


np_np_nerg_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,Case-case_val,VerbSort-anything,Aktionsart,Part-(a_ _)) :=
  (@np_np_verb(Pred,Arg1Sort,Arg2Sort,haben,VerbSort,Aktionsart),
   @nerg_verb,
   synsem:loc:cat:subcat:[@particle_synsem(Part),
                          @lex_ref_comp_np_synsem(Case),
                          @str_ref_comp_np_synsem]).



% arbeiten an
np_pp_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,PForm-pform,Case-case_val,VerbSort-anything,Aktionsart) :=
  (@haben_nerg_verb,
   @arg12_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Aktionsart),
   synsem:loc:cat:subcat:[(@ref_comp_pp_synsem(PForm,Case)),
                          (@str_ref_comp_np_synsem)]).

np_pp_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,PForm-pform,Case-case_val,VerbSort-anything,Aktionsart,Part-(a_ _)) :=
  (@haben_nerg_verb,
   @arg12_part_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Aktionsart),
   synsem:loc:cat:subcat:[(@particle_synsem(Part)),
                          (@ref_comp_pp_synsem(PForm,Case)),
                          (@str_ref_comp_np_synsem)]).


%% Da Peter klug ist, ist ihm aufgefallen.
cp_np_erg_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,CForm-cform,Case-case_val,VerbSort-anything) :=
 (@arg12_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,aktionsart),
  @erg_pred,
  synsem:loc:cat:(head:auxf:sein,
                  subcat:[@lex_ref_comp_np_synsem(Case),
                          @comp_cp_synsem(CForm)])).

cp_np_erg_verb(Pred-(a_ _),Arg1Sort-anything,Arg2Sort-anything,CForm-cform,Case-case_val,VerbSort-anything,Part-(a_ _)) :=
 (@arg12_part_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,aktionsart),
  @erg_pred,
  synsem:loc:cat:(head:auxf:sein,
                  subcat:[@particle_synsem(Part),
                          @lex_ref_comp_np_synsem(Case),
                          @comp_cp_synsem(CForm)])).



% deblocks the subject, perfect, modals, and raising verbs with zu-inf
% copula verbs, AcI verbs, subject and object predicatives.
raising_pred :=
  (synsem:loc:cat:subcat:[@complex_forming_attraction_head|_]).

% verbs or adjectives
complex_forming_attraction_head :=
  (loc:cat:head:subj:non_blocked_list,
   phrase:minus).

subj_raising_pred :=
  (@raising_pred,
   synsem:loc:cat:(subcat:[(@complex_forming_attraction_head,
                            loc:cat:(head:subj:Subj,
                                     subcat:Subcat))
                          |(list_of_non_complex_forming_synsems,
                            append(Subcat,Subj))])).

% The following states what may be raised. If verbs enter obligatorily
% coherent verbal constructions, they require their complex forming
% argument to be PHRASE-. The following prohibits raising of PHRASE-
% arguments.

% Do we need the restriction on saturatedness, or does this follow
% from phrasal status?  02.11.2003

non_complex_forming_synsem :=
  (loc:cat:(head:prd:minus,
            subcat:[]),
   phrase:plus).

fun list_of_non_complex_forming_synsems(-).
list_of_non_complex_forming_synsems(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_complex_forming_synsems(L) ).

% The prd:minus constraint should be changed into
% a type constraint. 02.11.2003
undelayed_list_of_non_complex_forming_synsems([]) if true.

% the following would be the proper recursive definition:
undelayed_list_of_non_complex_forming_synsems([(@non_complex_forming_synsem)|T]) if
   list_of_non_complex_forming_synsems(T).

% But we can improve efficiency by using knowledge about the grammar:
% We know that complex forming predicates are the most oblique elements,
% i.e. once we found a non_complex_forming_synsem, evrything else will be
% non_complex_forming_synsems also.

% This should be tested, once everything else works:
%undelayed_list_of_non_complex_forming_synsems([(@non_complex_forming_synsem)|_T]) if true.


% The following constraint is used when a non-head is extracted in head-cluster structures
% The attracted arguments are blocked from extraposition. Extraposition is admitted from
% the fronted element only.
%
% [_i stolz] wird er sein [auf ihn]_i.
%
% * stolz wird er _i sein [auf ihn]_i.
%
% 19.02.2004

fun list_of_non_complex_forming_non_extra_synsems(-).
list_of_non_complex_forming_non_extra_synsems(L) if
   when( (L=(e_list;ne_list)),
         undelayed_list_of_non_complex_forming_non_extra_synsems(L) ).

% The prd:minus constraint should be changed into
% a type constraint. 02.11.2003
undelayed_list_of_non_complex_forming_non_extra_synsems([]) if true.

% the following would be the proper recursive definition:
undelayed_list_of_non_complex_forming_non_extra_synsems([(@non_complex_forming_synsem,
                                                          trace:minus_or_extraction)|T]) if
   list_of_non_complex_forming_non_extra_synsems(T).



subj_raising_verb :=
  (@verb,
   @subj_raising_pred).

subj_raising_part_verb :=
  (@verb,
   synsem:loc:cat:(subcat:[ loc:cat:head:part,
                           (@complex_forming_attraction_head,
                            loc:cat:(head:subj:Subj,
                                     subcat:Subcat))
                          |(list_of_non_complex_forming_synsems,
                            append(Subcat,Subj))])).

sem_embed_pred :=
  (@non_intransitive_verb,
   synsem:loc:(cat:subcat:[loc:cont:ltop:VTop|_],
               cont:h_cons:(list:[(qeq,
                                %sc_arg:Top,
                                   outscpd:VTop)|Last],
                            last:Last))).

sem_embed_part_verb :=
  (@non_intransitive_verb,
   synsem:loc:(cat:subcat:[loc:cat:head:part,loc:cont:ltop:VTop|_],
               cont:h_cons:(list:[(qeq,
                                %sc_arg:Top,
                                   outscpd:VTop)|Last],
                            last:Last))).

sem_embed_arg1_pred :=
  (@sem_embed_pred,
   synsem:loc:cont:(key:arg1:Hand,
                    h_cons:(list:[sc_arg:Hand|Last],
                            last:Last))).

sem_embed_arg1_verb :=
  (@sem_embed_arg1_pred,
   @verb).

sem_embed_arg1_part_verb :=
  (@sem_embed_part_verb,
   synsem:loc:cont:(key:arg1:Hand,
                    h_cons:(list:[sc_arg:Hand|Last],
                            last:Last))).

sem_embed_arg2_verb :=
  (@sem_embed_pred,
   @verb,
   synsem:loc:cont:(key:arg2:Hand,
                    h_cons:(list:[sc_arg:Hand|Last],
                            last:Last))).

sem_embed_arg2_part_verb :=
  (@sem_embed_part_verb,
   @verb,
   synsem:loc:cont:(key:arg2:Hand,
                    h_cons:(list:[sc_arg:Hand|Last],
                            last:Last))).


sem_embed_arg3_verb :=
  (@sem_embed_pred,
   @verb,
   synsem:loc:cont:(key:arg3:Hand,
                    h_cons:(list:[sc_arg:Hand|Last],
                            last:Last))).

sem_embed_arg3_part_verb :=
  (@sem_embed_part_verb,
   @verb,
   synsem:loc:cont:(key:arg3:Hand,
                    h_cons:(list:[sc_arg:Hand|Last],
                            last:Last))).


sem_embed_subj_raising_pred :=
  (@subj_raising_pred,
   @sem_embed_arg1_pred).

sem_embed_subj_raising_verb :=
  (@subj_raising_verb,
   @sem_embed_arg1_verb).

sem_embed_subj_raising_part_verb :=
  (@subj_raising_part_verb,
   @sem_embed_arg1_part_verb).


% AcI verbs, resultative constructions, obj. predicatives
% Subcat:Pred,Pred-Subcat,Pred-Subj,Matrix-Subj

obj_raising_verb(Pred,Arg1Sort,VerbSort) :=
  (@raising_pred,
   @sem_embed_arg2_verb,
   synsem:loc:(cat:(subcat:[(@complex_forming_attraction_head,
                             loc:cat:(head:subj:Subj,
                                      subcat:Subcat))
                            |append(append(Subcat,Subj),
                                    [(@str_ref_comp_np_synsem,
                                      loc:cont:ind:(Ind,
                                                    sort:Arg1Sort))])]),
               cont:(ind:sort:VerbSort,
                     key:(pred:Pred,
                          arg1:Ind)))).

aci_verb(Pred,Arg1Sort,VerbSort) :=
  (@obj_raising_verb(Pred,Arg1Sort,VerbSort),
   @bse_complex_pred).

% Er findet ihn doof.

/* ich finde ihn albern.
   albern an ihm fand ich, dass ... (Ltscher 85, S. 215)

   ??? * Ich finde ihn stolz auf seinen Sohn.
   aber Ich finde ihn etwas zu stolz auf seinen Sohn.

*/
obj_pred_verb(Pred,Arg1Sort,VerbSort) :=
  (@obj_raising_verb(Pred,Arg1Sort,VerbSort),
   synsem:loc:cat:subcat:[loc:cat:head:prd_adj_or_prd_prep|_]).


% the same as above but the embedded subject is not raised
% and the DA is required to contain a referential element

%   Dieses Buch lt hoffen. -> both animate and inanimate subjects possible
% * Das Buch lt die Theorie revidieren.
lassen_passive :=
  (@sem_embed_arg2_verb,
   @bse_complex_pred,
   synsem:loc:(cat:subcat:[(loc:cat:(head:da:[loc:cont:ind:referential],
                                     subcat:Subcat),
                            phrase:minus)|
                          append(Subcat,[(@str_ref_comp_np_synsem,
                                          loc:cont:ind:(Ind,
                                                        sort:_Arg1Sort))])],
               cont:(ind:sort:situation,
                     key:(pred:(a_ lassen),
                          arg1:Ind)))).
/*
lassen_middle :=
  (@sem_embed_arg2_verb,
   @bse_complex_pred,
   synsem:loc:(cat:(subcat:append(Subcat,[(@str_ref_comp_np_synsem,
                                           loc:cont:ind:(Ind,
                                                         sort:_Arg1Sort))]),
                    xcomp:[(loc:cat:(head:da:[loc:cont:ind:referential],
                                     subcat:Subcat,
                                     xcomp:[]),
                            phrase:minus)]),
               cont:(ind:sort:situation,
                     key:(pred:(a_ lassen),
                          arg1:Ind)))).

*/

arg2_xcomp_attr_verb :=
  (@subj_raising_verb,
   @sem_embed_arg2_verb).

arg2_xcomp_attr_verb(Pred,Arg1Sort) :=
  (@arg2_xcomp_attr_verb,
   @arg12_verb(Pred,Arg1Sort,situation,situation,aktionsart)).


perfect_aux_pred(Auxf-auxf) :=
  (@sem_embed_arg1_pred,                              % deblocks the DA/SUBJ (DA/SUBJ are identical in case of ppp forms)
   synsem:loc:(cat:subcat:[loc:cat:head:(ppp_verb,
                                         auxf:Auxf)|_],
               cont:key:perfect_rel)).


% There is an additional constraint, that at least one argument has to be attracted
% from the embedded participle. There are no constructions without arguments that
% con be embedded under haben. For sein this is different:
%
% Heute ist gearbeitet worden.
%
%
% The constraint helps in cases where the participle is extracted (PVP).
% In this case the number of attracted arguments is unknown, the edge could
% be used in more complex structures as an edge with zero arguments, which
% is impossible since the fronted complex must have an argument due to properties
% of the lexical entries.
%
% For modal infinitives this cannot be applied, since passives are marginally
% possible under haben:
%
% ?Heute hat gearbeitet zu werden.
haben :=
  (@perfect_aux_pred(haben),
   @subj_raising_verb,
   synsem:loc:cat:(head:(flip:Flip,
                         da:DA),
%                             list_of_non_complex_forming_synsems)),  % we do not know what it is, but we know that
                                                                     % it is not complex forming
                                                                     % without this constraint the da_blocking would
                                                                     % block the embedded ppp_verb (cyclic structure), only to find out
                                                                     % later that the DA of the embedded ppp_verb differs from the ppp_verb
                   subcat:[loc:cat:head:(flip:Flip,
                                         da:DA)|at_least_one])).

modal_inf_pred :=
  (@sem_embed_arg1_pred,                              % deblocks the DA/SUBJ (DA/SUBJ are identical in case of ppp forms)
   synsem:loc:(cat:subcat:[loc:cat:head:inf_verb|_],
               cont:key:modal_rel)).


haben :=
  (@subj_raising_verb,
   @modal_inf_pred,
   synsem:loc:cat:(head:(flip:Flip,
                         da:DA),
                   subcat:[loc:cat:head:(flip:Flip,
                                         da:DA)|_])).

bse_complex_pred :=
  (synsem:loc:cat:(head:flip:minus,
                   subcat:[loc:cat:head:bse_verb|_])).

bse_raising_pred :=
  (@sem_embed_subj_raising_pred,
   @bse_complex_pred).

bse_raising_verb :=
  (@bse_raising_pred,
   @verb).

werden_fut :=
  (@bse_raising_pred,
   synsem:(@verb_y,
           loc:(cat:head:fin_verb,
                cont:(ind:temo:pres,
                      key:future_rel)))).

zu_inf_verb :=
  (synsem:loc:cat:(head:flip:minus,
                   subcat:[loc:cat:head:inf_verb|_])).

zu_inf_obl_coh_verb :=
  (@zu_inf_verb,
   synsem:loc:cat:subcat:[phrase:minus|_]).

zu_inf_part_verb :=
  (synsem:loc:cat:(head:flip:minus,
                   subcat:[loc:cat:head:part,loc:cat:head:inf_verb|_])).

zu_inf_obl_coh_part_verb :=
  (@zu_inf_part_verb,
   synsem:loc:cat:subcat:[_particle,phrase:minus|_]).


zu_raising_verb :=
  (@sem_embed_subj_raising_verb,
   @zu_inf_obl_coh_verb).

% agentive passive, stative passive, dative passive, modal infinitives with zu
general_passive_aux_pred :=
  (@sem_embed_arg1_pred,
   synsem:loc:cat:subcat:[(loc:(cat:head:da:[loc:cont:ind:referential],
                                cont:key:main_event_rel),                  % rules out Der Mann wird geliebt gehabt . + Ein Buch wird geschenkt bekommen .
                                                                           % aber nicht: Das Buch wird zu lesen gehabt .
                           phrase:minus)|_]).

% The elements on SUBCAT are only the non blocked.
% The auxiliary raises everything.
passive_aux_pred :=
  (@general_passive_aux_pred,
   synsem:loc:cat:subcat:[loc:cat:subcat:Subcat
                         |Subcat]).

ppp_passive_aux_pred :=
  (@passive_aux_pred,
   @erg_pred,
   synsem:loc:cat:subcat:[loc:cat:head:ppp_verb|_]).


% should there be a dative_passive_rel? Probably not.
dative_passive_aux_verb :=
  (@general_passive_aux_pred,
   @haben_nerg_verb,
   synsem:loc:(cat:subcat:[loc:cat:(head:ppp_verb,
                                   subcat:Subcat)
                         |promote_dat(Subcat)],
               cont:key:passive_rel)).

sein_perfect :=
  (@erg_pred,
   @subj_raising_pred,
   @perfect_aux_pred(sein)).


sein_pas :=
  (@irreg_verb,
   @sem_embed_arg1_pred,
   @ppp_passive_aux_pred,
   synsem:loc:cont:(ind:aktionsart:state,
                    key:stative_passive_rel)). % should be modelled more explicitely by using states and events


% having a passive_rel may seem strange
% but I think one needs it to give negation
% something to scope over
werden_pas :=
  (@irreg_verb,
   @sem_embed_arg1_pred,
   @ppp_passive_aux_pred,
   synsem:loc:cont:key:agentive_passive_rel).   

sein_inf :=
  (@erg_pred,
   @modal_inf_pred,
   @sem_embed_arg1_pred,
   @passive_aux_pred).

% since the forms of the copula are irregular, they are listed as fully inflected
% lexical entries.
irreg_verb :=
  (@overt_default_lexical_sign,
   synsem:(@verb_y)).

           
irreg_verb(Head) :=
  (@non_particle_ppp_infl_lex_rule(Dtr),
   zdtr:(Dtr,
        @irreg_verb,
        synsem:loc:cat:head:Head)).

irreg_verb(Head) :=
  (@non_particle_bse_infl_lex_rule(Dtr),
   zdtr:(Dtr,
        @irreg_verb,
        synsem:loc:cat:head:Head)).

irreg_verb(Per,Num,Temo) :=
  (@irreg_verb,
   non_derived_word,
   synsem:loc:(cat:(head:(fin_verb,
                          initial:minus),
                    subcat:subj_verb_agreement(Per,Num)
                   ),
               cont:ind:temo:Temo)).

%%% nonfinite forms
werden_pas(Head) :=
 (zdtr:(@werden_pas),
  @irreg_verb(Head)).

%%% finite forms
werden_pas(Per-per,Num-num,Temo-temo) :=
 (@werden_pas,
  @irreg_verb(Per,Num,Temo)).

%%% nonfinite forms
werden_kopula(Head) :=
 (zdtr:(@werden_kopula),
  @irreg_verb(Head)).

%%% finite forms
werden_kopula(Per-per,Num-num,Temo-temo) :=
 (@werden_kopula,
  @irreg_verb(Per,Num,Temo)).

%%% finite forms
werden_fut(Per,Num,Temo) :=
 (@werden_fut,
  @irreg_verb(Per,Num,Temo)).

werden(Per-per,Num-num,Temo-temo) :=
  @werden_pas(Per,Num,Temo).

werden(Per-per,Num-num,Temo-temo) :=
  @werden_kopula(Per,Num,Temo).

werden(Per-per,Num-num,Temo-temo) :=
  @werden_fut(Per,Num,Temo).

% there is no non-finite form for future werden

werden(Head) :=
  @werden_pas(Head).

werden(Head) :=
  @werden_kopula(Head).


%%% nonfinite forms
sein_pas(Head) :=
 (zdtr:(@sein_pas),
  @irreg_verb(Head)).

%%% finite forms
sein_pas(Per-per,Num-num,Temo-temo) :=
 (@sein_pas,
  @irreg_verb(Per,Num,Temo)).

%%% nonfinite forms
sein_pas(Head) :=
 (zdtr:(@sein_inf),
  @irreg_verb(Head)).

%%% finite forms
sein_pas(Per-per,Num-num,Temo-temo) :=
 (@sein_inf,
  @irreg_verb(Per,Num,Temo)).


kopula :=
  (@irreg_verb,
   @sem_embed_subj_raising_pred,
   @erg_pred,
   synsem:loc:(cat:subcat:[@prd_adj_synsem|_],
               cont:ind:aktionsart:state)).

sein_kopula :=
  (@kopula,
   synsem:loc:cont:key:support_rel).

werden_kopula :=
  (@kopula,
   synsem:loc:cont:key:become_rel).

%%% nonfinite forms
sein_kopula(Head) :=
 (zdtr:(@sein_kopula),
  @irreg_verb(Head)).

%%% finite forms
sein_kopula(Per-per,Num-num,Temo-temo) :=
 (@sein_kopula,
  @irreg_verb(Per,Num,Temo)).

sein_perfect(Head) :=
 (zdtr:(@sein_perfect),
  @irreg_verb(Head)).

sein_perfect(Per-per,Num-num,Temo-temo) :=
 (@sein_perfect,
  @irreg_verb(Per,Num,Temo)).

sein(Per-per,Num-num,Temo-temo) :=
  @sein_kopula(Per,Num,Temo).

sein(Per-per,Num-num,Temo-temo) :=
  @sein_perfect(Per,Num,Temo).


sein(Per-per,Num-num,Temo-temo) :=
  @sein_pas(Per,Num,Temo).



sein(Head) :=
  @sein_pas(Head).

sein(Head) :=
  @sein_kopula(Head).

sein(Head) :=
  @sein_perfect(Head).

% eigentlich mu es zwei Eintrge fr Modalverben geben:
% Raising und Kontrollversion

%Kontrollversion -> Rolle

%Karl soll schlafen.

% Auch bei der Kontrollversion kann das Subjekt implizit bleiben
% Haider90: dass den Vortrag abzusagen htte vereinbart werden mssen.

modal_verb(Pred-(a_ _),Arg1Sort) :=
  (@subj_raising_verb,
   @arg2_xcomp_attr_verb(Pred,Arg1Sort),
   synsem:loc:cat:(head:flip:minus,               % otherwise Karl wird lachen koennen duerfen.
                                                  % had two analyses.
                    
                   subcat:[loc:cat:head:bse_verb|_])).

modal_verb(Pred-(a_ _)) := 
  (@bse_raising_verb,
   synsem:loc:cont:key:pred:Pred).

% scheinen
subj_raising_obl_coh_verb(Pred-(a_ _)) := 
  (@zu_raising_verb,
   synsem:loc:cont:key:pred:Pred).

% Ihm scheint das Buch zu gefallen.
np_dat_subj_raising_verb(Pred-(a_ _),Arg1Sort-anything) := 
  (@sem_embed_arg2_verb,
   @erg_pred,
   synsem:loc:(cat:(head:flip:minus,
                    subcat:[(loc:cat:(head:(inf_verb,
                                            subj:Subj),
                                      subcat:Subcat),
                             phrase:minus)
                           |append(append(Subcat,Subj),[(@lex_ref_comp_np_synsem(dat,Arg1Sort),
                                                        loc:cont:ind:Ind)])]),
               cont:key:(pred:Pred,
                         arg1:(Ind,
                               sort:Arg1Sort)))).

v_synsem(SubjInd) :=
  (loc:cat:head:(verb,
                 subj:[loc:cont:ind:SubjInd])).

vp_synsem(SubjInd) :=
  (@saturated_synsem,
   @v_synsem(SubjInd),
   loc:cat:head:inf_verb,            % only zu-infinitives are selected as VPs, other infs may form phrases
                                     % but are never selected as phrases.
   phrase:plus).                     % necessary to exclude VPs in head cluster structures (intransitive verbs)

% the subject index is shared with the index of the subj value
% of the VP
% includes subject control verbs with additional objects
general_incoh_subj_control_verb(Pred,Arg1Sort,VerbSort-situation) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   synsem:loc:(cat:(head:da:[loc:cont:ind:(SubjInd,
                                           sort:Arg1Sort)],
                    subcat:[@vp_synsem(SubjInd)|_]),
               cont:key:arg1:SubjInd)).

general_incoh_subj_control_verb(Pred,Arg1Sort,VerbSort-situation,Part) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   synsem:loc:(cat:(head:da:[loc:cont:ind:(SubjInd,
                                           sort:Arg1Sort)],
                    subcat:[@particle_synsem(Part),
                            @vp_synsem(SubjInd)|_]),
               cont:key:arg1:SubjInd)).


% This is for both coherent and incoherent constructions.
np_v_subj_control_verb(Pred,Arg1Sort,VerbSort-situation) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_verb,
   @sem_embed_arg2_verb,
   synsem:loc:(cat:subcat:[(@v_synsem(SubjInd),
                            loc:cat:subcat:Subcat)
                          |append(Subcat,[(@str_ref_comp_np_synsem,
                                           loc:cont:ind:SubjInd)])],
               cont:key:arg1:(SubjInd,
                              sort:Arg1Sort))).

np_v_subj_control_verb(Pred,Arg1Sort,VerbSort-situation,Part) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_part_verb,
   @sem_embed_arg2_part_verb,
   synsem:loc:(cat:subcat:[@particle_synsem(Part),
                           (@v_synsem(SubjInd),
                               loc:cat:subcat:Subcat)
                          |append(Subcat,[(@str_ref_comp_np_synsem,
                                           loc:cont:(ind:SubjInd))])],
               cont:key:arg1:(SubjInd,
                              sort:Arg1Sort))).

/*
% incoherent version
np_v_subj_control_verb(Pred,Arg1Sort-anything,VerbSort-situation) :=
  (@general_incoh_subj_control_verb(Pred,Arg1Sort,VerbSort),
   @scope_arg2_pred(situation),
   synsem:loc:cat:subcat:[_Verb,@str_ref_comp_np_synsem]).


np_v_subj_control_verb(Pred,Arg1Sort,VerbSort-situation,Part-(a_ _)) :=
  (@general_incoh_subj_control_verb(Pred,Arg1Sort,VerbSort,Part),
   @scope_arg2_part_verb(situation),
   synsem:loc:cat:subcat:[_particle,
                          _Verb,
                          @str_ref_comp_np_synsem]).

*/

/*
unused
% versprechen
np_np_v_incoh_subj_control_verb(Pred,Arg1Sort,Arg2Sort,Case,VerbSort-situation) :=
  (@general_incoh_subj_control_verb(Pred,Arg1Sort,VerbSort),
   @scope_arg3_pred(situation),
   synsem:loc:(cat:subcat:[_Verb,
                           (@lex_ref_comp_np_synsem(Case,Arg2Sort),
                            loc:cont:ind:ObjInd),
                           @str_ref_comp_np_synsem],
               cont:key:arg2:ObjInd)).
*/

% with lexical case
np_np_v_subj_control_verb(Pred,Arg1Sort,Arg2Sort,Case,VerbSort-situation,Part-(a_ _)) :=
  (@general_incoh_subj_control_verb(Pred,Arg1Sort,VerbSort,Part),
   @scope_arg3_part_verb(situation),
   synsem:loc:(cat:subcat:[_particle,
                           _Verb,
                           (@lex_ref_comp_np_synsem(Case,Arg2Sort),
                            loc:cont:ind:ObjInd),
                           @str_ref_comp_np_synsem],
               cont:key:arg2:ObjInd)).


np_np_v_subj_control_verb(Pred,Arg1Sort,Arg2Sort,VerbSort-situation) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_verb,
   @sem_embed_arg3_verb,
   synsem:loc:(cat:subcat:[(@v_synsem(SubjInd),
                           loc:cat:subcat:Subcat)
                          |append(Subcat,[(@str_ref_comp_np_synsem,
                                           loc:cont:ind:ObjInd),
                                          (@str_ref_comp_np_synsem,
                                           loc:cont:ind:SubjInd)])],
               cont:key:(arg1:(SubjInd,
                               sort:Arg1Sort),
                         arg2:(ObjInd,
                               sort:Arg2Sort)))).


np_np_v_subj_control_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Part) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_part_verb,
   @sem_embed_arg3_part_verb,
   synsem:loc:(cat:subcat:[@particle_synsem(Part,nsep_part),
                           (@v_synsem(SubjInd),
                            loc:cat:subcat:Subcat)
                          |append(Subcat,[(@str_ref_comp_np_synsem,
                                           loc:cont:ind:ObjInd),(@str_ref_comp_np_synsem,
                                                                 loc:cont:ind:SubjInd)])],
               cont:key:(arg1:(SubjInd,
                               sort:Arg1Sort),
                         arg2:(ObjInd,
                               sort:Arg2Sort)))).


np_np_v_subj_control_verb(Pred,Arg1Sort,Arg2Sort,Case,VerbSort-situation) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_verb,
   @sem_embed_arg3_verb,
   synsem:loc:(cat:subcat:[(@v_synsem(SubjInd),
                           loc:cat:subcat:Subcat)
                           |append(Subcat,[(@lex_ref_comp_np_synsem(Case),
                                           loc:cont:ind:ObjInd),
                                           (@str_ref_comp_np_synsem,
                                            loc:cont:ind:SubjInd)])],
               cont:key:(arg1:(SubjInd,
                               sort:Arg1Sort),
                         arg2:(ObjInd,
                               sort:Arg2Sort)))).


np_np_v_subj_control_verb(Pred,Arg1Sort,Arg2Sort,Case,VerbSort,Part) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_part_verb,
   @sem_embed_arg3_part_verb,
   synsem:loc:(cat:subcat:[@particle_synsem(Part),
                           (@v_synsem(SubjInd),
                            loc:cat:subcat:Subcat)
                          |append(Subcat,[(@lex_ref_comp_np_synsem(Case),
                                           loc:cont:ind:ObjInd),
                                          (@str_ref_comp_np_synsem,
                                           loc:cont:ind:SubjInd)])],
               cont:key:(arg1:(SubjInd,
                               sort:Arg1Sort),
                         arg2:(ObjInd,
                               sort:Arg2Sort)))).


% Er zwingt ihn, das Problem anzuerkennen.
np_np_v_obj_control_verb(Pred,Arg1Sort,Arg2Sort,VerbSort-situation) :=
%  (@general_np_np_v_incoh_obj_control_verb(Pred,Arg1Sort,Arg2Sort,VerbSort),
%   synsem:loc:cat:subcat:[_Verb,
% both coherent and incoherent
(@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_verb,
   @sem_embed_arg3_verb,
   synsem:loc:(cat:subcat:[(@v_synsem(ObjInd),
                            loc:cat:subcat:Subcat)
                           |append(Subcat,[(@str_ref_comp_np_synsem,
                                            loc:cont:ind:(ObjInd,
                                                          sort:Arg2Sort)),
                                           (@str_ref_comp_np_synsem,
                                           loc:cont:ind:(SubjInd,
                                                          sort:Arg1Sort))])],
               cont:key:(arg1:SubjInd,
                         arg2:ObjInd))).

np_np_v_obj_control_verb(Pred,Arg1Sort,Arg2Sort,VerbSort,Part-(a_ _)) :=
(@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_part_verb,
   @sem_embed_arg3_part_verb,
   synsem:loc:(cat:subcat:[@particle_synsem(Part),
                           (@v_synsem(ObjInd),
                            loc:cat:subcat:Subcat)
                           |append(Subcat,[(@str_ref_comp_np_synsem,
                                            loc:cont:ind:(ObjInd,
                                                          sort:Arg2Sort)),
                                           (@str_ref_comp_np_synsem,
                                            loc:cont:ind:(SubjInd,
                                                          sort:Arg1Sort))])],
               cont:key:(arg1:SubjInd,
                         arg2:ObjInd))).


% Er helfe mir, das Problem zu lsen.
np_np_lex_v_obj_control_verb(Pred,Arg1Sort,Arg2Sort,Case,VerbSort-situation) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_verb,
   @sem_embed_arg3_verb,
   synsem:loc:(cat:subcat:[(@v_synsem(ObjInd),
                            loc:cat:subcat:Subcat)
                           |append(Subcat,[(@lex_ref_comp_np_synsem(Case),
                                            loc:cont:ind:(ObjInd,
                                                          sort:Arg2Sort)),
                                           (@str_ref_comp_np_synsem,
                                            loc:cont:ind:(SubjInd,
                                                          sort:Arg1Sort))])],
               cont:key:(arg1:SubjInd,
                         arg2:ObjInd))).


np_np_lex_v_obj_control_verb(Pred,Arg1Sort,Arg2Sort,Case-case_val,VerbSort-situation,Part-(a_ _)) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_part_verb,
   @sem_embed_arg3_part_verb,
   synsem:loc:(cat:subcat:[@particle_synsem(Part),
                           (@v_synsem(ObjInd),
                            loc:cat:subcat:Subcat)
                           |append(Subcat,[(@lex_ref_comp_np_synsem(Case),
                                            loc:cont:ind:(ObjInd,
                                                          sort:Arg2Sort)),
                                           (@str_ref_comp_np_synsem,
                                           loc:cont:ind:(SubjInd,
                                                          sort:Arg1Sort))])],
               cont:key:(arg1:SubjInd,
                         arg2:ObjInd))).

% Er verlangt von ihm, glcklich zu sein.
np_pp_v_obj_control_verb(Pred,Arg1Sort,Arg2Sort,PForm-pform,Case-case_val,VerbSort-situation) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_verb,
   @sem_embed_arg3_verb,
   synsem:loc:(cat:subcat:[(@v_synsem(ObjInd),
                            loc:cat:subcat:Subcat)
                           |append(Subcat,[(@ref_comp_pp_synsem(PForm,Case,Arg2Sort),
                                            loc:cont:ind:(ObjInd,
                                                          sort:Arg2Sort)),
                                           (@str_ref_comp_np_synsem,
                                            loc:cont:ind:(SubjInd,
                                                          sort:Arg1Sort))])],
               cont:key:(arg1:SubjInd,
                         arg2:ObjInd))).


np_pp_v_obj_control_verb(Pred,Arg1Sort,Arg2Sort,PForm-pform,Case-case_val,VerbSort-situation,Part-(a_ _)) :=
  (@verb(Pred,VerbSort,aktionsart),
   @haben_nerg_verb,
   @zu_inf_part_verb,
   @sem_embed_arg3_part_verb,
   synsem:loc:(cat:subcat:[@particle_synsem(Part),
                           (@v_synsem(ObjInd),
                            loc:cat:subcat:Subcat)
                           |append(Subcat,[(@ref_comp_pp_synsem(PForm,Case,Arg2Sort),
                                            loc:cont:ind:(ObjInd,
                                                          sort:Arg2Sort)),
                                           (@str_ref_comp_np_synsem,
                                           loc:cont:ind:(SubjInd,
                                                          sort:Arg1Sort))])],
               cont:key:(arg1:SubjInd,
                         arg2:ObjInd))).

% complement flip -  (should this be declared as constraint on inf_verb?)
% the incoherent construction is still missing
phase_verb(Pred-(a_ _)) :=
  (@verb(Pred,temp_sit,aktionsart),
   @haben_nerg_verb,
   @sem_embed_subj_raising_verb,
   synsem:loc:cat:subcat:[loc:cat:head:inf_verb|_]).


phase_verb(Pred-(a_ _),Part-(a_ _)) :=
  (@verb(Pred,temp_sit,aktionsart),
   @haben_nerg_verb,
   @sem_embed_subj_raising_part_verb,
   synsem:loc:cat:subcat:[@particle_synsem(Part),
                          loc:cat:head:inf_verb|_]).


wheather_verb(Pred-(a_ _)) :=
  (@haben_nerg_verb,
   @nscop_verb,
   synsem:loc:(cat:(head:pron:plus,
                    subcat:[@expl_pronoun_synsem]),
               cont:(ind:aktionsart:activity,
                     key:(event_pred_noarg_rel,
                          pred:Pred)))).



/*
np_np_pred_pp_verb(Pred,Arg1Sort,VerbSort) :=
  (@haben_nerg_verb,
   @arg123_pred
   synsem:loc:(cat:(subcat:[(@ref_comp_pp_synsem(als_pform,Case)),
                            (@str_ref_comp_np_synsem,
                             loc:cat:head:syn_case:Case),
                            @str_ref_comp_np_synsem]),
               cont:(arg123_rel,
                     arg1:

*/

coordination(CoordReln-coord_rel) :=
  (non_derived_word,
   @default_nonloc_lexical_sign,
   @overt_sign,
   @no_rel_lexical_sign,
   synsem:loc:(cat:(head:(coord,
                          extrap:minus,
                          spec:(loc:(cat:Cat,
                                     coord:minus),   % weder und noch oder :-\)
                                nonloc:NonLoc,
                                        %slash:[]),    % ? ATB
                                ellipsis:minus,
                                cat_change:minus,
                                trace:minus),
                          coordform:CoordReln),
                    subcat:[(loc:(cat:(Cat,
                                       head:dsl:none),      % this excludes spurious ambiguities
                                                            % [[eine Frau und ein Mann] t] vs. [[eine Frau t] und [ein Mann t]]
                                                            % but it also excludes the data of Tilman Hhle, he used as an
                                                            % argument for verb movement. But there was Andreas Kathol's
                                                            % argument against the Hhle data. Check

                                                            % Without the restriction and scrambling with del/3
                                                            % [[eine Frau t] und [ein Mann t]] loops. Why?

                                                            % With this restriction parsing is speed up by a factor of 5!
                                  cont:(ltop:LTop,
                                        ind:Ind,
                                        key:Key),
                                  coord:minus), 
                             nonloc:NonLoc,
                             ellipsis:minus,
                             cat_change:minus,
                             trace:minus)]),
               cont:(ltop:LTop,
                     ind:Ind,
                     key:Key),
               coord:CoordReln)).
                       


