% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: lexicon.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:19 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Contains types and macros used in phrase
%%             structure rules (rules.pl).
%%   Language: Trale
%      System: TRALE 2.3.7 under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Revision 1.2  2003/04/08 08:48:13  stefan
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile '~~>'/2.
:- multifile '--->'/2.


%%%%% pronouns
%%%%-----------------------------

% see comment in macro definition le_macros.pl
es ~~> @expl_pronoun(nom,bool).
es ~~> @expl_pronoun(acc,minus).

es ~~> @positional_es.

ich    ~~> @pers_pronoun(nom,       first, sg,gender,human,   std).
du     ~~> @pers_pronoun(nom,       second,sg,gender,agentive,std).
er     ~~> @pers_pronoun(nom,       third, sg,mas,   anything,std).
sie    ~~> @pers_pronoun(nom_or_acc,third, sg,fem,   anything,std).


% distinguishing the frontability of nominative and accusative es
% is not empirically justified:
% "Ihr Geld ist nicht weg: Es haben jetzt nur andere."
es     ~~> @pers_pronoun(nom_or_acc,third, sg,neu,   anything,std).

meiner ~~> @pers_pronoun(gen,first, sg,gender,    human,   std).
deiner ~~> @pers_pronoun(gen,second,sg,gender,    agentive,std).
seiner ~~> @pers_pronoun(gen,third, sg,mas_or_neu,anything,std).
ihrer  ~~> @pers_pronoun(gen,third, sg,fem,       anything,std).

mir    ~~> @pers_pronoun(dat,first, sg,gender,    human,   std).
dir    ~~> @pers_pronoun(dat,second,sg,gender,    agentive,std).
ihm    ~~> @pers_pronoun(dat,third, sg,mas_or_neu,anything,std).
ihr    ~~> @pers_pronoun(dat,third, sg,fem,       anything,std).

mich   ~~> @pers_pronoun(acc,first, sg,gender,    human,   vtype).  % refl and std
dich   ~~> @pers_pronoun(acc,second,sg,gender,    agentive,vtype).
ihn    ~~> @pers_pronoun(acc,third, sg,mas,       anything,std).

sich   ~~> @pers_pronoun(dat_or_acc,third, sg,gender,anything,vtype).

wir    ~~> @pers_pronoun(nom,       first, pl,gender,agentive,std).        % me and my dog
ihr    ~~> @pers_pronoun(nom,       second,pl,gender,agentive,std).
sie    ~~> @pers_pronoun(nom_or_acc,third, pl,gender,anything,std).

unserer  ~~> @pers_pronoun(gen,first, pl,gender,agentive,std).
eurer    ~~> @pers_pronoun(gen,second,pl,gender,agentive,std).
ihrer    ~~> @pers_pronoun(gen,third, pl,gender,anything,std).

uns      ~~> @pers_pronoun(dat_or_acc,first, pl,gender,agentive,vtype).
euch     ~~> @pers_pronoun(dat_or_acc,second,pl,gender,agentive,vtype).
ihnen    ~~> @pers_pronoun(dat,       third, pl,gender,anything,std).

man   ~~> @pers_pronoun(nom,third,sg,mas,human,std).


jemand    ~~> @flex_quantifier_np(jemand_rel, human,sg,mas).
niemand   ~~> @flex_quantifier_np(niemand_rel,human,sg,mas).


mein  ~~> @poss_pron(first,sg).
dein  ~~> @poss_pron(second,sg).
ihr   ~~> @poss_pron(third,sg,fem).
sein  ~~> @poss_pron(third,sg,mas_or_neu).

unser ~~> @poss_pron(first,pl).
euer  ~~> @poss_pron(second,pl).
ihr   ~~> @poss_pron(third,pl).


der    ~~> @rel_pron_np(nom,sg,mas).
dessen ~~> @rel_pron_np(gen,sg,mas_or_neu).
dem    ~~> @rel_pron_np(dat,sg,mas_or_neu).
den    ~~> @rel_pron_np(acc,sg,mas).

die    ~~> @rel_pron_np(nom_or_acc,sg,fem).
der    ~~> @rel_pron_np(gen_or_dat,sg,fem).

das    ~~> @rel_pron_np(nom_or_acc,sg,neu).

% plural forms are not morphologically specified for gender
% but agreement shows that there are inferences with semantics
%
die    ~~> @rel_pron_np(nom_or_acc,pl,_).
derer  ~~> @rel_pron_np(gen,pl,_).
denen  ~~> @rel_pron_np(dat,pl,_).

dessen ~~> @rel_pron_poss_p(sg,mas_or_neu).
deren  ~~> @rel_pron_poss_p(sg,fem).              % in Babel: fem, sg/pl + nonfem, pl
deren  ~~> @rel_pron_poss_p(pl,_).

wer    ~~> @rel_or_w_pron_np(nom,sg,mas,       agentive).
wessen ~~> @rel_or_w_pron_np(gen,sg,mas_or_neu).
wem    ~~> @rel_or_w_pron_np(dat,sg,mas_or_neu,agentive).
wen    ~~> @rel_or_w_pron_np(acc,sg,mas,       agentive).

was    ~~> @rel_or_w_pron_np(nom_or_acc,sg,mas_or_neu,non_agentive).   % except in pejorative uses, then also agentive


wo     ~~> @rel_pron_adv(a_ location).

%ob     ~~> @w_pron_adv(a_ ob).

wann   ~~> @w_pron_adv(a_ wann).
warum  ~~> @w_pron_adv(a_ warum).
wie    ~~> @w_pron_adv(a_ wie).
%wo     ~~> @w_pron_adv(a_ location).

%der ~~> @dem_pronoun(nom,       third, sg,mas,   anything,std).

%%%%% proper nouns
%%%%-----------------------------

john       ~~> @proper_noun_name((a_ john),human,mas,[]).

karl       ~~> @proper_noun_name((a_ karl),human,mas,[]).

maria      ~~> @proper_noun_name((a_ maria),human,fem,[]).

max        ~~> @proper_noun_name(a_ max,human,mas,[]).


hamburg    ~~> @proper_noun_name((a_ hamburg),geo_location,neu,[]).


%%%%% count nouns
%%%%-----------------------------

%noun_infl(UmlautStem,FK,GenE,DatE,EvorN,KUmw)

ansatz ~~>  @count_noun(a_ ansatz,abstract,mas,minus),
            @pl_stem(a_ anstz),
            @noun_flex_fk(nfk_e1),
            @noun_flex_gen_e(plus),
            @noun_flex_dat_e(minus),
            @noun_flex_kumw(minus).


aufsatz ~~>  @count_noun((a_ aufsatz),information_poly,mas,minus),
            @pl_stem(a_ aufstz),
            @noun_flex_fk(nfk_e1),
            @noun_flex_gen_e(plus),
            @noun_flex_dat_e(minus),
            @noun_flex_kumw(minus).


                                % zweiter Eintrag ntig:  Argument gegen ...
argument ~~> @cp_noun(a_ argument,abstract,neu,da,minus),
             @noun_flex_fk(nfk_e1),
             @noun_flex_gen_e(minus),
             @noun_flex_dat_e(minus).


            % Bildernomina, verlangen Determinator und Pr"apositionalphrase

bild   ~~>  @pp_noun(a_ bild,thing,von_pform,dat,anything,neu,minus),
            @noun_flex_fk(nfk_er),
            @noun_flex_gen_e(plus),
            @noun_flex_dat_e(minus).


buch ~~>    (@count_noun(a_ buch,information_poly,neu,minus),
             @noun_infl((a_ bch),nfk_er,plus,minus,_,minus)).

chef ~~>    (@count_noun((a_ chef),human,mas,minus),
             @noun_infl((a_ none),nfk_s1,bool,minus,_,minus)).

fisch    ~~> @mass_noun(a_ fleisch,food,mas),
             @noun_flex_fk(nfk_e1),
             @noun_flex_dat_e(minus).

fleisch ~~> (@mass_noun(a_ fleisch,food,neu),
             @noun_infl((a_ none),nfk_e1,bool,minus,_,minus)).

frau ~~>    (@count_noun((a_ frau),human,fem,minus),
             @noun_infl((a_ none),nfk_n5,plus,minus,plus,minus)).

freund ~~>  (@count_noun((a_ freund),human,mas,minus),
             @noun_infl((a_ none),nfk_e1,bool,minus,_,minus)).

general ~~> (@count_noun((a_ general),human,mas,minus),
             @noun_infl((a_ generl),nfk_e1,minus,minus,_,minus)).


gercht    ~~> @cp_noun(a_ gercht,abstract,neu,da,minus),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).

grammatiker ~~> (@count_noun((a_ grammatiker),human,mas,minus),
                 @noun_infl((a_ none),nfk_2,_,_,_,_)).

hauptmann   ~~> (@count_noun((a_ hauptmann),human,mas,minus),
                 @noun_infl((a_ hauptmnn),nfk_er,plus,minus,_,minus)).

haus ~~>    (@count_noun((a_ haus),nongeo_location,neu,minus),
             @noun_infl((a_ hus),nfk_er,plus,minus,_,minus)).

jacke   ~~> @count_noun((a_ jacke),thing,fem,minus),
            @noun_flex_fk(nfk_n5),
            @noun_flex_e_vor_n(minus).

jungeselle ~~> @count_noun((a_ junggeselle),human,mas,minus),
               @noun_flex_fk(nfk_n2),
               @noun_flex_e_vor_n(minus).

klte      ~~> @mass_noun(a_ klte,abstract,fem),
               @noun_flex_fk(nfk_n5),
               synsem:loc:cont:ind:num:sg.


kind       ~~> @count_noun(a_ kind,human,neu,minus),
               @noun_flex_fk(nfk_er),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(minus). % unspezifiziert falls dem Kinde gehen soll

kran       ~~> @count_noun(a_ mantel,thing,mas,minus),
               @pl_stem(a_ krn),
               @noun_flex_fk(nfk_e1),
               @noun_flex_dat_e(minus).

lehrling   ~~> @count_noun(a_ lehrling,human,mas,minus),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).

leutnant   ~~> @count_noun((a_ leutnant),human,mas,minus),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).

liter      ~~> @count_noun((a_ liter),unit,mas,minus),
               @noun_flex_fk(nfk_2).

lgner     ~~> @count_noun((a_ lgner),human,mas,minus),
               @noun_flex_fk(nfk_1).

manager    ~~> @count_noun(a_ manager,human,mas,minus),
               @noun_flex_fk(nfk_2).

mann       ~~> @count_noun((a_ mann),human,mas,minus),
               @pl_stem(a_ mnn),
               @noun_flex_fk(nfk_er),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(both).

mantel     ~~> @count_noun(a_ mantel,thing,mas,minus),
               @pl_stem(a_ mntel),
               @noun_flex_fk(nfk_1),
               @noun_flex_gen_e(minus).

material   ~~> @mass_noun(a_ material,thing,neu),
               @pl_stem(a_ materiali),
               @noun_flex_fk(nfk_n1),
               @noun_flex_e_vor_n(plus),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).

montag     ~~> @day_noun(a_ montag),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).
               

mrder     ~~> @count_noun((a_ mrder),human,mas,minus),
               @noun_flex_fk(nfk_2).


programm   ~~> @count_noun((a_ programm),information_poly,neu,minus),
               @noun_flex_fk(nfk_e1),
               @noun_flex_e_vor_n(plus),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(minus).

problem   ~~> @cp_noun(a_ problem,abstract,neu,da,minus),
              @noun_flex_fk(nfk_e1),
              @noun_flex_gen_e(plus),
              @noun_flex_dat_e(minus).

projekt   ~~> @count_noun((a_ projekt),abstract,neu,minus),
              @noun_flex_fk(nfk_e1),
              @noun_flex_dat_e(both). % TSNLP likes Projekte, so we admit it.

prfung   ~~> @count_noun((a_ prfung),action_sit,fem,minus),
              @noun_flex_fk(nfk_n5),
              @noun_flex_e_vor_n(plus).

sache     ~~> @count_noun(a_ sache,thing,fem,minus),
              @noun_flex_fk(nfk_n5),
              @noun_flex_e_vor_n(minus).

satz       ~~> @count_noun((a_ satz),information_poly,mas,minus),
               @pl_stem(a_ stz),
               @noun_flex_fk(nfk_e1),
               @noun_flex_e_vor_n(plus),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(minus).

student    ~~> @count_noun((a_ student),human,mas,minus),
               @noun_flex_fk(nfk_n2),
               @noun_flex_e_vor_n(plus).
%  LS:flex_m:dat_e   <=> i.

tag        ~~> @time_noun(a_ tag,mas),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).


tatsache   ~~> @cp_noun((a_ tatsache),info_content,fem,da,minus),
               @noun_flex_fk(nfk_n5),
               @noun_flex_e_vor_n(minus).

% Er hat (die) Verantwortung fr 300 Angestellte.
verantwortung ~~> @count_noun(a_ verantwortung,abstract,fem,plus),
                  @noun_flex_fk(nfk_n5),
                  @noun_flex_e_vor_n(plus).

% drop-det
% Da habe ich Vorlesung.
% *Ich habe in Vorlesung geschlafen. :-(
vorlesung ~~> @count_noun((a_ vorlesung),action_sit,fem,plus),
              @noun_flex_fk(nfk_n5),
              @noun_flex_e_vor_n(plus).

wagen     ~~> @count_noun((a_ wagen),vehicle,mas,minus),
              @noun_flex_fk(nfk_1),
              @noun_flex_gen_e(minus).

wand      ~~> @count_noun((a_ wand),thing,fem,minus),
              @pl_stem(a_ wnd),
              @noun_flex_fk(nfk_e3).

woche     ~~> @time_noun(a_ woche,fem),
              @noun_flex_fk(nfk_n5),
              @noun_flex_e_vor_n(minus).

zug       ~~> @count_noun(a_ zug,vehicle,mas,minus),
              @pl_stem(a_ zge),
              @noun_flex_fk(nfk_e1),
              @noun_flex_gen_e(plus),
              @noun_flex_dat_e(minus).

%%%%% determiner
%%%%-----------------------------

der ~~> @det(def_rel,nom,mas,sg,strong).
des ~~> @det(def_rel,gen,mas_or_neu,sg,strong).
dem ~~> @det(def_rel,dat,mas_or_neu,sg,strong).
den ~~> @det(def_rel,acc,mas,sg,strong).

die ~~> @det(def_rel,nom_or_acc,fem,sg,strong).
der ~~> @det(def_rel,gen_or_dat,fem,sg,strong).

das ~~> @det(def_rel,nom_or_acc,neu,sg,strong).

% plural forms are not morphologically specified for gender
% but agreement shows that there are inferences with semantics
%
die ~~> @det(def_rel,nom_or_acc,_,pl,strong).
der ~~> @det(def_rel,gen,_,pl,strong).
den ~~> @det(def_rel,dat,_,pl,strong).



derselbe  ~~> @det(def_rel,nom,mas,sg,strong).
desselben ~~> @det(def_rel,gen,mas_or_neu,sg,strong).
demselben ~~> @det(def_rel,dat,mas_or_neu,sg,strong).
denselben ~~> @det(def_rel,acc,mas,sg,strong).

dieselbe  ~~> @det(def_rel,nom_or_acc,fem,sg,strong).
derselben ~~> @det(def_rel,gen_or_dat,fem,sg,strong).

dasselbe  ~~> @det(def_rel,nom_or_acc,neu,sg,strong).

dieselben ~~> @det(def_rel,nom_or_acc,_,pl,strong).
derselben ~~> @det(def_rel,gen,_,pl,strong).
denselben ~~> @det(def_rel,dat,_,pl,strong).

derjenige  ~~> @det(def_rel,nom,mas,sg,strong).
desjenigen ~~> @det(def_rel,gen,mas_or_neu,sg,strong).
demjenigen ~~> @det(def_rel,dat,mas_or_neu,sg,strong).
denjenigen ~~> @det(def_rel,acc,mas,sg,strong).

diejenige  ~~> @det(def_rel,nom_or_acc,fem,sg,strong).
derjenigen ~~> @det(def_rel,gen_or_dat,fem,sg,strong).

dasjenige  ~~> @det(def_rel,nom_or_acc,neu,sg,strong).

diejenigen ~~> @det(def_rel,nom_or_acc,_,pl,strong).
derjenigen ~~> @det(def_rel,gen,_,pl,strong).
denjenigen ~~> @det(def_rel,dat,_,pl,strong).



% inflected determiners (macro has a different arity)

% alle/dies alten Projekte
all       ~~> @det(alle_rel).
dies      ~~> @det(dies_rel).
jed       ~~> @det(jeder_rel,sg).
jen       ~~> @det(jenes_rel).
manch     ~~> @det(manch_rel).

welch ~~> @det(wq_rel,strong).

% mixed declension
ein       ~~> @mixed_det(ein_rel,sg).
irgendein ~~> @mixed_det(irgendein_rel,sg).
kein      ~~> @mixed_det(kein_rel).



% einige alte Projekte
einig     ~~> @weak_det(einige_rel).     % meine Sekretrin drfte da einige Ahnung haben, einiges Gemse, einige Mnner
etlich    ~~> @weak_det(etlich_rel). 
mehrer    ~~> @weak_det(mehrere_rel,pl).
viel      ~~> @weak_det(viel_rel).


%%%%% adjective
%%%%-----------------------------

alt         ~~> @adjective((a_ alt),        anything).
dumm        ~~> @adjective((a_ dumm),       agentive).
frisch      ~~> @adjective(a_ frisch,       object).
glcklich   ~~> @adjective((a_ glcklich),  agentive).
grammatisch ~~> @adjective((a_ grammatisch),thing). 
gro        ~~> @adjective((a_ gro),       anything).
gut         ~~> @adjective(a_ gut,          anything).
intelligent ~~> @adjective((a_ intelligent),agentive).
klein       ~~> @adjective((a_ klein),      anything).
klug        ~~> @adjective((a_ klug),  agentive).
krank       ~~> @adjective((a_ krank), object).   % Baum
ledig       ~~> @adjective((a_ ledig), human).
leicht      ~~> @adjective((a_ leicht),anything).
nackt       ~~> @adjective((a_ nackt), agentive).
neu         ~~> @adjective((a_ neu),   anything).
roh         ~~> @adjective((a_ roh),   thing).    % not the metaphoric use
schlecht    ~~> @adjective((a_ schlecht),anything).
schn       ~~> @adjective((a_ schn),   anything).

spannend    ~~> @adjective(a_ spannend, anything).
stark       ~~> @adjective(a_ stark, anything).
stolz       ~~> @adjective(a_ stolz, human).    % stolzer Preis has a different meaning
warm        ~~> @adjective(a_ warm,  object).


offen      ~~> @adjective(a_ offen,object).     % der Patient, die Tr,   offen im Sinne von Einstellung
offen      ~~> @subjless_adjective(a_ offen).   % weil offen ist

schulfrei  ~~> @adjective(a_ schulfrei,time).                    % der Montag, die Ferien
schulfrei  ~~> @subjless_adjective(a_ schulfrei).

schlecht   ~~> @subjless_np_adjective(a_ schlecht,agentive).

warm       ~~> @non_ref_adjective(a_ warm). % weil es ihm hier zu warm ist.
warm       ~~> @subjless_np_adjective(a_ warm,agentive).

treu       ~~> @np_adjective((a_ treu),agentive,dat,anything).

stolz      ~~> @pp_adjective((a_ stolz),human,auf_pform,acc,anything).

nchst     ~~> @attr_adjective(a_ nchst,  anything).
morgig     ~~> @attr_adjective(a_ morgig,  temporal).        % Gesprch, Treffen, Tag
pleite     ~~> @prd_adjective(a_ pleite,  ilcp_human_poly).  % Berlin, Humboldt-Uni, Hans Eichel

angeblich    ~~> @scopal_adjective(a_ angeblich).
potentiell   ~~> @scopal_adjective(a_ potentiell).
vermeintlich ~~> @scopal_adjective(a_ vermeintlich).

%%% die beiden Tage -> ist ein Adjektiv
beid       ~~> (@attr_adjective(a_ beide,  anything),
                synsem:loc:cat:head:subj:[loc:cont:ind:num:pl]).

%%% unsere smtlichen Filialen
smtlich   ~~> @attr_adjective(a_ smtlich,  anything).

%%% ein solcher Vorschlag
solch      ~~> @attr_adjective(a_ solch,  anything).


%% adverbs
%--------------------------------


da      ~~> @pron_adv(a_ da,location).
                      
damals  ~~> @temp_adverb(a_ damals).

deshalb ~~> @pron_adv(a_ deshalb,anything).

dort    ~~> @pron_adv(a_ dort,location).

gestern ~~> @temp_adverb(a_ gestern).

heute   ~~> @temp_adverb(a_ heute).

hier    ~~> @pron_adv(a_ hier,location).

jetzt   ~~> @temp_adverb(a_ jetzt).

% grad particle
genug    ~~> @intersective_adverb_lex(a_ genug).

hier    ~~> @intersective_adverb_lex(a_ hier).

merkwrdigerweise ~~> @intersective_adverb_lex(a_ merkwrdigerweise).


morgen  ~~> @temp_adverb(a_ morgen).


mehrmals ~~> @scopal_adverb_lex(a_ mehrmals).

nicht    ~~> @negation_adverb(a_ nicht).

oft      ~~> @scopal_adverb_lex(a_ oft).

sofort   ~~> @temp_adverb(a_ sofort).


%% r pronouns (da, hier, wo)

da       ~~> @r_pronoun.

%% verbs
%--------------------------------

%anfangen
fang    ~~> @phase_verb(a_ anfangen,(a_ [a,n])),
            @pres2_stem(a_ fng),
 
            @past_stem(a_ fing),
            @part_stem(a_ fang),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%ankommen
komm    ~~> @intrans_erg_verb(a_ ankommen,object,situation,achievement,(a_ [a,n])),
 
            @past_stem(a_ kam),
            @conj_stem(a_ km),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


% does not cover "Das Holz arbeitet."
arbeit  ~~> (@intrans_nerg_verb(a_ arbeiten,agentive,haben,action_sit,activity)
            ;@np_pp_verb(a_ arbeiten,agentive,anything,an_pform,dat,action_sit,activity)
            ),
            @vflex_fk(v_weak),

            @vflex_ep(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%auffallen
fall    ~~> (@np_np_erg_verb(a_ auffallen,anything, agentive,    dat,situation,state,(a_ [a,u,f]))
            ;@cp_np_erg_verb(a_ auffallen,situation,agentive,da,dat,situation,(a_ [a,u,f]))
            ),
            @pres2_stem(a_ fll),
 
            @past_stem(a_ fiel),
            @part_stem(a_ fall),
 
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%aufhren
% Beispielphrase: weil ihm aufhoerte schlecht zu sein.
%
hr     ~~> @phase_verb(a_ aufhren,(a_ [a,u,f])),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%aufwachen
wach    ~~> @intrans_erg_verb(a_ aufwachen,agentive,situation,activity,(a_ [a,u,f])),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%ausbilden
            % goal = wozu
bild    ~~> @trans_verb(a_ ausbilden,agentive,anything,haben,situation,accomplishment,(a_ [a,u,s])),
            @vflex_fk(v_weak),
 
            @vflex_ep(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

blitz   ~~> @wheather_verb(a_ blitzen),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


begr  ~~> @trans_verb(a_ begren,agentive,anything,haben,situation,accomplishment),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).


behaupt ~~> (@np_v_subj_control_verb(a_ behaupten,human,communicat_sit)
            ;@np_cp_or_s_verb(a_ behaupten,human,da,communicat_sit)
            ),
            @vflex_fk(v_weak),
 
            @vflex_ep(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

bekomm  ~~> @dative_passive_aux_verb,
            @past_stem(a_ bekam),
            @part_stem(a_ bekomm),
            @conj_stem(a_ bekm),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

betrg  ~~> @trans_verb(a_ betrgen,human,agentive,haben,action_sit,dynamic),
            @past_stem(a_ betrog),
            @part_stem(a_ betrog),
            @conj_stem(a_ betrg),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).


befrder ~~> @trans_verb(a_ befrdern,human,human,haben,action_sit,achievement),
             @vflex_fk(v_weak),
 
             @vflex_ep(minus),
             @vflex_sm(minus),
             @vflex_pl_n(plus),
             @vflex_spe(minus),
             @vflex_tm(minus),
             @vflex_em(minus),
             @vflex_bet1(minus).

                                % subject-control in vm_verb_stamm

bevorzug ~~> @trans_verb(a_ bevorzugen,human,anything,haben,mental_sit,atelic),
             @vflex_fk(v_weak),
 
             @vflex_ep(minus),
             @vflex_sm(minus),
             @vflex_pl_n(minus),
             @vflex_spe(minus),
             @vflex_tm(minus),
             @vflex_em(minus),
             @vflex_bet1(minus).

%% busfahren
fahr      ~~> @sep_part_intrans_nerg_verb(a_ busfahren,agentive,sein,action_sit,activity,a_ [b,u,s]),
              @pres2_stem(a_ fhr),
              @past_stem(a_ fuhr),
              @part_stem(a_ fahr),
              
              @conj_stem(a_ fhr),
              @vflex_fk(v_strong),
 
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).



donner  ~~> @wheather_verb(a_ donnern),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(plus),
%            @vflex_spe(minus),
%            @vflex_tm(minus),
            @vflex_em(plus),
            @vflex_bet1(plus).

  
% * Es darf regnen. / Es drfte morgen nicht regnen.
% ja , mit Christi-Himmelfahrt duerfte es kein Problem geben .
drf    ~~> @modal_verb((a_ drfen_raising)),
            @pres2_stem(a_ darf),
 
            @past_stem(a_ durf),
            @part_stem(a_ durf),
            @conj_stem(a_ drf),

            @vflex_fk(modal),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


drst   ~~> @subjless_np_pp_verb(a_ drsten,agentive,anything,acc,nach_pform,dat,situation),
            @vflex_fk(v_weak),
 
            @vflex_ep(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

schlaf  ~~> @intrans_erg_verb(a_ einschlafen,agentive,situation,accomplishment,a_ [e,i,n]),
            @pres2_stem(a_ schlf),
            @past_stem(a_ schlief),
            
            @vflex_fk(v_strong),
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

ekel    ~~> @subjless_np_pp_verb(a_ ekeln,agentive,anything,acc,vor_pform,dat,situation),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(plus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

erhol   ~~> @intrans_refl_verb(a_ erholen,agentive,situation,accomplishment),
            @vflex_fk(v_weak),
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

erlaub    ~~> ( @np_v_subj_control_verb(a_ erlauben,human,communicat_sit)
              ; @np_np_v_subj_control_verb(a_ erlauben,human,agentive,dat,communicat_sit)
              ),
              @vflex_fk(v_weak),
              
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).

% Beispielphrase: Dass er gestorben ist, verdient, erwaehnt zu werden.
%
erwhn ~~> @np_cp_verb(a_ erwhnen,human,da,communicat_sit),
           @vflex_fk(v_weak),
 
           @vflex_ep(minus),
           @vflex_epp(plus),
           @vflex_sm(minus),
           @vflex_pl_n(minus),
           @vflex_em(minus),
           @vflex_bet1(minus).

ess     ~~> ( @intrans_nerg_verb(a_ essen,agentive,haben,action_sit,activity)
            ; @trans_verb(a_ essen,agentive,object,haben,action_sit,activity_or_accomplishment)
            ),
            @pres2_stem(a_ i),
 
            @past_stem(a_ a),
            @part_stem(a_ gess),
            @conj_stem(a_ ),
            @imp2_stem,
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


find    ~~> @obj_pred_verb((a_ finden),agentive,mental_sit),
            @past_stem(a_ fand),
            @part_stem(a_ fund),
            @conj_stem(a_ fnd),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(plus),
            @vflex_evp(plus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(plus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


frag    ~~> ( @np_int_verb(a_ fragen,human,communicat_sit)
            ; @np_np_int_verb(a_ fragen,human,agentive,communicat_sit)
            ),

            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).
  
freu    ~~> ( @intrans_refl_verb((a_ freu),agentive,mental_sit,state)
            ; @np_np_refl_pp_verb((a_ freu),agentive,anything,auf_ber_pform,acc,mental_sit) %,state)
            ),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

ftter  ~~> @trans_verb(a_ fttern,agentive,agentive,haben,situation,activity_or_accomplishment),
            @vflex_fk(v_weak),
            
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(plus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

geb     ~~> @ditrans_verb(a_ geben,agentive,anything,agentive,action_sit),
            @pres2_stem(a_ gib),
            @past_stem(a_ gab),
            @part_stem(a_ geb),
            @conj_stem(a_ gb),
            @imp2_stem,
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).
 
gedenk  ~~> @np_np_nerg_verb(a_ gedenken,human, anything, gen, mental_sit,state),
            @past_stem(a_ gedach),
            @part_stem(a_ gedach),
            
            @vflex_fk(v_weak),
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

gefall  ~~> (@np_np_erg_verb((a_ gefallen),anything, agentive,    dat,situation,state)
            ;@cp_np_erg_verb((a_ gefallen),situation,agentive,da,dat,situation)
            ),
            @pres2_stem((a_ gefll)),
 
            @past_stem((a_ gefiel)),
            @part_stem((a_ gefall)),
 
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

% an unspecified version: Peter geht, Montag geht gut. ...
geh     ~~> @intrans_nerg_verb(a_ gehen,anything,sein,situation,aktionsart),
            @past_stem(a_ ging),
            @part_stem(a_ gang),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

gehr   ~~> @np_np_nerg_verb(a_ gehren,anything, anything, dat, situation,state),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

  
genie  ~~> @trans_verb(a_ genieen,agentive,anything,haben,situation,durative),
            @past_stem(a_ geno),
            @part_stem(a_ genoss),
            @conj_stem(a_ gen),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

%%% Er glaubt zu trumen.
%%% Er glaubt, Peter liebt Maria / da Peter Maria liebt.
%%% Er glaubt diese Lgengeschichte.
%%% Er glaubt an eine friedliche Zukunft.
glaub   ~~> (@np_v_subj_control_verb(a_ glauben,human,mental_sit)
            ;@np_cp_or_s_verb(a_ glauben,human,da,mental_sit)
            ;@trans_verb(a_ glauben,human,anything,haben,mental_sit,state)
            ;@np_pp_verb(a_ glauben,human,anything,an_pform,acc,mental_sit,state)
            ),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

grau    ~~> @subjless_np_pp_verb(a_ grauen,human,anything,dat,vor_pform,dat,situation),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

% form fr habest fehlt noch in Morphologie
hab     ~~> @haben,
            @pres2_stem(a_ ha),
            @past_stem(a_ hat),
            @part_stem(a_ hab),
            @conj_stem(a_ ht),
            
            @vflex_fk(mixed),
            
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


halt    ~~> @trans_verb((a_ halten),human,space_time,haben,situation,durative),
            @pres2_stem(a_ hlt),
            @past_stem(a_ hielt),
            @part_stem(a_ halt),
            
            @conj_stem(a_ hielt), 

            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(plus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%%% Das Buch half ihr.
%%% Die Analysten helfen der Aktie. -> =:-(
%%% there should be two entries:  Mensch, Tablette hilft
%% hilft ihm auf die andere Strassenseite, in den Mantel ... ??
helf    ~~> ( @np_np_nerg_verb(a_ helfen,anything, anything, dat, situation,activity_or_accomplishment)
            ; @np_np_lex_v_obj_control_verb(a_ helfen,anything,agentive,dat,situation)
            ), 
            @pres2_stem(a_ hilf),
            @past_stem(a_ half),
            @part_stem(a_ holf),
            @conj_stem(a_ hlf),
            @imp2_stem,
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

hr     ~~> @aci_verb(a_ hren,agentive,situation),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%kartenspielen
spiel   ~~> @sep_part_intrans_nerg_verb((a_ kartenspielen),agentive,haben,action_sit,activity,a_ [k,a,r,t,e,n]),
            @vflex_fk(v_weak),

            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

kauf    ~~> ( @ditrans_verb(a_ kaufen,agentive,anything,agentive,action_sit)
            ; @trans_verb(a_ kaufen,agentive,anything,haben,action_sit,achievement)     % not quite right, better treatment of optional
            ),                                                                          % complements needed
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


                                % ??? * Der  Mann wird von mir gekannt.
kenn    ~~> @trans_verb(a_ kennen,agentive,anything,haben,mental_sit,state),
            @past_stem(a_ kann),
            @part_stem(a_ kann),
            
            @vflex_fk(mixed),
            
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

% Im VerbMobil mit raising-Lesart
% Das kann ganz lustig sein.
knn    ~~> @modal_verb(a_ knnen),
            @pres2_stem(a_ kann),
 
            @past_stem(a_ konn),
            @part_stem(a_ konn),
            @conj_stem(a_ knn),

            @vflex_fk(modal),
            
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

kritisier ~~> @trans_verb(a_ kritisieren,human,anything,haben,situation,activity),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
%            @vflex_spe(minus),
%            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).

kss    ~~> @trans_verb(a_ kssen,agentive,object,haben,action_sit,activity_or_semelfactive),
            @pres2_stem(a_ k),
            @past_stem(a_ k),
            @part_stem(a_ k),
            @conj_stem(a_ k),
            @imp2_stem,
            @vflex_fk(v_weak),

            @vflex_ep(minus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

lach    ~~> @intrans_nerg_verb((a_ lachen),agentive,haben,action_sit,activity_or_semelfactive),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

% one underspecified lexical entry for both causative and permissive reading

% Das Buch laesst mich nicht zur Ruhe kommen.
% Das Buch laesst Peter seine Theorie revidieren.

% Karl laesst den Mann den Wagen reparieren.
lass    ~~> ( @aci_verb(a_ lassen,anything,situation)
            ; @lassen_passive
            ),
            @pres2_stem(a_ l),

            @past_stem(a_ lie),
            @part_stem(a_ lass),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


les     ~~> (@trans_verb(a_ lesen,agentive,info_bearer,haben,action_sit,activity_or_accomplishment)
            ;@intrans_nerg_verb(a_ lesen,agentive,haben,action_sit,activity)
            ),
            @pres2_stem(a_ lies),

            @past_stem(a_ las),
            @part_stem(a_ les),
            @conj_stem(a_ ls),
            @imp2_stem,
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(plus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


lieb    ~~> @trans_verb(a_ lieben,agentive,anything,haben,situation,activity_or_state),
            @vflex_fk(v_weak),
            
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


ls     ~~> @trans_verb(a_ lsen,agentive,property,haben,situation,activity_or_accomplishment),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
%            @vflex_spe(minus),
%            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

  
mal     ~~> @trans_verb(a_ malen,agentive,entity,haben,action_sit,activity_or_accomplishment),
            @vflex_fk(v_weak),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


%%% Das Treffen mu ausfallen.
mss    ~~> @modal_verb((a_ mssen_raising)),
            @pres2_stem(a_ mu),
 
            @past_stem(a_ mu),
            @part_stem(a_ mu),
            
            @conj_stem(a_ mss),

            @vflex_fk(modal),
            
            @vflex_ep(minus),
            @vflex_sm(plus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%nachdenken
denk  ~~>  (@intrans_nerg_verb(a_ nachdenken,agentive,haben,situation,activity,(a_ [n,a,c,h]))
           ;@np_pp_verb(a_ nachdenken,agentive,anything,ber_pform,acc,situation,state,(a_ [n,a,c,h]))
           ),
           @past_stem(a_ dach),
           @part_stem(a_ dach),
  
           @vflex_fk(v_weak),
           @vflex_ep(minus),
           @vflex_sm(minus),
           @vflex_pl_n(minus),
           @vflex_spe(minus),
           @vflex_tm(minus),
           @vflex_em(minus),
           @vflex_bet1(plus).

nenn   ~~> @case_agreement_verb(a_ nennen,human,mental_sit),
           @past_stem(a_ nann),
           @part_stem(a_ nann),
           
           @vflex_fk(mixed),
           
           @vflex_ep(minus),
           @vflex_sm(minus),
           @vflex_pl_n(minus),
           @vflex_em(minus),
           @vflex_bet1(plus).

%% radfahren
fahr      ~~> @intrans_nerg_verb(a_ radfahren,agentive,sein,action_sit,activity,a_ [r,a,d]),
              @pres2_stem(a_ fhr),
              @past_stem(a_ fuhr),
              @part_stem(a_ fahr),
              
              @conj_stem(a_ fhr),
              @vflex_fk(v_strong),
 
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

rechn     ~~> @np_pp_verb(a_ rechnen_mit,agentive,anything,mit_pform,dat,mental_sit,state),
              @vflex_fk(v_weak),
 
              @vflex_ep(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

red       ~~> @intrans_nerg_verb(a_ reden,agentive,haben,communicat_sit,activity),
              @vflex_fk(v_weak),
             
              @vflex_ep(plus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).


regn      ~~> @wheather_verb(a_ regnen),
              @vflex_fk(v_weak),
 
              @vflex_ep(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

%%%% kann man Menschen/Tiere reparieren?
reparier  ~~> @trans_verb(a_ reparieren,agentive,thing,haben,action_sit,activity_or_accomplishment),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).

% Ich sage, er kommt nicht.
% Ich sage, da er kommt.
% Ich sage ihm, da er kommt.
% Ich sage das.
% Ich sage ihm das.

sag   ~~> (@np_cp_or_s_verb(a_ sagen,human,da,communicat_sit)
          ;@np_cp_or_s_np_verb(a_ sagen,human,human,da,communicat_sit)
          ;@trans_verb(a_ sagen,human,anything,haben,communicat_sit,activity_or_semelfactive)
          ;@ditrans_verb(a_ sagen,agentive,anything,agentive,communicat_sit)
          ),
          @vflex_fk(v_weak),

          @vflex_ep(minus),
          @vflex_sm(minus),
          @vflex_pl_n(minus),
          @vflex_spe(minus),
          @vflex_tm(minus),
          @vflex_em(minus),
          @vflex_bet1(plus).
          
schein    ~~> (@subj_raising_obl_coh_verb(a_ scheinen)
              ;@np_dat_subj_raising_verb(a_ scheinen,agentive)
              ),
              synsem:loc:cat:head:fin_verb,        % *Karl wird zu schlafen scheinen.
                                                   % *Karl hat zu schlafen geschienen.
              @past_stem(a_ schien),
 
              @vflex_fk(v_strong),
                
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

schenk    ~~> @ditrans_verb(a_ schenken,agentive,anything,agentive,action_sit),
              @vflex_fk(v_weak),

              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

schlaf    ~~> @intrans_nerg_verb(a_ schlafen,agentive,haben,situation,activity),
              @pres2_stem(a_ schlf),
              @past_stem(a_ schlief),

              @vflex_fk(v_strong),
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

%%% Karl schlgt den Ball ins Abseits.
%%% Das Knguruh schlgt die Frau.
schlag  ~~>   @trans_verb(a_ schlagen,agentive,object,haben,action_sit,activity_or_accomplishment),
              @pres2_stem(a_ schlg),
              @past_stem(a_ schlug),
              @part_stem(a_ schlag),
 
              @vflex_fk(v_strong),
 
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

schreib   ~~> (@trans_verb(a_ schreiben,human,info_content,haben,action_sit,activity_or_accomplishment)
              ;@np_pp_verb(a_ schreiben_an,  human,human,an_pform,acc,action_sit,activity)
              ;@np_pp_verb(a_ schreiben_ber,human,human,ber_pform,acc,action_sit,activity)
              ),
              @past_stem(a_ schrieb),
              @part_stem(a_ schrieb),
              
              @vflex_fk(v_strong),
              
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

seh       ~~> ( @trans_verb(a_ sehen,agentive,anything,haben,situation,state)
              ; @aci_verb(a_ sehen,agentive,situation)
              ),
              @pres2_stem(a_ sieh),

              @past_stem(a_ sah),
              @part_stem(a_ seh),
              
              @conj_stem(a_ sh),
              @imp2_stem,
              @vflex_fk(v_strong),
              
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

sing    ~~>   ( @intrans_nerg_verb(a_ singen,agentive,haben,situation,activity)
              ; @trans_verb(a_ singen,agentive,thing,haben,situation,activity_or_accomplishment)
              ),

              @past_stem(a_ sang),
              @part_stem(a_ sung),
              
              @conj_stem(a_ sng),
              
              @vflex_fk(v_strong),
              
              @vflex_ep(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
%              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).


soll    ~~> @modal_verb((a_ sollen_raising)),

            @vflex_fk(modal),
 
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).



sterb     ~~> @intrans_erg_verb(a_ sterben,agentive,situation,accomplishment),
              @pres2_stem(a_ stirb),
              @past_stem(a_ starb),
              @part_stem(a_ storb),
              
              @conj_stem(a_ strb),
              @imp2_stem,
              @vflex_fk(v_strong),
              
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).


sndig    ~~> @intrans_nerg_verb(a_ sndigen,human,haben,situation,activity),

              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

tanz      ~~> @intrans_nerg_verb(a_ tanzen,human,haben,action_sit,activity),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(plus),
              @vflex_pl_n(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

%umfrben
frb      ~~> @trans_verb(a_ umfrben,human,thing,haben,action_sit,activity_or_accomplishment,(a_ [u,m])),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

untersuch ~~> @trans_verb(a_ utersuchen,agentive,anything,haben,action_sit,activity_or_accomplishment),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).

veracht   ~~> @trans_verb(a_ verachten,human,object,haben,mental_sit,state),
              @vflex_fk(v_weak),
 
              @vflex_ep(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).

vernder  ~~> @trans_verb(a_ verndern,anything,anything,haben,situation,activity_or_accomplishment),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(plus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).

verlang   ~~> @np_pp_v_obj_control_verb(a_ verlangen,agentive,agentive,von_pform,dat,communicat_sit),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).
  
vermut    ~~> @np_cp_or_s_verb(a_ vermuten,human,da,mental_sit),
              @vflex_fk(v_weak),
 
              @vflex_ep(plus),
              @vflex_sm(plus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).


versprech ~~> ( @np_v_subj_control_verb(a_ versprechen,human,communicat_sit)
              ; @np_np_v_subj_control_verb(a_ versprechen,human,agentive,dat,communicat_sit)
              ),
              @pres2_stem(a_ versprich),

              @past_stem(a_ versprach),
              @part_stem(a_ versproch),
              
              @conj_stem(a_ versprch),
              @imp2_stem,
              @vflex_fk(v_strong),
              
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).


%%% Karl versucht wegzulaufen.
versuch   ~~> @np_v_subj_control_verb(a_ versuchen,human,situation),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(minus).



%vorziehen
zieh      ~~> ( @np_v_subj_control_verb(a_ vorziehen,human,situation,(a_ [v,o,r]))
              ; @np_cp_verb(a_ vorziehen,human,da,mental_sit,(a_ [v,o,r]))
              ),
              @past_stem(a_ zog),
              @part_stem(a_ zog),
              
              @conj_stem(a_ zg),
 
              @vflex_fk(v_strong),
              
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

wasch     ~~> @trans_verb(a_ waschen,human,object,haben,action_sit,activity_or_accomplishment),
              @pres2_stem(a_ wsch),

              @past_stem(a_ wusch),
    
              @conj_stem(a_ wsch),
 
              @vflex_fk(v_strong),
 
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

%% weglaufen
lauf      ~~> @intrans_erg_verb(a_ weglaufen,agentive,action_sit,accomplishment,a_ [w,e,g]),
              @pres2_stem(a_ luf),
              @past_stem(a_ lief),
              @part_stem(a_ lauf),
              
              @vflex_fk(v_strong),
 
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).


widersprech  ~~> @np_np_nerg_verb(a_ widersprechen,human, human, dat, situation,activity_or_accomplishment),
            @pres2_stem(a_ widersprich),
            @past_stem(a_ widersprach),
            @part_stem(a_ widersproch),
            @conj_stem(a_ widersprch),
            @imp2_stem,
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
%            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(minus).
  
wiss      ~~> ( @np_cp_or_s_verb(a_ wissen,agentive,da,mental_sit)
              ; @np_int_verb(a_ wissen,agentive,mental_sit)
              ),
              @pres2_stem(a_ wei),
              @past_stem(a_ wu),
              @part_stem(a_ wu),
              
              @conj_stem(a_ w), 

              @vflex_fk(modal),
 
              @vflex_ep(minus),
              @vflex_sm(plus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

woll    ~~> @modal_verb((a_ wollen_raising)),
            @pres2_stem(a_ will),
 
            @vflex_fk(modal),
            
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).
  
% Karl zwingt John, die Jacke umzufrben.
% Die Umstnde zwingen mich, unpopulre Manahmen zu ergreifen.
zwing     ~~> @np_np_v_obj_control_verb(a_ zwingen,anything,agentive,situation),
              @past_stem(a_ zwang),
              @part_stem(a_ zwung),
              
              @conj_stem(a_ zwng),
 
              @vflex_fk(v_strong),
              
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

% the future auxiliary does have only present tense finite forms,
% but the passive has all forms.
/*
werd      ~~> (@werden_fut
              ;@werden_pas
              ),
              @pres2_stem((a_ wir)),  % Problem wirt -> wird

% irregular should do this in the morph rules
%              @past_stem(a_ wurd),
%              @part_stem(a_ word),
              
              @conj_stem(a_ wrd),
              
              @vflex_fk(v_strong),
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(werden),
              @vflex_em(minus),
              @vflex_bet1(plus).
*/

% The templates for werden are defined so that all templates
% are called, i.e. werden_pas, werden_fut, and werden_kopula.
% If a certain form has just one function, it is specified exactly.
% Some of the templates have further restrictions. For instence
% the future auxilary does not have nonfinite or past forms.


werde    ~~> @werden(first,  sg, pres_ind_conj).
wirst    ~~> @werden(second, sg, pres_ind).
wird     ~~> @werden(third,  sg, pres_ind).

werden   ~~> @werden(first_or_third, pl, pres_ind_conj).
werdet   ~~> @werden(second,         pl, pres_ind_conj).

werde    ~~> @werden(third,          sg, pres_conj).  % first person listed above, reduces ambiguity
werdest  ~~> @werden(second,         sg, pres_conj).

wurde    ~~> @werden(first_or_third, sg, past_ind).
wurdest  ~~> @werden(second,         sg, past_ind).
wurden   ~~> @werden(first_or_third, pl, past_ind).
wurdet   ~~> @werden(second,         pl, past_ind).



wrde    ~~> @werden(first_or_third, sg, past_conj).
wrdest  ~~> @werden(second,         sg, past_conj).

werden   ~~> @werden(bse_verb).

worden   ~~> @werden_pas(ppp_verb).

geworden ~~> @werden_kopula(ppp_verb).



bin   ~~> @sein(first, sg, pres_ind).
bist  ~~> @sein(second,sg, pres_ind).
ist   ~~> @sein(third, sg, pres_ind).

sind  ~~> @sein(first_or_third, pl, pres_ind).
seid  ~~> @sein(second,         pl, pres_ind).

sei   ~~> @sein(first_or_third, sg, pres_conj).
seist ~~> @sein(second,         sg, pres_conj).

seien ~~> @sein(first_or_third, pl, pres_conj).
seiet ~~> @sein(second,         pl, pres_conj).

war   ~~> @sein(first_or_third, sg, past_ind).
warst ~~> @sein(second,         sg, past_ind).

waren ~~> @sein(first_or_third, pl, past_ind).
wart  ~~> @sein(second,         pl, past_ind).

wre   ~~> @sein(first_or_third, sg, past_conj).
wrest ~~> @sein(second,         sg, past_conj).

wren ~~> @sein(first_or_third, pl, past_conj).
wrt  ~~> @sein(second,         pl, past_conj).


gewesen  ~~> @sein(ppp_verb).

sein     ~~> @sein(bse_verb).



%% prepositions
%-------------------------------


an  ~~> @preposition(an_pform,dat_or_acc,anything).

an  ~~> @preposition(an_rel,dat,object).

am  ~~> @preposition_det(an_pform,dat,anything,mas_or_neu).

% am Montag, am Kuchen, am Hotel Ilm
am  ~~> @preposition_det(an_rel,dat,location_temporal_or_thing,mas_or_neu).


auf  ~~> @preposition(auf_pform,acc,anything).

auf  ~~> @preposition(auf_rel,dat,object).

% aus Hamburg, aus einem Stein, aus Luft, aus dem August
% aus klugen Leuten kann man viel herausholen
aus  ~~> @preposition(aus_rel,dat,anything).

bis  ~~> @preposition(bis_rel,acc,anything).

fr  ~~> @preposition(fr_pform,acc,anything).

% fr diesen Plan, seine Frau, den Garten
fr  ~~> @preposition(fr_rel,acc,anything).

frs ~~> @preposition_det(fr_pform,acc,anything,neu).

frs ~~> @preposition_det(fr_rel,acc,anything,neu).


in   ~~> @preposition(in_rel,dat,anything).

im  ~~> @preposition_det(in_pform,dat,anything,mas_or_neu).

% im Haus, im Treffen, im Plan, im Wissenschaftsbereich
im  ~~> @preposition_det(in_rel,dat,anything,mas_or_neu).


mit  ~~> @preposition(mit_pform,dat,anything).

nach ~~> @preposition(nach_pform,dat,anything).

ber ~~> @preposition(ber_pform,dat_or_acc,anything).

von  ~~> @preposition(von_pform,dat,anything).

von  ~~> @passive_preposition(dat).

vom  ~~> @preposition_det(von_pform,dat,anything,mas_or_neu).

vom  ~~> @passive_preposition_det(dat,mas_or_neu).

vor  ~~> @preposition(vor_pform,dat_or_acc,anything).

wegen ~~> @preposition(wegen_rel,gen_or_dat,anything).

wegen ~~> @postposition(wegen_rel,gen,anything).

zu   ~~> @preposition(zu_pform,dat,anything).

% die Platte zu diesem Buch
% Er fhrt zu Peter.
zu   ~~> @preposition(zu_rel,dat,anything).

zum  ~~> @preposition_det(zu_pform,dat,anything,mas_or_neu).

zum  ~~> @preposition_det(zu_rel,dat,anything,mas_or_neu).

zur  ~~> @preposition_det(zu_rel,dat,anything,fem).



%%%%% complementizer
%%%%-----------------------------

da  ~~> @complementizer(da).
dass ~~> @complementizer(da).


weil ~~> @complementizer(weil_rel).

ob   ~~> @w_complementizer.

%%%%% coordinations
%%%%-----------------------------

oder ~~> @coordination(oder_rel).

und  ~~> @coordination(und_rel).

entweder ~~> @coordination(entweder_oder_rel),
             synsem:nonloc:rel:[].

weder ~~> @coordination(weder_noch_rel),
          synsem:nonloc:rel:[].

noch  ~~> @coordination(weder_noch_rel),
          synsem:nonloc:rel:[].

sowohl ~~> @coordination(sowohl_als_auch_rel),
           synsem:nonloc:rel:[].

als_auch ~~> @coordination(sowohl_als_auch_rel),
             synsem:nonloc:rel:[].


%% verb movement
%-------------------------------

%empty @verb_movement_trace.
empty @verb_movement_trace_cyclic.


empty @extraction_trace.
empty @extraposition_trace.

