%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: lexrules.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:20 $
%%     Author: Stefan Mueller (Stefan.Mueller@uni-bremen.de)
%%    Purpose: This file contains the lexical rules of a TRALE grammar 
%%             which is an improved reimplemetation of the Babel grammar.
%%             See Mller (2002) for further documentation.
%%   Language: Trale
%      System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile '##'/2.
:- multifile macro/2.
:- multifile if/2.
:- multifile '*>'/2. 
:- multifile ':='/2.
:- multifile fun/1.
:- discontiguous '##'/2.
:- discontiguous ':='/2.
:- discontiguous if/2.
:- discontiguous lex_rule/2.
:- discontiguous fun/1.
        
%%% *************************************
%%%    Lexical Rules			 
%%% *************************************

:- lex_rule_depth(5).

lex_rule_infl_affixed(Dtr) :=
   (infl_word,
    synsem:trace:minus,     % could do some structure sharing into the stem, but ...
    zdtr:(stem,
         Dtr)).

lex_rule_infl_affixed_identical_synsem(Dtr) :=
  (@lex_rule_infl_affixed(Dtr),
   infl_word,
   synsem:Synsem,
   zdtr:synsem:Synsem). 

% this is copying material that is never changed in lexical rules
lex_rule_identical_never_changed(Dtr) :=
 (synsem:(loc:coord:Coord,
          trace:Trace),
  zdtr:(Dtr,
       synsem:(loc:coord:Coord,
               trace:Trace))).

lexical_rule_identical_subcat(Dtr) :=
 (synsem:loc:cat:subcat:Subcat,
  zdtr:(Dtr,
       synsem:loc:cat:subcat:Subcat)).

lex_rule_identical_nonloc(Dtr) :=
 (synsem:(nonloc:Nonloc,
          active_anchors:AA,
          inert_anchors:IA),
  zdtr:(Dtr,
       synsem:(nonloc:Nonloc,
               active_anchors:AA,
               inert_anchors:IA))).

lexical_rule_identical_cont(Dtr) :=
 (synsem:loc:cont:Cont,
  zdtr:(Dtr,
       synsem:loc:cont:Cont)).

lex_rule_identical_never_changed_and_nonloc(Dtr) :=
 (@lex_rule_identical_never_changed(Dtr),
  @lex_rule_identical_nonloc(Dtr)).

lex_rule_infl_affixed_identical_never_changed(Dtr) :=
 (@lex_rule_infl_affixed(Dtr),
  @lex_rule_identical_never_changed_and_nonloc(Dtr)).

lex_rule_identical_but_subcat_and_nonloc(Dtr) :=
 (@lex_rule_identical_never_changed(Dtr),
  synsem:(loc:(cat:(head:Head,
                    spr:Spr),
               cont:Cont),
          lex:Lex,
          phrase:Phrase),
  zdtr:(Dtr,
       synsem:(loc:(cat:(head:Head,
                         spr:Spr),
               cont:Cont),
          lex:Lex,
          phrase:Phrase))).

lex_rule_identical_but_subcat_and_slash(Dtr) :=
 (@lex_rule_identical_but_subcat_and_nonloc(Dtr),
  synsem:(nonloc:(que:Que,
                  rel:Rel,
                  active_extra:AExtra,
                  inert_extra:IExtra),
          active_anchors:AA,
          inert_anchors:IA),
  zdtr:synsem:(nonloc:(que:Que,
                      rel:Rel,
                      active_extra:AExtra,
                      inert_extra:IExtra),
              active_anchors:AA,
              inert_anchors:IA)).

lex_rule_identical_but_subcat_que_rel(Dtr) :=
 (@lex_rule_identical_but_subcat_and_nonloc(Dtr),
  synsem:(nonloc:(slash:Slash,
                  active_extra:AExtra,
                  inert_extra:IExtra),
          active_anchors:AA,
          inert_anchors:IA),
  zdtr:synsem:(nonloc:(slash:Slash,
                      active_extra:AExtra,
                      inert_extra:IExtra),
              active_anchors:AA,
              inert_anchors:IA)).

lex_rule_infl_affixed_identical_but_subcat_and_head(Dtr) :=
 (@lex_rule_infl_affixed_identical_never_changed(Dtr),
  synsem:(loc:(cat:spr:Spr,
               cont:Cont),
          lex:Lex,
          phrase:Phrase),
  zdtr:(Dtr,
       synsem:(loc:(cat:spr:Spr,
                    cont:Cont),
               lex:Lex,
               phrase:Phrase))).

lex_rule_identical_but_subcat(Dtr) :=
 (@lex_rule_identical_but_subcat_and_nonloc(Dtr),
  @lex_rule_identical_never_changed_and_nonloc(Dtr)).

lex_rule_infl_affixed_identical_but_subcat(Dtr) :=
 (@lex_rule_infl_affixed_identical_never_changed(Dtr),
  @lex_rule_identical_but_subcat(Dtr)).

lex_rule_infl_affixed_identical_but_head(Dtr) :=
 (@lex_rule_infl_affixed_identical_but_subcat_and_head(Dtr),
  synsem:loc:cat:subcat:Subcat,
  zdtr:(Dtr,
       synsem:loc:cat:subcat:Subcat)).


% Such rules apply to everything that does not have a particle
% that has to be written together with the verb. 
non_particle_lex_rule(Dtr) :=
  (zdtr:(Dtr,
        synsem:loc:cat:subcat:([] % this is the case for prenominal participles
                              ;[loc:cat:head:(@not(nsep_part))
%                              (sep_part;prd_adj_or_prd_prep;bse_or_ppp_verb;v_arg_head)
                              % declaring a type not_nsep_part is too much fuzz, I am sick of specifying mgu's
                              % I guess I have to redo everything under head once the grammar stabalized. 03.11.2003
                              
                              % did not work (=\= nsep_part), even with extensionality constraints
                              |_]
                              ))).


%%% maps stems to stems
lex_rule_deriv_affixed(Dtr) :=
   (stem,
    zdtr:(stem,
         Dtr)).

lex_rule_deriv_affixed_identical_never_changed(Dtr) :=
 (@lex_rule_deriv_affixed(Dtr),
  @lex_rule_identical_never_changed_and_nonloc(Dtr)).

%%% maps words to stems
%%% lachen -> lachend
lex_rule_deriv_word_affixed(Dtr) :=
   (stem,
    zdtr:(word,
         Dtr)).

lex_rule_deriv_word_affixed_identical_never_changed(Dtr) :=
 (@lex_rule_deriv_word_affixed(Dtr),
  @lex_rule_identical_never_changed_and_nonloc(Dtr)).

%%% maps words to words
%%% lachen -> lachend
%%% this is a shortcut that eliminates an additional zero inflection
lex_rule_deriv_word_word_affixed(Dtr) :=
   (word,
    zdtr:(word,
         Dtr)).

lex_rule_deriv_word_word_affixed_identical_never_changed(Dtr) :=
 (@lex_rule_deriv_word_word_affixed(Dtr),
  @lex_rule_identical_never_changed_and_nonloc(Dtr)).


%%% maps words to words
%%% nackt (predicative) -> nackt (depictive)

%%% currently the ARG1 argument is instantiated wrongly for prenominal participles:
%%% die nackt schlafende Frau
%%% the econt/icont destinction is needed, it has to be made for indices.

general_depictive_lr(Dtr) :=
 (@intersective_modifier,
  @general_non_aux_adverbial,
  @lexical_rule_identical_subcat(Dtr),
  synsem:loc:cont:(key:(Key,
                         pred:(a_ whrend),
                         arg2:Handle),
                   liszt:(list:[Key|AdjList],
                          last:Last)),
 zdtr:(Dtr,
      synsem:loc:cont:(key:lbl:Handle,
                       liszt:(list:AdjList,
                              last:Last)))).
lex_rule_depictive ##
(Dtr,
 word,
 synsem:loc:cat:head:(prd_adj,
                      subj:[loc:cont:ind:(ref_ind,
                                          Ind)] % da es warm regnet. = Regen ist warm, nicht whrend es regnet, ist es warm
                      ))
**>
(word,
 % weil er nackt nicht schlft. % scopal?
 @general_depictive_lr(Dtr),
 @lex_rule_deriv_word_word_affixed_identical_never_changed(Dtr),
 synsem:loc:cat:head:(adverbial_adj,
                      mod:loc:cat:(head:(subj:Subj,
                                         da:DA),
                                   subcat:Subcat)))
if
  % the antecedent can be in the blocked DA
  % das nackt zu putzende Fenster
  % in the SUBJ
  % der das Fenster nackt putzende Mann
  % or in SUBCAT
  % Er putzt das Fenster nackt.
  member(loc:cont:ind:Ind,check_identical_append(DA,Subj,Subcat))
morphs
  X becomes X.


noun_infl_lr ##
(@lexical_noun,
 infl:(umlaut:UmlautStem,
       affix:(Affix,
              noun_i_suffix,
              phon:[(a_ Suff)],
              num:Num,
              morph_case:Case)),
 Dtr)
**>
(@lexical_noun,
 @lex_rule_infl_affixed_identical_synsem(Dtr),
 synsem:loc:(cat:head:case:(morph_case:Case,
                            syn_case:Case               % this should be an independent copy of the morph case
                                                        % see also macros
                           ),
             cont:ind:num:Num))
if
  get_irreg_n_stem(Affix,UmlautStem,(a_ IStem))
morphs
  X becomes (X,Suff) when IStem = none,
  X becomes (IStem,Suff).


% sharing of declension class is done in the macros for lexical entries
% in cases like `ein' in which we have mixed declension the value from the suffix is ignored
det_infl_lr ##
(synsem:loc:cat:head:det,
 infl:affix:(det_i_suffix,
             phon:[(a_ Suff)],
             num:Num,
             gen:Gen,
%             dtype:DType,
             morph_case:Case),
 Dtr)
**>
(@lex_rule_infl_affixed_identical_synsem(Dtr),
 synsem:loc:cat:head:(num:Num,
                      gen:Gen,
%                      dtype:DType,
                      case:(morph_case:Case,
                            syn_case:Case               % this should be an independent copy of the morph case
                           )))
morphs
  X becomes (X,Suff).


% for determiners and quantifier NPs like 'niemand'
% normal nouns have noun_i_affixes and do not qualify for this rule
quant_infl_lr ##
(synsem:loc:cat:head:noun,
 infl:affix:(det_i_suffix,
             phon:[(a_ Suff)],
             num:Num,
             gen:Gen,
             morph_case:Case),
 Dtr)
**>
(@lex_rule_infl_affixed_identical_synsem(Dtr),
 synsem:loc:(cat:head:case:(morph_case:Case,
                            syn_case:Case             % this should be an independent copy of the morph case
                            ),
             cont:ind:(num:Num,
                       gen:Gen)))
morphs
  X becomes (X,Suff).



% Forms are usually underspecified in the lexicon.
% Whether the adjectives are used predicatively or attributively
% is determined by the lexical rules that are applied to them.
% In cases like `pleite' or `morgig' where either the attributive
% or the predicative form is missing, the lexical entries are
% made more specific, so that the lexical rules for predicative
% or attributive forms cannot apply.

% The partial copying may seem a bit weared but I want to specify
% the fact that an adjective is intersective in the stem entries.
% Therefore the handle identification of attributive adjectives
% is done in the stem entry. This means that lexical entries have
% a specified MOD value. This conflicts with pred_adj

prd_adj_infl_lr ##
(synsem:loc:cat:head:(adj,
                      subj:Subj),
 infl:affix:prd_adj_i_suffix,  % this affix does not contribute anything
                               % It's only there for uniformity and it is used
                               % in a hack to exclude predicative forms of participles
 Dtr)
**>
(@lex_rule_infl_affixed_identical_but_head(Dtr),
 synsem:loc:(cat:head:(prd_adj,
                       subj:Subj),
             cont:(ltop:LTop,
                   key:lbl:LTop)))
 
morphs
  X becomes X.


attr_adj_infl_lr ##
(synsem:loc:(cat:(head:(Head,
                        attr_adjectival,
                        subj:[loc:cont:(ltop:STop,
                                        ind:SInd,
                                        key:SKey)] % get the linking transfered to mod
                        ), % the LRs for participles add information about intersectiveness (handle identification)
                  subcat:Subcat),
             cont:Cont),
 infl:affix:(attr_adj_i_suffix,
             phon:[(a_ Suff)],
             dtype:DType,
             num:Num,
             gen:Gen,
             morph_case:Case),
 Dtr)
**>
(@lex_rule_infl_affixed_identical_never_changed(Dtr),
 @left_modifier,
 synsem:loc:(cat:(head:(Head,
                         mod:(@n_bar_(Case,SInd),
                              loc:(cat:spr:[loc:cat:head:dtype:DType],
                                  cont:(ltop:STop,
                                        ind:(SInd,
                                             per:third,
                                             num:Num,
                                             gen:Gen),
                                        key:SKey)))
                       ),
                  subcat:(Subcat,
                          list_of_non_move_synsems)),  % no movement from or relativization in the prenominal area
             cont:Cont)
 )
morphs
  X becomes (X,Suff).


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%% Participles

% There are two usages of the participle:
%
% die lachende Frau
% Die Frau lief lachend weg.
%
% Although the form `lachend' exists, it cannot be used predicatively:
%
% * Die Frau ist lachend.
%
% This should be explained on more principled grounds, e.g. by case theoretic considerations.
%
% Currently it is excluded by lexical stipulations: The lexical rules licence 'lachend' as adjectival
% stem that can only be used with an attributive affix, i.e. inflected with a non-zero ending.
% The lexical item that is used adverbially comes with a zero affix. To avoid having an unusable lexical item.
% The word is licensed directly from verb+d.
%

part_derivation_lr(Dtr) :=
(@non_particle_lex_rule(Dtr),
 @general_intersective_modifier,

 zdtr:(Dtr,
      synsem:loc:cat:head:nonfin_verb)).

part_derivation_attr_lr(Dtr) :=
 (@part_derivation_lr(Dtr),
  @lex_rule_deriv_word_affixed_identical_never_changed(Dtr),
  synsem:loc:cat:head:participle,
  infl:affix:attr_adj_i_suffix).                        % this is a hack to exclude predicative useage,
                                                         % should be done by case principles or something,
                                                         % see below


part_derivation_prd_lr(Dtr) :=
 (@part_derivation_lr(Dtr),
  @lex_rule_deriv_word_word_affixed_identical_never_changed(Dtr)).
%   infl:affix:prd_adj_i_suffix).

part_derivation_identical_cont_attr_lr(Dtr) :=
(@part_derivation_attr_lr(Dtr),
 @lexical_rule_identical_cont(Dtr)).




%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Participle I


% lachen -> lachend -> inflection
% die lachende Frau
bse_part_derivation_attr_lr ##
 (Dtr,
  synsem:loc:cat:(head:(bse_verb,
                        subj:[Subj]),
                  subcat:Subcat))
**>
(@part_derivation_identical_cont_attr_lr(Dtr),
 synsem:loc:cat:(head:(subj:[Subj],
                       % there is no possability to refer to or to deblock the DA of the verb
                       % * der ihn von ihm liebende Mann
                       da:[]),
                 subcat:Subcat))
morphs
  X becomes (X,d).

% lachen -> lachend
% Sie lief lachend weg.
%
% The following is similar to the depictive LR
bse_part_derivation_prd_lr ##
 (Dtr,
  synsem:loc:cat:(head:(bse_verb,
                        subj:[(Subj,
                               loc:cont:ind:( %ref_ind,  % excludes regnend
                                              Ind))]),
                  subcat:Subcat))
**>
(@part_derivation_prd_lr(Dtr),
 @general_depictive_lr(Dtr),
 synsem:loc:cat:(head:(adverbial_participle,
                       subj:[Subj],
                                % there is no possability to refer to or to deblock the DA of the verb
                                % * von ihm liebend
                       da:[],
                       mod:loc:cat:(head:(subj:ModVSubj,
                                          da:ModVDA),
                                    subcat:ModVSubcat)),
                 subcat:Subcat))
if
  % the antecedent can be in the blocked DA
  % das lachend zu putzende Fenster
  % in the SUBJ
  % der das Fenster lachend putzende Mann
  % or in SUBCAT
  % Er putzt das Fenster lachend.
  member(loc:cont:ind:Ind,check_identical_append(ModVDA,ModVSubj,ModVSubcat))
morphs
  X becomes (X,d).

% auszubilden -> auszubildende
inf_part_derivation_lr ##
 (Dtr,
  synsem:loc:(cat:(head:(inf_verb,
                         da:DA),
                   subcat:append(Subcat,[(Subj,@np_str)])),
              cont:(ind:Ind,
                    liszt:(list:Liszt,
                           last:LLast),
                    ltop:VTop,
                    h_cons:(list:HCons,
                            last:HLast))))
**>
(@part_derivation_attr_lr(Dtr),
 synsem:loc:(cat:(head:(subj:[Subj],
                        da:DA),
                  subcat:Subcat),
             cont:(ind:Ind,
                   key:Key,
                   liszt:(list:[(Key,
                                 modal_rel,
                                 arg1:Hand)|Liszt],
                          last:LLast),
                   h_cons:(list:[(qeq,
                                  sc_arg:Hand,
                                  outscpd:VTop)|HCons],
                           last:HLast))))
morphs
  X becomes (X,d).



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Participle II

% ausgebildet -> ausgebildete
ppp_part_derivation_lr ##
 (Dtr,
  synsem:loc:cat:(head:(ppp_verb,
                        da:DA
                       ),
                  subcat:append(Subcat,[(Subj,@np_str)])))
**>
(@part_derivation_identical_cont_attr_lr(Dtr),
  synsem:loc:cat:(head:(subj:[Subj],
                        da:DA
                       ),
                  subcat:Subcat))
morphs
  X becomes X.



/*
X becomes (Y,Suff) when (noun_suffix(Suff,(flex_m:FlexM,
                                           k_umw:(K_Umw,plus),
                                           num:Num,
                                           morph_case:Case)),
                         duplicate_last(X,Y)).
*/


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%
%%%  Verb Movement

% There is a problem with this being a lexical rule:
% To analyze: Er kennt und liebt diese Frau .
% this should be a syntactic rule, otherwise the semantics
% of the two different verbs is in the subcat list and
% coordination clashes.

general_verb_movement_lex_rule(Dtr) :=
 (@lex_rule_identical_never_changed_and_nonloc(Dtr),
  infl_word,
  synsem:(loc:(cat:(head:initial_fin_verb,
                    subcat:[(@saturated_synsem_unsp_dsl,
                             loc:(cat:head:(fin_verb, % this is in fact empty_final_fin_verb
                                            initial:minus,
                                % only this is compatible with a specified dsl value
                                % but since the constraints are related to empty_final_fin_verb
                                % it is better to not mention the full type here.
                                            
                                            vf:minus, % to prevent extraction of this complement
                                            extrap:minus,  
                                            dsl:Loc),
                                  cont:(ind:Ind,
                                        key:Key,
                                        ltop:Top))
% this would be the linguistically correct place to rule out
% spurious ambiguities. But then the empty verbal head licences tons of extraposition structures
% since all delayed constraints get unblocked                            
% Intead I require the head daughter in head_extra structures to be dsl:none. Head extra structures
% therefore contain the verb initial sentence, i.e. there is sufficient valence information.
%                            
%                             nonloc:(@no_extra)        % avoids spurious ambiguities.
                                                      % Extraposed constituents are combined with fully saturated verb movement trace.
                            )]),
               cont:(ind:Ind,
                     key:Key,
                     ltop:Top,
                     liszt:(@e_diff_list),
                     h_cons:(@e_diff_list))),
          v2:minus),
     zdtr:(Dtr,
          synsem:(loc:(Loc,
                       cat:head:(fin_verb_moveable,
                                 initial:minus)),
                  trace:minus))).

verb_initial_lr ##
(word,
% phon:[(a_ Phon)], %debugging
 Dtr)
**>
( @general_verb_movement_lex_rule(Dtr))
morphs
  X becomes X. % when ((write('v1:  '),write(Phon),nl)).


/*
% lexical rule for multiple constituents in the Vorfeld
% to demonstrate this lexical rule the extraction of
% parts of the predicate complex has to be enabled.
% (in general_head_cluster_phrase_speed remove the trace:minus specification)

mult_fronting_verb_movement_lr ##
(word,
 phon:[(a_ Phon)],  %debugging
 synsem:(loc:(Loc,
              cat:(head:(%nonfin_verb,     % for testing this is restricted to non-finite verbs
                         verb,
                         initial:Initial,
                         %initial:minus,   % would exclude particle verbs: [Vllig zur Kaffeesatzleserei -] artet es aus
                         vform:VForm
                        ),
                   subcat:(list %_of_non_complex_forming_synsems
                           %,[@np_str]  % for testing we restrict this to transitive verbs
                          )
                  )),
         nonloc:(rel:[],
                 slash:[],
                 @no_extra)),
 Dtr)
**>
( word,
  synsem:(loc:(cat:(head:(verb,                    % this would yield wrong DSL values:    Head,
                          initial:Initial,
                          vform:VForm),
                    subcat:Subcat),
               cont:(ind:Ind,
                     key:Key,
                     ltop:Top,
                     liszt:(@e_diff_list),
                     h_cons:(@e_diff_list))),
          nonloc:(rel:[],
                  slash:[(cat:(head:(extrap:minus,  
                                     dsl:Loc
                                    ),
                               subcat:Subcat),
                          cont:(ind:Ind,
                                key:Key,
                                ltop:Top))],
                  @no_extra),
          v2:minus),
  zdtr:Dtr)
morphs
  X becomes X when ((write('mult:'),write(Phon),nl)).

*/

% usually the initial verb lr maps a finite form that can
% occur sentence finally onto one that occurs sentence initially.
% however, with particle verbs the final form differs from the
% initial one due to orthographic conventions. In a syntactic
% analysis as suggested in Mller (2002) this would not be a problem,
% but in a computational system the orthographic facts have to
% be respected. So we have this rule in addition that takes a
% particle verb as input und licences an inflected initial form.


verb_initial_infl_lr ##
(synsem:loc:cat:subcat:[loc:cat:head:nsep_part|Subcat],
  infl:(v_stems:VStems,
        affix:(Affix,
               verb_i_suffix,
               phon:[(a_ AffixPhon)],
               per:Per,
               num:Num,
               temo:TeMo)),
 Dtr)
**>
( @general_verb_movement_lex_rule(Dtr),
  synsem:loc:cont:ind:temo:TeMo)
if (subj_verb_agreement(Subcat,Per,Num),
    get_irreg_v_stem(Affix,VStems,a_ IStem))
morphs
  X becomes (X,AffixPhon) when IStem = none,
  X becomes (IStem,AffixPhon).

%--------------

% because of the infl features traces are excluded.
% the DA value and the AUXF is not shared with the stem, it would break
% coordination at the sentece level and would cause complications
% with the determination of the antecedents of depictive predicates.
% The DA:[] definition is done in the signature.
fin_verb_infl_lr ##
( synsem:loc:cat:(head:verb, %(fin_verb_moveable,                        initial:minus),
                  subcat:Subcat),
  infl:(v_stems:VStems,
        affix:(Affix,
               verb_i_suffix,
               phon:[(a_ AffixPhon)],
               per:Per,
               num:Num,
               temo:TeMo)),
  Dtr) 
 **>
( infl_word,
  @lex_rule_infl_affixed_identical_but_head(Dtr),
  @non_particle_lex_rule(Dtr),
  synsem:loc:(cat:head:(fin_verb_moveable,                        
                        initial:minus,
                        da:[]
                        %dsl:none,
                       ),
              cont:ind:temo:TeMo)
  )
if (subj_verb_agreement(Subcat,Per,Num),
    get_irreg_v_stem(Affix,VStems,a_ IStem))
morphs
  X becomes (X,AffixPhon) when IStem = none,
  X becomes (IStem,AffixPhon).

%--------------


fin_verb_infl_particle_verb_lr ##
 (stem,
  infl:(v_stems:VStems,
        affix:(Affix,
               verb_i_suffix,
               phon:[(a_ Suff)],
               per:Per,
               num:Num,
               temo:TeMo)),
  synsem:loc:cat:subcat:[@particle_synsem(a_ Part)|Subcat]),
  Dtr
 **>
( infl_word,
  @lex_rule_infl_affixed_identical_but_subcat_and_head(Dtr),
  synsem:loc:(cat:(head:(fin_verb_nonmoveable, %    in the signature                    initial:minus, dsl:none),
                         da:[]),
                   subcat:Subcat),
              cont:ind:temo:TeMo
             )
  )
if (subj_verb_agreement(Subcat,Per,Num),
    get_irreg_v_stem(Affix,VStems,(a_ IStem)))
morphs
  X becomes (Part,X,Suff) when IStem = none,
  X becomes (Part,IStem,Suff).

general_ppp_infl_lex_rule(Dtr) :=
 (@lex_rule_infl_affixed(Dtr),
  @lex_rule_identical_never_changed_and_nonloc(Dtr),
  synsem:loc:(cat:head:(Head,
                        ppp_verb,
                        subj:DA,
                        flip:minus % except modal verbs, not covered yet
                       ),
              cont:Cont),
     zdtr:(Dtr,
          synsem:loc:(cat:head:(Head,
                                da:DA),
                      cont:Cont)
         )).

non_particle_ppp_infl_lex_rule(Dtr) :=
  (@general_ppp_infl_lex_rule(Dtr),
   @non_particle_lex_rule(Dtr),
   synsem:loc:cat:subcat:block_da(DA,Subcat),
   zdtr:synsem:loc:cat:(head:da:DA,
                       subcat:Subcat)).

ppp_verb_infl_lr ##
  (stem,
   infl:(v_stems:part:(a_ IStem),
         affix:(ppp_verb_i_suffix,
                phon:[(a_ Suff)]),
         bet1:Bet),
  Dtr)
  **>
(@non_particle_ppp_infl_lex_rule(Dtr))
if
   (get_prefix(Bet,Ge),
%       prolog(Ge=_-(a_ GeP)-bot)
    Ge=(a_ GeP)
)
morphs
  X becomes (GeP,X,Suff) when IStem = none,
  X becomes (GeP,IStem,Suff).

ppp_verb_infl_lr ##
  (stem,
   infl:(v_stems:part:(a_ IStem),
         affix:(ppp_verb_i_suffix,
                phon:[(a_ Suff)]),
         bet1:Bet),
   synsem:loc:cat:(head:da:DA,
                   subcat:[@particle_synsem(a_ Part)|Subcat]),
   Dtr)
  **>
(@general_ppp_infl_lex_rule(Dtr),
% phon:[(a_ Phon)],
 synsem:loc:cat:subcat:block_da(DA,Subcat))
if
   (get_prefix(Bet,Ge),
%       prolog(Ge=_-(a_ GeP)-bot)
    Ge=(a_ GeP)
   )
morphs
  X becomes (Part,GeP,X,Suff) when IStem = none,
  X becomes (Part,GeP,IStem,Suff).


general_bse_infl_lex_rule(Dtr) :=
 (@lex_rule_infl_affixed_identical_but_subcat(Dtr),
  synsem:loc:cat:(head:(bse_verb,
                        flip:minus % except modal verbs, not covered yet
                       ))).

non_particle_bse_infl_lex_rule(Dtr) :=
  (@general_bse_infl_lex_rule(Dtr),
   @non_particle_lex_rule(Dtr),
   synsem:loc:cat:(head:subj:Subj,
                   subcat:block_subject(Subcat,Subj)),
   zdtr:synsem:loc:cat:subcat:Subcat).

% zu-inf is done in syntax
bse_verb_infl_lr ##
  (stem,
  infl:affix:(phon:[(a_ Suff)],
              per:third,
              num:pl,
              temo:pres_ind),
  Dtr)
  **>
(@non_particle_bse_infl_lex_rule(Dtr)
 )
morphs
  X becomes (X,Suff).

bse_pv_verb_infl_lr ##
  (stem,
  infl:affix:(phon:[(a_ Suff)],
              per:third,
              num:pl,
              temo:pres_ind),
   synsem:loc:cat:subcat:[@particle_synsem(a_ Part)|Subcat],
  Dtr)
  **>
(@general_bse_infl_lex_rule(Dtr),
 synsem:loc:cat:(head:subj:Subj,
                 subcat:block_subject(Subcat,Subj)))
morphs
  X becomes (Part,X,Suff).

inf_pv_verb_infl_lr ##
  (stem,
%   infl:(%v_stems:VStems,
%         affix:(ppp_verb_i_suffix,
%                phon:[(a_ Suff)]),
%         bet1:Bet),
   synsem:loc:cat:subcat:[@particle_synsem(a_ Part)|Subcat],
  Dtr)
  **>
(@lex_rule_infl_affixed_identical_but_subcat(Dtr),
 synsem:loc:cat:(head:(inf_verb,
                       subj:Subj,
                       flip:minus % except modal verbs, not covered yet
                      ),
                  subcat:block_subject(Subcat,Subj)))
morphs
  X becomes (Part,zu,X,en).



possessive_lr ##
  (stem,
   infl:affix:fk:nfk_p,
   synsem:loc:cont:(key:named_rel,
                    ind:Ind,
                    liszt:(list:Liszt,
                           last:Last)),
   Dtr)
  **>
 (@lex_rule_infl_affixed_identical_never_changed(Dtr),
  @general_poss_det,
  synsem:loc:(cat:head:spec:nonloc:slash:[],    % NPs with propernames as determiners are extraction islands
              cont:(ind:Ind,
                    liszt:(list:[_,_|Liszt],
                           last:Last))))
morphs
  X becomes (X,s).

prep_stranding_lr ##
 (non_derived_word,
  synsem:loc:cat:(head:prep,
                  subcat:[loc:(cat:head:case:syn_case:dat_or_acc,
                               cont:ind:Ind)]),
  phon:hd:Phon,
  Dtr)
 **>
 (@lex_rule_identical_but_subcat_and_slash(Dtr),
  word,
  synsem:(loc:cat:subcat:[],
          nonloc:slash:[(cat:head:r_pron,
                         cont:ind:Ind)]))
if
  old_preposition(Phon)
morphs
  (V,X) becomes ([d,r],V,X) when vowel(V),
  X becomes X.

% Er schlft  darin.
% Er arbeitet daran.
% das Haus daneben

pron_adv_lr ##
 (non_derived_word,
  synsem:loc:cat:(head:prep,
                  subcat:[loc:cat:head:case:syn_case:dat_or_acc]),
  phon:hd:Phon,
  Dtr)
 **>
 (@lex_rule_identical_but_subcat(Dtr),
  word,
  synsem:loc:cat:subcat:[])
if
  old_preposition(Phon)
morphs
  (V,X) becomes ([d,a,r],V,X) when vowel(V),
  X becomes ([d,a],X).


% Ich wei, worin er schlft.
% Ich wei, woran er arbeitet.
% das, woran er arbeitet
% das, worin er schlft
wh_or_rel_pron_adv_lr ##
 (non_derived_word,
  synsem:loc:cat:(head:prep,
                  subcat:[loc:(cat:head:case:syn_case:dat_or_acc,
                               cont:ind:Ind)]),
  phon:hd:Phon,
  Dtr)
 **>
 (@lex_rule_identical_but_subcat_que_rel(Dtr),
  word,
  synsem:(loc:cat:subcat:[],
          nonloc:(que:[Ind],
                  rel:[]
                 ;que:[],
                  rel:[Ind]
                 )))
if
  old_preposition(Phon)
morphs
  (V,X) becomes ([w,o,r],V,X) when vowel(V),
  X becomes ([w,o],X).

%   Er glaubt daran, da ...
% * Er schlft darin, da
pron_adv_lr ##
 (non_derived_word,
  synsem:loc:cat:(head:comp_prep,
                  subcat:[loc:cat:head:case:syn_case:dat_or_acc]),
  phon:hd:Phon,
  Dtr)
 **>
 (@lex_rule_identical_but_subcat(Dtr),
  word,
  synsem:loc:(cat:subcat:[(@comp_cp_synsem(da),
                          loc:cont:ind:Ind,
                          nonloc:slash:[])],
              cont:ind:Ind))
if
  old_preposition(Phon)
morphs
  (V,X) becomes ([d,a,r],V,X) when vowel(V),
  X becomes ([d,a],X).

 
vowel([a]).
vowel([e]).
vowel([i]).
vowel([o]).
vowel([u]).
vowel([]).
% ...

old_preposition(a_ an) if true.
old_preposition(a_ auf) if true.
old_preposition(a_ aus) if true.
old_preposition(a_ bei) if true.
old_preposition(a_ durch) if true.
old_preposition(a_ fr) if true.
old_preposition(a_ gegen) if true.
old_preposition(a_ hinter) if true.
old_preposition(a_ in) if true.
old_preposition(a_ mit) if true.
old_preposition(a_ nach) if true.
old_preposition(a_ neben) if true.
old_preposition(a_ ber) if true.
old_preposition(a_ um) if true.
old_preposition(a_ von) if true.
old_preposition(a_ vor) if true.
old_preposition(a_ zu) if true.
old_preposition(a_ zwischen) if true.


get_prefix(plus, (a_ [g,e])) if true.
get_prefix(minus,(a_ [])   ) if true.


get_irreg_v_stem((Affix,
                  phon:Phon),VStems,IrregStem) if
  when(Phon=(e_list;ne_list)
       ,undelayed_get_irreg_v_stem(Affix,VStems,IrregStem)).


undelayed_get_irreg_v_stem((temo:pres_ind_conj),                (pres2:(a_ none)),     (a_ none    ))  if !,true.

% ich fange, du fngst, er fngt
% ich habe, du hast, er hat
undelayed_get_irreg_v_stem((fk:(v_strong;mixed;v_weak),
                            temo:pres_ind, per:second_or_third,num:sg),(pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.


undelayed_get_irreg_v_stem((fk:(v_strong;mixed;v_weak),
                            temo:pres_imp),                     (imp_st:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.

% Ich darf, du darfst, er darf, wir drfen, ihr drft, sie drfen
% the irregular stem in sg:
undelayed_get_irreg_v_stem((fk:modal,
                            temo:pres_ind,
                            num:sg),                            (pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.


undelayed_get_irreg_v_stem((temo:pres_conj,per:second_or_third,num:sg),_,     (a_ none    ))  if !,true.

% ich fange, ich habe
undelayed_get_irreg_v_stem((fk:(v_strong;mixed),
                            temo:pres_ind_conj,per:first,num:sg),      _,                     (a_ none    ))  if !,true.


% versuchtest
undelayed_get_irreg_v_stem((temo:past_ind_conj),                (past:(a_ none),
                                                                 conj:(a_ none)),      (a_ none    ))  if !,true.

% ich fing, ..., ich durfte, ...
undelayed_get_irreg_v_stem((temo:past_ind),                     (past:(a_ PastStem)),  (a_ PastStem))  if !,true.

% If a conj stem is definied, take it, otherwise return the past stem.
% kommen, kam, kme
% fangen, fing, finge
undelayed_get_irreg_v_stem((temo:past_conj),                    (conj:(a_ ConjStem)),  (a_ ConjStem))  if !,prolog(ConjStem\=none).
undelayed_get_irreg_v_stem((temo:past_conj),                    (past:(a_ ConjStem)),  (a_ ConjStem))  if !,prolog(ConjStem=none).


undelayed_get_irreg_v_stem(_,          _,                     (a_ none    ))  if true.



get_irreg_n_stem(num:pl,(a_ UmlautStem),  (a_ UmlautStem))  if !.
get_irreg_n_stem(_,_,_) if true.



duplicate_last([X],[X,X]) if
  consonant(X).

duplicate_last([X|Y],[X|Z]) if
  duplicate_last(Y,Z).

consonant(n).

fun block_da(+,+,-).
block_da((DA,
          list_of_non_complex_forming_synsems),           % speed
                                                          % for auxiliaries like `haben', we do not know what the DA is, but we know that
                                                          % it is not complex forming
                                                          % without this constraint the da_blocking would
                                                          % block the embedded ppp_verb (cyclic structure), only to find out
                                                          % later that the DA of the embedded ppp_verb differs from the ppp_verb
         Subcat,RedSubcat) if
  append(RedSubcat,DA,Subcat).

fun block_subject(+,-,+).
block_subject(Subcat,RestSubcat,Subj) if
   when( Subcat=(e_list;ne_list)
       , undelayed_block_subject(Subcat,RestSubcat,Subj)).


% this case does not arise, since all verbs have at least
% one element in their SUBCAT list. For raising verbs this is
% the embedded verb.
%undelayed_block_subject([],[],[]) if true.
% the list may contain only the embedded verb/verbal complex:
% da gelacht werden (drfen) kann


undelayed_block_subject([(SubjNP,
                          @np_str)],[],[SubjNP]) if true.
undelayed_block_subject([(Other,
                         @np_lex)],[Other],[]) if true.
% undelayed_block_subject([(Other,
%                          loc:cat:head:(@not(noun)))],[Other],[]) if true.

undelayed_block_subject([X|T1],[X|T2],Subj) if
  when( T1 = (e_list;ne_list)
      , ( (T1=e_list,
           T2=e_list,
           X=(loc:cat:head:(@not(noun))),
           Subj=e_list)
        ;
          block_subject(T1,T2,Subj))).









