%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: mini_lexicon.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:21 $
%%     Author: Stefan Mueller (Stefan.Mueller@uni-bremen.de)
%%    Purpose: Contains types and macros used in phrase
%%             structure rules (rules.pl).
%%   Language: Trale
%      System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% $Log: mini_lexicon.pl,v $
%% Revision 2.15  2004/05/04 16:31:21  stefan
%% added my-draw-hierarchy to the repository
%%
%% Revision 2.14  2004/03/26 10:34:31  stefan
%% enabled chart manipulation
%%
%% Revision 2.13  2004/03/25 20:08:02  stefan
%% fixed particples
%%
%% Revision 2.12  2004/03/25 19:46:35  stefan
%% disabled chart manipulation for testing
%%
%% Revision 2.11  2004/03/25 17:13:13  stefan
%% added participle rule, reorganization of types under head, chart manipulation code
%%
%% Revision 2.10  2004/03/23 13:59:34  stefan
%% excluded spurious ambiguities in coordination structures, fixed extraposition
%%
%% Revision 2.9  2004/03/22 21:18:27  stefan
%% clause boundedness of extraposition, introduction of new types
%%
%% Revision 2.8  2004/03/12 12:17:04  stefan
%% fixed particle verbs
%%
%% Revision 2.7  2004/03/11 22:51:20  stefan
%% total redesign of types under phrase, fixed depictives and bare infinitives
%%
%% Revision 2.6  2004/03/11 12:49:55  stefan
%% various speed improvements changed dalaying of extra constraint significant improvement
%%
%% Revision 2.5  2004/03/10 23:18:02  stefan
%% fixed delay
%%
%% Revision 2.4  2004/03/10 23:01:56  stefan
%% fixed conditional append for depictives, fixed DA for participles 'nackt schlafende'
%%
%% Revision 2.3  2004/03/10 15:02:22  stefan
%% fixed que in free relative clauses
%%
%% Revision 2.2  2004/03/05 21:29:40  stefan
%% fixed participle lexrule
%%
%% Revision 2.1  2004/03/04 12:22:38  stefan
%% difference lists for liszt and h_cons
%%
%% Revision 2.0  2004/02/29 16:17:34  stefan
%% first public release
%%
%% Revision 1.49  2004/02/23 18:28:35  stefan
%% fixed anchor introduction for irregular verbs, fixed extraposition from verbal clusters
%%
%% Revision 1.48  2004/02/23 16:07:14  stefan
%% fixed complement extraposition, posessive of proper nouns, fixed spurious ambiguity problem with Berthold's analysis, fixed quantifier-np issue
%%
%% Revision 1.47  2004/02/22 21:17:06  stefan
%% complete revision of adjunct extraposition
%%
%% Revision 1.46  2004/02/22 17:36:22  stefan
%% fixed extraposition of negation, and introduction of extraposition traces
%%
%% Revision 1.45  2004/02/21 15:47:35  stefan
%% various extensions and fixes
%%
%% Revision 1.44  2004/02/20 17:12:49  stefan
%% fixed determiner inflection
%%
%% Revision 1.43  2004/02/20 13:56:00  stefan
%% fixed determiner inflection
%%
%% Revision 1.42  2004/02/20 10:50:13  stefan
%% fixed determiner inflection
%%
%% Revision 1.41  2004/02/20 10:37:47  stefan
%% fixed determiner inflection
%%
%% Revision 1.40  2004/02/19 16:32:24  stefan
%% avoided spurious ambiguity with PVP and extraposition
%%
%% Revision 1.39  2004/02/18 20:13:05  stefan
%% fixed inflection, QUE percolation, coherent constructions with object control verbs
%%
%% Revision 1.38  2004/02/18 17:43:14  stefan
%% fixed 'zu' for infinitives
%%
%% Revision 1.37  2004/02/18 16:11:57  stefan
%% implemented pronominal adverbs + sentential arguments and Berthold Crysmann's treatement of ambiguity prevention in extraposition structures
%%
%% Revision 1.36  2004/02/16 23:04:36  stefan
%% computed s_subcat for verbal complexes
%%
%% Revision 1.35  2004/02/16 11:12:20  stefan
%% introduced max_ feature to avoid the unblocking of the delayed constraint del
%%
%% Revision 1.34  2004/02/15 11:38:59  stefan
%% fixed bug with extraposition in incoherent constructions
%%
%% Revision 1.33  2004/02/14 17:40:41  stefan
%% added imperative inflection, simplified type hierarchies, modification reading for day_nouns
%%
%% Revision 1.32  2004/02/13 15:26:27  stefan
%% added aktionsarten, excluded some impossible passives
%%
%% Revision 1.31  2004/02/12 19:53:45  stefan
%% fixed block_subject, fixed DA for participles and lexical rules, intersective_modifiers
%%
%% Revision 1.30  2004/02/11 12:40:25  stefan
%% fixed inflection bug, fixed bug in block-subject
%%
%% Revision 1.29  2004/02/06 22:49:56  stefan
%% fixed inflection bug, total reorganization of signature under head, time-mod-nouns
%%
%% Revision 1.28  2004/02/06 12:44:53  stefan
%% changed subject verb agreement, fixed modal inflection, w-clauses should work
%%
%% Revision 1.27  2004/02/05 11:41:56  stefan
%% fixed QUE percolation
%%
%% Revision 1.26  2004/02/04 20:49:21  stefan
%% short type fix
%%
%% Revision 1.25  2004/02/04 20:44:21  stefan
%% one more fix for the genitive rule
%%
%% Revision 1.24  2004/02/03 19:04:28  stefan
%% added lexical entries, relativization with adverbs, fixed genitive rule
%%
%% Revision 1.23  2004/02/02 11:13:11  stefan
%% removed restrictions since they were blocked in most cases by delay mechanism, introduced special list for counting (s_subcat)
%%
%% Revision 1.22  2004/01/30 20:43:13  stefan
%% restricted the number of arguments in clauses with V1 and predicate complex
%%
%% Revision 1.21  2004/01/29 16:16:13  stefan
%% fixed extraposition with v-last sentences, lexical items
%%
%% Revision 1.20  2004/01/28 18:33:51  stefan
%% fixed adjunct attachment in verbal complexes + PVP
%%
%% Revision 1.19  2004/01/27 20:21:47  stefan
%% cleaned type hierarchy, made adverb attachment less ambiguos
%%
%% Revision 1.18  2004/01/27 19:21:56  stefan
%% depictives
%%
%% Revision 1.17  2004/01/25 20:25:02  stefan
%% reorganized introduction of nonlocal dependencies
%%
%% Revision 1.16  2004/01/24 15:38:16  stefan
%% fixed spurious ambiguities
%%
%% Revision 1.15  2004/01/24 14:33:30  stefan
%% (complement) extraposition
%%
%% Revision 1.14  2004/01/23 20:26:53  stefan
%% fixed n-bar
%%
%% Revision 1.13  2004/01/23 16:31:52  stefan
%% various changes see log
%%
%% Revision 1.12  2004/01/22 23:51:51  stefan
%% treatment for spurious ambiguities with intersective noun modifers
%%
%% Revision 1.11  2004/01/20 21:10:14  stefan
%% empty-noun rule
%%
%% Revision 1.10  2004/01/20 18:32:18  stefan
%% now we use the cyclic trace ...
%%
%% Revision 1.6  2003/11/04 16:41:03  stefan
%% fixed complemention with saturated verbal complexes, fixed past_conj inflection
%%
%% Revision 1.5  2003/11/03 21:37:55  stefan
%% fixed coordination and spurious ambiguities
%%
%% Revision 1.4  2003/11/03 15:10:18  stefan
%% fixed structural case of adjective subjects, fixed trace information for inflected elements
%%
%% Revision 1.3  2003/11/03 13:42:19  stefan
%% fix in lexical rule for participles, fix verbs with lexical cas object (helfen)
%%
%% Revision 1.2  2003/11/03 11:59:16  stefan
%% fix in lexical rule that introduced spurious ambiguities, fix in coherent constr. with zu-inf
%%
%% Revision 1.1  2003/11/02 20:15:59  stefan
%% got rid ov XCOMP
%%
%% Revision 1.0  2003/11/01 17:35:40  stefan
%% switched after confusion, fixed trace stuff
%%
%% Revision 1.8.2.1  2003/11/01 17:21:34  stefan
%% fixed attachment sites
%%
%% Revision 1.8  2003/10/23 09:01:13  stefan
%% Back to append again
%%
%% Revision 1.6  2003/10/21 19:37:56  stefan
%% Version after Introduction of Traces
%%
%% Revision 1.2  2003/04/08 08:48:13  stefan
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%


:- multifile '~~>'/2.
:- multifile '--->'/2.


%%%%% pronouns
%%%%-----------------------------

% see comment in macro definition le_macros.pl
es ~~> @expl_pronoun(nom,bool).
es ~~> @expl_pronoun(acc,minus).

es ~~> @positional_es.

ich    ~~> @pers_pronoun(nom,       first, sg,gender,human,   std).
du     ~~> @pers_pronoun(nom,       second,sg,gender,agentive,std).
er     ~~> @pers_pronoun(nom,       third, sg,mas,   anything,std).
sie    ~~> @pers_pronoun(nom_or_acc,third, sg,fem,   anything,std).

% distinguishing the frontability of nominative and accusative es
% is not empirically justified:
% "Ihr Geld ist nicht weg: Es haben jetzt nur andere."
es     ~~> @pers_pronoun(nom_or_acc,third, sg,neu,   anything,std).

meiner ~~> @pers_pronoun(gen,first, sg,gender,    human,   std).
deiner ~~> @pers_pronoun(gen,second,sg,gender,    agentive,std).
seiner ~~> @pers_pronoun(gen,third, sg,mas_or_neu,anything,std).
ihrer  ~~> @pers_pronoun(gen,third, sg,fem,       anything,std).

mir    ~~> @pers_pronoun(dat,first, sg,gender,    human,   std).
dir    ~~> @pers_pronoun(dat,second,sg,gender,    agentive,std).
ihm    ~~> @pers_pronoun(dat,third, sg,mas_or_neu,anything,std).
ihr    ~~> @pers_pronoun(dat,third, sg,fem,       anything,std).

mich   ~~> @pers_pronoun(acc,first, sg,gender,    human,   vtype).  % refl and std
dich   ~~> @pers_pronoun(acc,second,sg,gender,    agentive,vtype).
ihn    ~~> @pers_pronoun(acc,third, sg,mas_or_neu,anything,std).

sich   ~~> @pers_pronoun(dat_or_acc,third, sg,gender,anything,vtype).

wir    ~~> @pers_pronoun(nom,       first, pl,gender,agentive,std).        % me and my dog
ihr    ~~> @pers_pronoun(nom,       second,pl,gender,agentive,std).
sie    ~~> @pers_pronoun(nom_or_acc,third, pl,gender,anything,std).

unserer  ~~> @pers_pronoun(gen,first, pl,gender,agentive,std).
eurer    ~~> @pers_pronoun(gen,second,pl,gender,agentive,std).
ihrer    ~~> @pers_pronoun(gen,third, pl,gender,anything,std).

uns      ~~> @pers_pronoun(dat_or_acc,first, pl,gender,agentive,vtype).
euch     ~~> @pers_pronoun(dat_or_acc,second,pl,gender,agentive,vtype).
ihnen    ~~> @pers_pronoun(dat,       third, pl,gender,anything,std).


mein  ~~> @poss_pron(first,sg).
dein  ~~> @poss_pron(second,sg).
ihr   ~~> @poss_pron(third,sg,fem).
sein  ~~> @poss_pron(third,sg,mas_or_neu).

unser ~~> @poss_pron(first,pl).
euer  ~~> @poss_pron(second,pl).
ihr   ~~> @poss_pron(third,pl).


der    ~~> @rel_pron_np(nom,sg,mas).
dessen ~~> @rel_pron_np(gen,sg,mas_or_neu).
dem    ~~> @rel_pron_np(dat,sg,mas_or_neu).
den    ~~> @rel_pron_np(acc,sg,mas).

die    ~~> @rel_pron_np(nom_or_acc,sg,fem).
der    ~~> @rel_pron_np(gen_or_dat,sg,fem).

das    ~~> @rel_pron_np(nom_or_acc,sg,neu).

% plural forms are not morphologically specified for gender
% but agreement shows that there are inferences with semantics
%
die    ~~> @rel_pron_np(nom_or_acc,pl,_).
derer  ~~> @rel_pron_np(gen,pl,_).
denen  ~~> @rel_pron_np(dat,pl,_).

dessen ~~> @rel_pron_poss_p(sg,mas_or_neu).
deren  ~~> @rel_pron_poss_p(sg,fem).              % in Babel: fem, sg/pl + nonfem, pl
deren  ~~> @rel_pron_poss_p(pl,_).

wer    ~~> @rel_or_w_pron_np(nom,sg,mas,       agentive).
wessen ~~> @rel_or_w_pron_np(gen,sg,mas_or_neu).
wem    ~~> @rel_or_w_pron_np(dat,sg,mas_or_neu,agentive).
wen    ~~> @rel_or_w_pron_np(acc,sg,mas,       agentive).

was    ~~> @rel_or_w_pron_np(nom_or_acc,sg,mas_or_neu,non_agentive).   % except in pejorative uses, then also agentive


%%%%% proper nouns
%%%%-----------------------------

john       ~~> @proper_noun_name((a_ john),human,mas,[]).

karl       ~~> @proper_noun_name((a_ karl),human,mas,[]).

maria      ~~> @proper_noun_name((a_ maria),human,fem,[]).

max        ~~> @proper_noun_name(a_ max,human,mas,[]).


hamburg    ~~> @proper_noun_name((a_ hamburg),geo_location,neu,[]).


%%%%% count nouns
%%%%-----------------------------

%noun_infl(UmlautStem,FK,GenE,DatE,EvorN,KUmw)

ansatz ~~>  @count_noun((a_ ansatz),abstract,mas,minus),
            @pl_stem(a_ anstz),
            @noun_flex_fk(nfk_e1),
            @noun_flex_gen_e(plus),
            @noun_flex_dat_e(minus),
            @noun_flex_kumw(minus).


                                % zweiter Eintrag ntig:  Argument gegen ...
argument ~~> @cp_noun(a_ argument,abstract,neu,da,minus),
             @noun_flex_fk(nfk_e1),
             @noun_flex_gen_e(minus),
             @noun_flex_dat_e(minus).


            % Bildernomina, verlangen Determinator und Pr"apositionalphrase

bild   ~~>  @pp_noun(a_ bild,thing,von_pform,dat,anything,neu,minus),
            @noun_flex_fk(nfk_er),
            @noun_flex_gen_e(plus),
            @noun_flex_dat_e(minus).


buch ~~>    (@count_noun((a_ buch),information_poly,neu,minus),
             @noun_infl((a_ bch),nfk_er,plus,minus,_,minus)).

chef ~~>    (@count_noun((a_ chef),human,mas,minus),
             @noun_infl((a_ none),nfk_s1,bool,minus,_,minus)).

fleisch ~~> (@count_noun((a_ fleisch),food,neu,minus),
             @noun_infl((a_ none),nfk_e1,bool,minus,_,minus)).

frau ~~>    (@count_noun((a_ frau),human,fem,minus),
             @noun_infl((a_ none),nfk_n5,plus,minus,plus,minus)).

freund ~~>  (@count_noun((a_ freund),human,mas,minus),
             @noun_infl((a_ none),nfk_e1,bool,minus,_,minus)).

general ~~> (@count_noun((a_ general),human,mas,minus),
             @noun_infl((a_ generl),nfk_e1,minus,minus,_,minus)).

grammatiker ~~> (@count_noun((a_ grammatiker),human,mas,minus),
                 @noun_infl((a_ none),nfk_2,_,_,_,_)).

hauptmann   ~~> (@count_noun((a_ hauptmann),human,mas,minus),
                 @noun_infl((a_ hauptmnn),nfk_er,plus,minus,_,minus)).

haus ~~>    (@count_noun((a_ haus),nongeo_location,neu,minus),
             @noun_infl((a_ hus),nfk_er,plus,minus,_,minus)).

jacke   ~~> @count_noun((a_ jacke),thing,fem,minus),
            @noun_flex_fk(nfk_n5),
            @noun_flex_e_vor_n(minus).

jungeselle ~~> @count_noun((a_ junggeselle),human,mas,minus),
               @noun_flex_fk(nfk_n2),
               @noun_flex_e_vor_n(minus).

kind       ~~> @count_noun((a_ kind),human,neu,minus),
               @noun_flex_fk(nfk_er),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(minus). % unspezifiziert falls dem Kinde gehen soll

lehrling   ~~> @count_noun((a_ lehrling),human,mas,minus),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).

leutnant   ~~> @count_noun((a_ leutnant),human,mas,minus),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).

liter      ~~> @count_noun((a_ liter),unit,mas,minus),
               @noun_flex_fk(nfk_2).

lgner     ~~> @count_noun((a_ lgner),human,mas,minus),
               @noun_flex_fk(nfk_1).


mann       ~~> @count_noun((a_ mann),human,mas,minus),
               @pl_stem(a_ mnn),
               @noun_flex_fk(nfk_er),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(both).

mantel     ~~> @count_noun((a_ mantel),thing,mas,minus),
               @pl_stem(a_ mntel),
               @noun_flex_fk(nfk_1),
               @noun_flex_gen_e(minus).

material   ~~> @count_noun((a_ material),thing,neu,minus),
               @pl_stem(a_ materiali),
               @noun_flex_fk(nfk_n1),
               @noun_flex_e_vor_n(plus),
               @noun_flex_gen_e(minus),
               @noun_flex_dat_e(minus).

mrder     ~~> @count_noun((a_ mrder),human,mas,minus),
               @noun_flex_fk(nfk_2).


programm   ~~> @count_noun((a_ programm),information_poly,neu,minus),
               @noun_flex_fk(nfk_e1),
               @noun_flex_e_vor_n(plus),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(minus).

problem   ~~> @cp_noun((a_ problem),abstract,neu,da,minus),
              @noun_flex_fk(nfk_e1),
              @noun_flex_gen_e(plus),
              @noun_flex_dat_e(minus).

projekt   ~~> @count_noun((a_ projekt),abstract,neu,minus),
              @noun_flex_fk(nfk_e1),
              @noun_flex_dat_e(both). % TSNLP likes Projekte, so we admit it.

prfung   ~~> @count_noun((a_ prfung),action_sit,fem,minus),
              @noun_flex_fk(nfk_n5),
              @noun_flex_e_vor_n(plus).

satz       ~~> @count_noun((a_ satz),information_poly,mas,minus),
               @pl_stem(a_ stz),
               @noun_flex_fk(nfk_e1),
               @noun_flex_e_vor_n(plus),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(minus).

tatsache   ~~> @cp_noun((a_ tatsache),info_content,fem,da,minus),
               @noun_flex_fk(nfk_n5),
               @noun_flex_e_vor_n(minus).

% drop-det
% Da habe ich Vorlesung.
% *Ich habe in Vorlesung geschlafen. :-(
vorlesung ~~> @count_noun((a_ vorlesung),action_sit,fem,plus),
              @noun_flex_fk(nfk_n5),
              @noun_flex_e_vor_n(plus).

wagen     ~~> @count_noun((a_ wagen),vehicle,mas,minus),
              @noun_flex_fk(nfk_1),
              @noun_flex_gen_e(minus).

wand      ~~> @count_noun((a_ wand),thing,fem,minus),
              @pl_stem(a_ wnd),
              @noun_flex_fk(nfk_e3).

zug     ~~> @count_noun(a_ zug,vehicle,mas,minus),
               @pl_stem(a_ zge),
               @noun_flex_fk(nfk_e1),
               @noun_flex_gen_e(plus),
               @noun_flex_dat_e(minus).

%%%%% determiner
%%%%-----------------------------

der ~~> @det(def_rel,nom,mas,sg,strong).
des ~~> @det(def_rel,gen,mas_or_neu,sg,strong).
dem ~~> @det(def_rel,dat,mas_or_neu,sg,strong).
den ~~> @det(def_rel,acc,mas,sg,strong).

die ~~> @det(def_rel,nom_or_acc,fem,sg,strong).
der ~~> @det(def_rel,gen_or_dat,fem,sg,strong).

das ~~> @det(def_rel,nom_or_acc,neu,sg,strong).

% plural forms are not morphologically specified for gender
% but agreement shows that there are inferences with semantics
%
die ~~> @det(def_rel,nom_or_acc,_,pl,strong).
der ~~> @det(def_rel,gen,_,pl,strong).
den ~~> @det(def_rel,dat,_,pl,strong).



derselbe  ~~> @det(def_rel,nom,mas,sg,strong).
desselben ~~> @det(def_rel,gen,mas_or_neu,sg,strong).
demselben ~~> @det(def_rel,dat,mas_or_neu,sg,strong).
denselben ~~> @det(def_rel,acc,mas,sg,strong).

dieselbe  ~~> @det(def_rel,nom_or_acc,fem,sg,strong).
derselben ~~> @det(def_rel,gen_or_dat,fem,sg,strong).

dasselbe  ~~> @det(def_rel,nom_or_acc,neu,sg,strong).

dieselben ~~> @det(def_rel,nom_or_acc,_,pl,strong).
derselben ~~> @det(def_rel,gen,_,pl,strong).
denselben ~~> @det(def_rel,dat,_,pl,strong).

derjenige  ~~> @det(def_rel,nom,mas,sg,strong).
desjenigen ~~> @det(def_rel,gen,mas_or_neu,sg,strong).
demjenigen ~~> @det(def_rel,dat,mas_or_neu,sg,strong).
denjenigen ~~> @det(def_rel,acc,mas,sg,strong).

diejenige  ~~> @det(def_rel,nom_or_acc,fem,sg,strong).
derjenigen ~~> @det(def_rel,gen_or_dat,fem,sg,strong).

dasjenige  ~~> @det(def_rel,nom_or_acc,neu,sg,strong).

diejenigen ~~> @det(def_rel,nom_or_acc,_,pl,strong).
derjenigen ~~> @det(def_rel,gen,_,pl,strong).
denjenigen ~~> @det(def_rel,dat,_,pl,strong).



% inflected determiners (macro has a different arity)
all    ~~> @det(alle_rel,strong).
dies   ~~> @det(dies_rel,strong).
ein    ~~> @det(ein_rel,sg,weak).
einig  ~~> @det(einige_rel,strong).     % meine Sekretrin drfte da einige Ahnung haben, einiges Gemse, einige Mnner
etlich ~~> @det(etlich_rel,strong). 
irgendein ~~> @det(irgendein_rel,sg,weak).
jed    ~~> @det(jeder_rel,sg,strong).
jemand ~~> @det(jemand_rel,sg,weak).
jen    ~~> @det(jenes_rel,strong).
kein   ~~> @det(kein_rel,weak).
mehrer ~~> @det(mehrere_rel,pl,strong).
niemand ~~> @det(niemand_rel,sg,weak).
manch  ~~> @det(manch_rel,strong).
viel   ~~> @det(viel_rel,strong).



%%%%% adjective
%%%%-----------------------------

alt         ~~> @adjective((a_ alt),        anything).
dumm        ~~> @adjective((a_ dumm),       agentive).
glcklich   ~~> @adjective((a_ glcklich),  agentive).
grammatisch ~~> @adjective((a_ grammatisch),thing). 
gro        ~~> @adjective((a_ gro),       anything).
intelligent ~~> @adjective((a_ intelligent),agentive).
klein       ~~> @adjective((a_ klein),      anything).
klug        ~~> @adjective((a_ klug),  agentive).
krank       ~~> @adjective((a_ krank), object).   % Baum
ledig       ~~> @adjective((a_ ledig), human).
leicht      ~~> @adjective((a_ leicht),anything).
nackt       ~~> @adjective((a_ nackt), agentive).
neu         ~~> @adjective((a_ neu),   anything).
roh         ~~> @adjective((a_ roh),   thing).    % not the metaphoric use
schlecht    ~~> @adjective((a_ schlecht),anything).
schn       ~~> @adjective((a_ schn),   anything).

spannend    ~~> @adjective(a_ spannend, anything).
stark       ~~> @adjective(a_ stark, anything).
stolz       ~~> @adjective(a_ stolz, human).    % stolzer Preis has a different meaning
warm        ~~> @adjective(a_ warm,  object).

schulfrei  ~~> @subjless_adjective((a_ schulfrei)).
schlecht   ~~> @subjless_np_adjective(a_ schlecht,agentive).

warm       ~~> @non_ref_adjective(a_ warm). % weil es ihm hier zu warm ist.
warm       ~~> @subjless_np_adjective(a_ warm,agentive).

treu       ~~> @np_adjective((a_ treu),agentive,dat,anything).

stolz      ~~> @pp_adjective((a_ stolz),human,auf_pform,acc,anything).

morgig     ~~> @attr_adjective(a_ morgig,  agentive).
pleite     ~~> @prd_adjective(a_ pleite,  ilcp_human_poly).  % Berlin, Humboldt-Uni, Hans Eichel

angeblich    ~~> @scopal_adjective(a_ angeblich).
potentiell   ~~> @scopal_adjective(a_ potentiell).
vermeintlich ~~> @scopal_adjective(a_ vermeintlich).

%%% die beiden Tage -> ist ein Adjektiv
beid       ~~> (@attr_adjective(a_ beide,  anything),
                synsem:loc:cat:head:subj:[loc:cont:ind:num:pl]).

%%% unsere smtlichen Filialen
smtlich   ~~> @attr_adjective((a_ smtlich),  anything).

solch      ~~> @attr_adjective((a_ solch),  anything).


%% adverbs
%--------------------------------


damals  ~~> @temp_adverb(a_ damals).

gestern ~~> @temp_adverb(a_ gestern).

heute   ~~> @temp_adverb(a_ heute).

jetzt   ~~> @temp_adverb(a_ jetzt).

hier    ~~> @intersective_adverb(a_ hier).

morgen  ~~> @temp_adverb(a_ morgen).


mehrmals ~~> @scopal_adverb(a_ mehrmals).

nicht    ~~> @scopal_adverb(a_ nicht).

oft      ~~> @scopal_adverb(a_ oft).

sofort   ~~> @temp_adverb(a_ sofort).

%% verbs
%--------------------------------

%anfangen
fang    ~~> @phase_verb(a_ anfangen,(a_ [a,n])),
            @pres2_stem(a_ fng),
 
            @past_stem(a_ fing),
            @part_stem(a_ fang),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

%ankommen
komm    ~~> @intrans_erg_verb((a_ ankommen),object,situation,(a_ [a,n])),
 
            @past_stem(a_ kam),
            @conj_stem(a_ km),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).


geb     ~~> @ditrans_verb(a_ geben,agentive,anything,agentive,action_sit),
            @pres2_stem(a_ gib),
            @past_stem(a_ gab),
            @part_stem(a_ geb),
            @conj_stem(a_ gb),
            
            @vflex_fk(v_strong),
            
            @vflex_ep(minus),
            @vflex_evp(minus),
            @vflex_epp(plus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
                                %  LS:flex_m:imp_stem      <=> 2,
            @vflex_bet1(plus).


% form fr habest fehlt noch in Morphologie
hab     ~~> @haben,
            @pres2_stem(a_ ha),
            @past_stem(a_ hat),
            @part_stem(a_ hab),
            @conj_stem(a_ ht),
            
            @vflex_fk(mixed),
            
            @vflex_ep(minus),
            @vflex_sm(minus),
            @vflex_pl_n(minus),
            @vflex_spe(minus),
            @vflex_tm(minus),
            @vflex_em(minus),
            @vflex_bet1(plus).

schlaf    ~~> @intrans_nerg_verb((a_ schlafen),agentive,haben,situation),
              @pres2_stem(a_ schlf),
              @past_stem(a_ schlief),

              @vflex_fk(v_strong),
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

%%% Karl schlgt den Ball ins Abseits.
%%% Das Knguruh schlgt die Frau.
schlag  ~~>   @trans_verb((a_ schlagen),agentive,object,haben,action_sit),
              @pres2_stem(a_ schlg),
              @past_stem(a_ schlug),
              @part_stem(a_ schlag),
 
              @vflex_fk(v_strong),
 
              @vflex_ep(minus),
              @vflex_evp(minus),
              @vflex_epp(plus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).

%umfrben
frb      ~~> @trans_verb((a_ umfrben),human,thing,haben,action_sit,(a_ [u,m])),
              @vflex_fk(v_weak),
 
              @vflex_ep(minus),
              @vflex_sm(minus),
              @vflex_pl_n(minus),
              @vflex_spe(minus),
              @vflex_tm(minus),
              @vflex_em(minus),
              @vflex_bet1(plus).


%% prepositions
%-------------------------------

auf  ~~> @preposition(auf_pform,acc,anything).

auf  ~~> @preposition(auf_rel,dat,object).

in   ~~> @preposition(in_rel,dat,anything).

mit  ~~> @preposition(mit_pform,dat,anything).

nach ~~> @preposition(nach_pform,dat,anything).

ber ~~> @preposition(ber_pform,dat_or_acc,anything).

von  ~~> @preposition(von_pform,dat,anything).

von  ~~> @passive_preposition(dat).

vor  ~~> @preposition(vor_pform,dat_or_acc,anything).

zu   ~~> @preposition(zu_pform,dat,anything).


%%%%% complementizer
%%%%-----------------------------

da  ~~> @complementizer(da).
dass ~~> @complementizer(da).


weil ~~> @complementizer(weil_rel).

%%%%% coordinations
%%%%-----------------------------

oder ~~> @coordination(oder_rel).

und  ~~> @coordination(und_rel).


%% verb movement
%-------------------------------

%empty @verb_movement_trace.
empty @verb_movement_trace_cyclic.

empty @extraction_trace.

