%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: lexrules.pl,v $
%%  $Revision: 1.28 $
%%      $Date: 2004/02/06 12:44:53 $
%%     Author: Stefan Mueller (Stefan.Mueller@uni-bremen.de)
%%    Purpose: This file contains the lexical rules of a TRALE grammar 
%%             which is an improved reimplemetation of the Babel grammar.
%%             See Mller (2002) for further documentation.
%%   Language: Trale
%      System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% $Log: lexrules.pl,v $
%% Revision 1.28  2004/02/06 12:44:53  stefan
%% changed subject verb agreement, fixed modal inflection, w-clauses should work
%%
%% Revision 1.27  2004/02/05 11:41:56  stefan
%% fixed QUE percolation
%%
%% Revision 1.26  2004/02/04 20:49:20  stefan
%% short type fix
%%
%% Revision 1.25  2004/02/04 20:44:20  stefan
%% one more fix for the genitive rule
%%
%% Revision 1.24  2004/02/03 19:04:28  stefan
%% added lexical entries, relativization with adverbs, fixed genitive rule
%%
%% Revision 1.23  2004/02/02 11:13:10  stefan
%% removed restrictions since they were blocked in most cases by delay mechanism, introduced special list for counting (s_subcat)
%%
%% Revision 1.22  2004/01/30 20:43:12  stefan
%% restricted the number of arguments in clauses with V1 and predicate complex
%%
%% Revision 1.21  2004/01/29 16:16:12  stefan
%% fixed extraposition with v-last sentences, lexical items
%%
%% Revision 1.20  2004/01/28 18:33:50  stefan
%% fixed adjunct attachment in verbal complexes + PVP
%%
%% Revision 1.19  2004/01/27 20:21:46  stefan
%% cleaned type hierarchy, made adverb attachment less ambiguos
%%
%% Revision 1.18  2004/01/27 19:21:55  stefan
%% depictives
%%
%% Revision 1.17  2004/01/25 20:25:02  stefan
%% reorganized introduction of nonlocal dependencies
%%
%% Revision 1.16  2004/01/24 15:38:16  stefan
%% fixed spurious ambiguities
%%
%% Revision 1.15  2004/01/24 14:33:30  stefan
%% (complement) extraposition
%%
%% Revision 1.14  2004/01/23 20:26:53  stefan
%% fixed n-bar
%%
%% Revision 1.13  2004/01/23 16:31:52  stefan
%% various changes see log
%%
%% Revision 1.12  2004/01/22 23:51:51  stefan
%% treatment for spurious ambiguities with intersective noun modifers
%%
%% Revision 1.11  2004/01/20 21:10:13  stefan
%% empty-noun rule
%%
%% Revision 1.10  2004/01/20 18:32:17  stefan
%% now we use the cyclic trace ...
%%
%% Revision 1.9  2004/01/19 12:17:44  stefan
%% fixed mult vf rule after introduction of cyclic trace
%%
%% Revision 1.8  2003/11/12 14:31:33  stefan
%% fixed detmar's constraint on verb movement traces which did not apply to copula verbs
%%
%% Revision 1.7  2003/11/11 13:59:59  stefan
%% Detmars cyclic verbal trace
%%
%% Revision 1.6  2003/11/04 16:41:03  stefan
%% fixed complemention with saturated verbal complexes, fixed past_conj inflection
%%
%% Revision 1.5  2003/11/03 21:37:55  stefan
%% fixed coordination and spurious ambiguities
%%
%% Revision 1.4  2003/11/03 15:10:18  stefan
%% fixed structural case of adjective subjects, fixed trace information for inflected elements
%%
%% Revision 1.3  2003/11/03 13:42:19  stefan
%% fix in lexical rule for participles, fix verbs with lexical cas object (helfen)
%%
%% Revision 1.2  2003/11/03 11:59:16  stefan
%% fix in lexical rule that introduced spurious ambiguities, fix in coherent constr. with zu-inf
%%
%% Revision 1.1  2003/11/02 20:15:59  stefan
%% got rid ov XCOMP
%%
%% Revision 1.0  2003/11/01 17:35:40  stefan
%% switched after confusion, fixed trace stuff
%%
%% Revision 1.8.2.1  2003/10/23 09:57:46  stefan
%% added signature
%%
%% Revision 1.8  2003/10/23 09:01:13  stefan
%% Back to append again
%%
%% Revision 1.6  2003/10/21 19:37:56  stefan
%% Version after Introduction of Traces
%%
%%
%% Revision 1.2  2003/04/08 08:57:20  stefan
%% Initial revision
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile '##'/2.
:- multifile macro/2.
:- multifile if/2.
:- multifile '*>'/2. 
:- multifile ':='/2.
:- multifile fun/1.
:- discontiguous '##'/2.
:- discontiguous ':='/2.
:- discontiguous if/2.
:- discontiguous lex_rule/2.
:- discontiguous fun/1.
        
%%% *************************************
%%%    Lexical Rules			 
%%% *************************************

:- lex_rule_depth(5).

lex_rule_infl_affixed(Dtr) :=
   (infl_word,
    synsem:trace:minus,     % could do some structure sharing into the stem, but ...
    dtr:(stem,
         Dtr)).

lex_rule_infl_affixed_identical_synsem(Dtr) :=
  (@lex_rule_infl_affixed(Dtr),
   infl_word,
   synsem:Synsem,
   dtr:synsem:Synsem). 

% this is copying material that is never changed in lexical rules
lex_rule_identical_never_changed(Dtr) :=
 (synsem:(loc:coord:Coord,
          nonloc:Nonloc,
          trace:Trace),
  dtr:(Dtr,
       synsem:(loc:coord:Coord,
               nonloc:Nonloc,
               trace:Trace))).


lex_rule_infl_affixed_identical_never_changed(Dtr) :=
 (@lex_rule_infl_affixed(Dtr),
  @lex_rule_identical_never_changed(Dtr)).

lex_rule_infl_affixed_identical_but_subcat(Dtr) :=
 (@lex_rule_infl_affixed_identical_never_changed(Dtr),
  synsem:(loc:(cat:(head:Head,
                    spr:Spr),
               cont:Cont),
          lex:Lex,
          phrase:Phrase),
  dtr:(Dtr,
       synsem:(loc:(cat:(head:Head,
                         spr:Spr),
               cont:Cont),
          lex:Lex,
          phrase:Phrase))).

lex_rule_infl_affixed_identical_but_head(Dtr) :=
 (@lex_rule_infl_affixed_identical_never_changed(Dtr),
  synsem:(loc:(cat:(spr:Spr,
                    subcat:Subcat),
               cont:Cont),
          lex:Lex,
          phrase:Phrase),
  dtr:(Dtr,
       synsem:(loc:(cat:(spr:Spr,
                         subcat:Subcat),
                    cont:Cont),
               lex:Lex,
               phrase:Phrase))).


% Such rules applies to everything that does not have a particle
% that has to be written together with the verb. 
non_particle_infl_lex_rule(Dtr) :=
  (dtr:(Dtr,
        synsem:loc:cat:subcat:([] % this is the case for prenominal participles
                              ;[loc:cat:head:(sep_part;prd_adj_or_prd_prep;bse_or_ppp_verb;v_arg_head)
                              % declaring a type not_nsep_part is too much fuzz, I am sick of specifying mgu's
                              % I guess I have to redo everything under head once the grammar stabalized. 03.11.2003
                              
                              % did not work (=\= nsep_part)
                              |_]
                              ))).


%%% maps stems to stems
lex_rule_deriv_affixed(Dtr) :=
   (stem,
    dtr:(stem,
         Dtr)).

lex_rule_deriv_affixed_identical_never_changed(Dtr) :=
 (@lex_rule_deriv_affixed(Dtr),
  synsem:nonloc:Nonloc,
  dtr:(Dtr,
       synsem:nonloc:Nonloc)).

%%% maps words to stems
%%% lachen -> lachend
lex_rule_deriv_word_affixed(Dtr) :=
   (stem,
    dtr:(word,
         Dtr)).

lex_rule_deriv_word_affixed_identical_never_changed(Dtr) :=
 (@lex_rule_deriv_word_affixed(Dtr),
  synsem:nonloc:Nonloc,
  dtr:(Dtr,
       synsem:nonloc:Nonloc)).


%%% maps words to words
%%% nackt (predicative) -> nackt (depictive)

%%% currently the ARG1 argument is instantiated wrongly for prenominal participles:
%%% die nackt schlafende Frau
%%% the econt/icont destinction is needed, it has to be made for indices.
lex_rule_depictive ##
(Dtr,
 word,
 synsem:loc:(cat:head:(prd_adj,
                       subj:[loc:cont:ind:Ind]
                      ),
             cont:(key:handel:Handle,
                   liszt:AdjList)))
**>
(word,
 @intersective_non_rel_adverb(a_ whrend),
 @default_nonloc_non_coord_lexical_sign,   % everything but the restrictions on liszt, since we have two elements in liszt
 @overt_sign,
 synsem:loc:(cat:head:mod:loc:cat:(head:subj:Subj,
                                   subcat:Subcat),
             cont:(key:(Key,
                        arg2:Handle),
                   liszt:[Key|AdjList])),
 dtr:Dtr)
if
  member(loc:cont:ind:Ind,append(Subj,Subcat))
morphs
  X becomes X.


noun_infl_lr ##
(@lexical_noun,
 infl:(umlaut:UmlautStem,
       affix:(Affix,
              noun_i_suffix,
              phon:[(a_ Suff)],
              num:Num,
              morph_case:Case)),
 Dtr)
**>
(@lexical_noun,
 @lex_rule_infl_affixed_identical_synsem(Dtr),
 synsem:loc:(cat:head:case:(morph_case:Case,
                            syn_case:Case               % this should be an independent copy of the morph case
                                                        % see also macros
                           ),
             cont:ind:num:Num))
if
  get_irreg_n_stem(Affix,UmlautStem,(a_ IStem))
morphs
  X becomes (X,Suff) when IStem = none,
  X becomes (IStem,Suff).


det_infl_lr ##
(synsem:loc:cat:head:det,
 infl:affix:(det_i_suffix,
             phon:[(a_ Suff)],
             num:Num,
             gen:Gen,
             dtype:DType,
             morph_case:Case),
 Dtr)
**>
(@lex_rule_infl_affixed_identical_synsem(Dtr),
 synsem:loc:cat:head:(num:Num,
                      gen:Gen,
                      dtype:DType,
                      case:(morph_case:Case,
                            syn_case:Case               % this should be an independent copy of the morph case
                           )))
morphs
  X becomes (X,Suff).




get_prefix(plus, (a_ [g,e])) if true.
get_prefix(minus,(a_ [])   ) if true.


get_irreg_v_stem((Affix,
                  temo:Temo),VStems,IrregStem) if
  when(Temo=(pres_ind_conj;past_ind_conj;conj)
       ,undelayed_get_irreg_v_stem(Affix,VStems,IrregStem)).

undelayed_get_irreg_v_stem((temo:pres_ind_conj),                (pres2:(a_ none)),     (a_ none    ))  if !,true.
% ich fange, du fngst, er fngt
undelayed_get_irreg_v_stem((fk:v_strong,
                            temo:pres_ind, per:second_or_third),(pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if true.

% Ich darf, du darfst, er darf, wir drfen, ihr drft, sie drfen
% the irregular stem in sg:
undelayed_get_irreg_v_stem((fk:modal,
                            temo:pres_ind,
                            num:sg),                            (pres2:(a_ Pres2Stem)),(a_ Pres2Stem)) if !,true.


undelayed_get_irreg_v_stem((temo:pres_conj,per:second_or_third),_,     (a_ none    ))  if !,true.

% ich fange
undelayed_get_irreg_v_stem((fk:v_strong,
                            temo:pres_ind_conj,per:first),      _,                     (a_ none    ))  if !,true.

% ich fing, ..., ich durfte, ...
undelayed_get_irreg_v_stem((temo:past_ind),                     (past:(a_ PastStem)),  (a_ PastStem))  if true.

% If a conj stem is definied, take it, otherwise return the past stem.
% kommen, kam, kme
% fangen, fing, finge
undelayed_get_irreg_v_stem((temo:past_conj),                    (conj:(a_ ConjStem)),  (a_ ConjStem))  if prolog(ConjStem\=none).
undelayed_get_irreg_v_stem((temo:past_conj),                    (past:(a_ ConjStem)),  (a_ ConjStem))  if prolog(ConjStem=none).


%undelayed_get_irreg_v_stem(_,          _,                     (a_ none    ))  if true.



get_irreg_n_stem((num:pl),(a_ UmlautStem),  (a_ UmlautStem))  if !.
get_irreg_n_stem(_,_,_) if true.



duplicate_last([X],[X,X]) if
  consonant(X).

duplicate_last([X|Y],[X|Z]) if
  duplicate_last(Y,Z).

consonant(n).

fun block_da(+,+,-).
block_da(DA,Subcat,RedSubcat) if
  append(RedSubcat,DA,Subcat).

fun block_subject(+,-,+).
block_subject(Subcat,RestSubcat,Subj) if
   when( Subcat=(e_list;ne_list)
       , undelayed_block_subject(Subcat,RestSubcat,Subj)).


% this assumes that all predicates (verbs) have at least one argument,
% expletive or not
undelayed_block_subject([(SubjNP,
                          @np_str)],[],[SubjNP]) if !, true.

%undelayed_block_subject([(Other,
%                          @np_lex)],[Other],[]) if true.

%undelayed_block_subject([(Other,
%                          loc:cat:head:no_noun)],[Other],[]) if true.

undelayed_block_subject([Other],[Other],[]) if true.

undelayed_block_subject([X|T1],[X|T2],Subj) if
%  X =\= @np_str,
  block_subject(T1,T2,Subj).








