% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: rules.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:23 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Contains phrase
%%   Language: Trale
%%     System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% $Log: rules.pl,v $
%% Revision 2.15  2004/05/04 16:31:23  stefan
%% added my-draw-hierarchy to the repository
%%
%% Revision 2.14  2004/03/26 10:34:31  stefan
%% enabled chart manipulation
%%
%% Revision 2.13  2004/03/25 20:08:02  stefan
%% fixed particples
%%
%% Revision 2.12  2004/03/25 19:46:35  stefan
%% disabled chart manipulation for testing
%%
%% Revision 2.11  2004/03/25 17:13:13  stefan
%% added participle rule, reorganization of types under head, chart manipulation code
%%
%% Revision 2.10  2004/03/23 13:59:34  stefan
%% excluded spurious ambiguities in coordination structures, fixed extraposition
%%
%% Revision 2.9  2004/03/22 21:18:27  stefan
%% clause boundedness of extraposition, introduction of new types
%%
%% Revision 2.8  2004/03/12 12:17:04  stefan
%% fixed particle verbs
%%
%% Revision 2.7  2004/03/11 22:51:20  stefan
%% total redesign of types under phrase, fixed depictives and bare infinitives
%%
%% Revision 2.6  2004/03/11 12:49:55  stefan
%% various speed improvements changed dalaying of extra constraint significant improvement
%%
%% Revision 2.5  2004/03/10 23:18:02  stefan
%% fixed delay
%%
%% Revision 2.4  2004/03/10 23:01:56  stefan
%% fixed conditional append for depictives, fixed DA for participles 'nackt schlafende'
%%
%% Revision 2.3  2004/03/10 15:02:22  stefan
%% fixed que in free relative clauses
%%
%% Revision 2.2  2004/03/05 21:29:40  stefan
%% fixed participle lexrule
%%
%% Revision 2.1  2004/03/04 12:22:39  stefan
%% difference lists for liszt and h_cons
%%
%% Revision 2.0  2004/02/29 16:17:34  stefan
%% first public release
%%
%% Revision 1.49  2004/02/23 18:28:37  stefan
%% fixed anchor introduction for irregular verbs, fixed extraposition from verbal clusters
%%
%% Revision 1.48  2004/02/23 16:07:15  stefan
%% fixed complement extraposition, posessive of proper nouns, fixed spurious ambiguity problem with Berthold's analysis, fixed quantifier-np issue
%%
%% Revision 1.47  2004/02/22 21:17:07  stefan
%% complete revision of adjunct extraposition
%%
%% Revision 1.46  2004/02/22 17:36:23  stefan
%% fixed extraposition of negation, and introduction of extraposition traces
%%
%% Revision 1.45  2004/02/21 15:47:36  stefan
%% various extensions and fixes
%%
%% Revision 1.44  2004/02/20 17:12:50  stefan
%% fixed determiner inflection
%%
%% Revision 1.43  2004/02/20 13:56:01  stefan
%% fixed determiner inflection
%%
%% Revision 1.42  2004/02/20 10:50:14  stefan
%% fixed determiner inflection
%%
%% Revision 1.41  2004/02/20 10:37:48  stefan
%% fixed determiner inflection
%%
%% Revision 1.40  2004/02/19 16:32:25  stefan
%% avoided spurious ambiguity with PVP and extraposition
%%
%% Revision 1.39  2004/02/18 20:13:06  stefan
%% fixed inflection, QUE percolation, coherent constructions with object control verbs
%%
%% Revision 1.38  2004/02/18 17:43:15  stefan
%% fixed 'zu' for infinitives
%%
%% Revision 1.37  2004/02/18 16:11:58  stefan
%% implemented pronominal adverbs + sentential arguments and Berthold Crysmann's treatement of ambiguity prevention in extraposition structures
%%
%% Revision 1.36  2004/02/16 23:04:36  stefan
%% computed s_subcat for verbal complexes
%%
%% Revision 1.35  2004/02/16 11:12:20  stefan
%% introduced max_ feature to avoid the unblocking of the delayed constraint del
%%
%% Revision 1.34  2004/02/15 11:38:59  stefan
%% fixed bug with extraposition in incoherent constructions
%%
%% Revision 1.33  2004/02/14 17:40:41  stefan
%% added imperative inflection, simplified type hierarchies, modification reading for day_nouns
%%
%% Revision 1.32  2004/02/13 15:26:27  stefan
%% added aktionsarten, excluded some impossible passives
%%
%% Revision 1.31  2004/02/12 19:53:45  stefan
%% fixed block_subject, fixed DA for participles and lexical rules, intersective_modifiers
%%
%% Revision 1.30  2004/02/11 12:40:26  stefan
%% fixed inflection bug, fixed bug in block-subject
%%
%% Revision 1.29  2004/02/06 22:49:56  stefan
%% fixed inflection bug, total reorganization of signature under head, time-mod-nouns
%%
%% Revision 1.28  2004/02/06 12:44:53  stefan
%% changed subject verb agreement, fixed modal inflection, w-clauses should work
%%
%% Revision 1.27  2004/02/05 11:41:58  stefan
%% fixed QUE percolation
%%
%% Revision 1.26  2004/02/04 20:49:21  stefan
%% short type fix
%%
%% Revision 1.25  2004/02/04 20:44:23  stefan
%% one more fix for the genitive rule
%%
%% Revision 1.24  2004/02/03 19:04:29  stefan
%% added lexical entries, relativization with adverbs, fixed genitive rule
%%
%% Revision 1.23  2004/02/02 11:13:11  stefan
%% removed restrictions since they were blocked in most cases by delay mechanism, introduced special list for counting (s_subcat)
%%
%% Revision 1.22  2004/01/30 20:43:13  stefan
%% restricted the number of arguments in clauses with V1 and predicate complex
%%
%% Revision 1.21  2004/01/29 16:16:14  stefan
%% fixed extraposition with v-last sentences, lexical items
%%
%% Revision 1.20  2004/01/28 18:33:52  stefan
%% fixed adjunct attachment in verbal complexes + PVP
%%
%% Revision 1.19  2004/01/27 20:21:48  stefan
%% cleaned type hierarchy, made adverb attachment less ambiguos
%%
%% Revision 1.18  2004/01/27 19:21:56  stefan
%% depictives
%%
%% Revision 1.17  2004/01/25 20:25:02  stefan
%% reorganized introduction of nonlocal dependencies
%%
%% Revision 1.16  2004/01/24 15:38:16  stefan
%% fixed spurious ambiguities
%%
%% Revision 1.15  2004/01/24 14:33:30  stefan
%% (complement) extraposition
%%
%% Revision 1.14  2004/01/23 20:26:53  stefan
%% fixed n-bar
%%
%% Revision 1.13  2004/01/23 16:31:52  stefan
%% various changes see log
%%
%% Revision 1.12  2004/01/22 23:51:51  stefan
%% treatment for spurious ambiguities with intersective noun modifers
%%
%% Revision 1.11  2004/01/20 21:10:14  stefan
%% empty-noun rule
%%
%% Revision 1.10  2004/01/20 18:32:18  stefan
%% now we use the cyclic trace ...
%%
%% Revision 1.9  2004/01/19 12:17:45  stefan
%% fixed mult vf rule after introduction of cyclic trace
%%
%% Revision 1.8  2003/11/12 14:31:33  stefan
%% fixed detmar's constraint on verb movement traces which did not apply to copula verbs
%%
%% Revision 1.7  2003/11/11 13:59:59  stefan
%% Detmars cyclic verbal trace
%%
%% Revision 1.6  2003/11/04 16:41:03  stefan
%% fixed complemention with saturated verbal complexes, fixed past_conj inflection
%%
%% Revision 1.5  2003/11/03 21:37:55  stefan
%% fixed coordination and spurious ambiguities
%%
%% Revision 1.4  2003/11/03 15:10:18  stefan
%% fixed structural case of adjective subjects, fixed trace information for inflected elements
%%
%% Revision 1.3  2003/11/03 13:42:19  stefan
%% fix in lexical rule for participles, fix verbs with lexical cas object (helfen)
%%
%% Revision 1.2  2003/11/03 11:59:16  stefan
%% fix in lexical rule that introduced spurious ambiguities, fix in coherent constr. with zu-inf
%%
%% Revision 1.1  2003/11/02 20:15:59  stefan
%% got rid ov XCOMP
%%
%% Revision 1.0  2003/11/01 17:35:40  stefan
%% switched after confusion, fixed trace stuff
%%
%% Revision 1.8.2.1  2003/10/23 09:09:49  stefan
%% test
%%
%% Revision 1.8  2003/10/23 09:01:13  stefan
%% Back to append again
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

:- multifile '##'/2. 

%% The instances of phrases defined in syntax.pl


spr_h ## @spr_head_phrase(HeadDtr,NonheadDtr)
  ===>
cat> NonheadDtr,
sem_head> HeadDtr.
%cat> HeadDtr.


h_arg ## @head_argument_phrase(HeadDtr,NonheadDtr)
  ===>
cat> HeadDtr,
sem_head> NonheadDtr.
%cat> NonheadDtr.

arg_h ## @argument_head_phrase(HeadDtr,NonheadDtr)
  ===>
cat> NonheadDtr,
sem_head> HeadDtr.
%cat> HeadDtr.


% h_cl ## @head_cluster_phrase(HeadDtr,NonheadDtr)
%   ===>
% cat> HeadDtr,
% cat> NonheadDtr.


cl_h ## @cluster_head_phrase(HeadDtr,NonheadDtr)
  ===>
cat> NonheadDtr,
sem_head> HeadDtr.
%cat> HeadDtr.

h_adj ## @head_adjunct_phrase(HeadDtr,NonheadDtr)
  ===>
cat> HeadDtr,
sem_head> NonheadDtr.
%cat> NonheadDtr.


adj_h ## @adjunct_head_phrase(HeadDtr,NonheadDtr)
  ===>
sem_head> NonheadDtr,
%cat> NonheadDtr,
cat> HeadDtr.



f_h ## @filler_head_phrase(HeadDtr,NonheadDtr)
  ===>
cat> NonheadDtr,
%cat> HeadDtr.
sem_head> HeadDtr.




% this adds an edge for every maximal projection + verb trace with extracted argument
% and another one for every verb trace with no argument and one for verb trace with extracted adjunct
h_e ##  @head_extra_phrase(HeadDtr,NonheadDtr)
  ===>
cat> HeadDtr,
%cat> HeadDtr.
sem_head> NonheadDtr.

h_e_a ##  @head_adjunct_extra_phrase(HeadDtr,NonheadDtr)
  ===>
cat> (HeadDtr,
      synsem:active_anchors:Anchors),
%cat> HeadDtr.
sem_head> (NonheadDtr,
           synsem:loc:cat:head:mod:loc:cont:(ltop:Handel,
                                             ind:Ind)),
goal> member((handle:Handel,ind:Ind),Anchors).


/*
arg_ei ## @arg_extra_intro_phrase(HeadDtr)
   ===>
sem_head> HeadDtr.
*/


rc ## @rc(RelDtr,VDtr)
  ===>
cat> RelDtr,
cat> VDtr.

free_rc ## @free_rc(Dtr)
  ===>
cat> Dtr.

w_clause ## @w_clause(WDtr,VDtr)
  ===>
cat> WDtr,
cat> VDtr.


inf_zu ## @inf_zu(Zu,Verb)
  ===>
cat> Zu,
sem_head> Verb.
%cat> Verb.

empty_det ## @empty_det_phrase(HeadDtr)
  ===>
cat> HeadDtr.




% Diese Regel muss fuer nicht flektierte Adjektive blockiert werden:
% Das sind super   Frauen. -\> Das sind super.
% Das sind schoene Frauen. -> Das sind schoene.

empty_noun ##
   (empty_noun_phrase,
    synsem:(loc:(cat:(head:(Noun,
                            noun,
                            mod:none,
                            case:Case,
                            lpe:LPE),
                      spr:[(Spr,
                            @det_synsem,
                            loc:(cat:head:(case:Case,
                                           gen:Gen,
                                           num:Num),
                                 drop_det:minus))],
                      subcat:[],
                      left_adj_poss:LA)),
            nonloc:Nonloc,
            active_anchors:[],
            inert_anchors:[(handle:ModLTop,
                             ind:Ind)],
            phrase:plus,
            lex:minus,
            v2:minus,
            trace:minus,
            

   % wenn das Nomen wegfllt beziehen sich in einer Koordination trotzdem beide Adjektive auf dasselbe Nomen   
   % der erste oder sechzehnte
   % der schne und kluge
            
            cat_change:plus),
    c_cont:(ltop:ModLTop,             % can be different from the nominal LTop (angebliche)
            ind:(Ind,
                 per:third,
                 gen:Gen,
                 num:Num),
             key:Key,
             liszt:(list:[(Key,
                          abstr_nom_rel,
                          lbl:LTop,
                          arg1:Ind)|Last],
                   last:Last),
            h_cons:(@e_diff_list))
       %,dtrs:[Modifier]
   )
   ===>
        
cat> (@complete_sign,
      synsem:(loc:(cat:(head:(extrap:minus, % sonst Probleme beim einsetzen in hoehere
                                            % Domaenen
                              lpe:LPE,
                              mod:loc:(cat:(head:Noun,
                                            spr:[Spr]), % is needed for agreement, since this works via the
                                                        % constraints on Det in the Spr list
                                       
                                       cont:(ltop:LTop, % the adjunct may scope over this (angebliche)
                                             ind:Ind))),
                        left_adj_poss:LA),
                   cont:ltop:ModLTop),
              nonloc:Nonloc,
              trace:minus)).


% Allerdings:   Ich kenne eine aus Hamburg.
%             * Ich kenne ein aus Hamburg.
%             * Ich kenne eins aus Hamburg.

%   Det:loc:cat:head:def   <=> p,  % ein [von wem ich gehrt habe]
                                  % eigentlich sind das Demonstrativpronomina und keine Artikel
                                  % ich helfe denen / *den, von denen ich gehrt habe.
                                  % aber bei diesem Hack mu auf alle Flle der indef. Artikel ausgeschlossen werden

%   Det:loc:drop_det <=> m,       % sonst 'schoene schlafen' mit 'schoene' im Singular
%  den Kommentar oben verstehe ich nicht mehr. Drop-Det mu mglich sein, dann handelt es sich um Stoffnomina
%  Ich kaufe nur frische [Milch] 



genitive ## @genitive(HeadDtr,NonHeadDtr)
  ===>
sem_head> HeadDtr,
cat> NonHeadDtr.

x_conj_y ## @x_conj_y_coord_phrase(Dtr1,Dtr2)
  ===>
cat> Dtr1,
cat> Dtr2.

x_y_conj_z ## @x_y_conj_z_coord_phrase(Dtr1,Dtr2)
  ===>
cat> Dtr1,
cat> Dtr2.

conj_x_conj_y ## @conj_x_conj_y_phrase(Dtr1,Dtr2)
  ===>
cat> Dtr1,
cat> Dtr2.











