%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: speed.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:24 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Just speed constraints. The grammar should
%%             produce the same number of readings when this
%%             file is not loaded.
%%   Language: Trale
%      System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile '*>'/2.


% this excludes relative pronouns in the Mittelfeld.
% Projections of finite verbs with elements in REL are
% excluded by the relative clause schema as well,
% but the type constraint avoids constructing the uneccessary signs during parsing.

% we cannot refer to fin_verb, since the type of the verb movement trace is `verb'
% due to what is needed for multiple frontings. The interesting fin-verbs are
% the verb traces, i.e. the things that have something in DSL.          14.02.2004

% Damn, we need an additional case for verb last verbs with an empty DSL value.

(basic_binary_headed_phrase,
 synsem:loc:cat:head:(fin_verb;
                      dsl:local)) *> (synsem:nonloc:rel:[]).




% speed, restriction of the number of arguments for the verb movement trace
head_argument_phrase *> (synsem:loc:cat:s_subcat:S_Subcat,
                         head_dtr:synsem:loc:cat:s_subcat:tl:S_Subcat).


% speed
%head_non_argument_non_cluster_phrase
head_ad_e_f_s_phrase *> (synsem:loc:cat:s_subcat:Subcat,
                            head_dtr:synsem:loc:cat:s_subcat:Subcat).


% If the head daughter is the verb trace, we know that the valence list of the
% cluster can contain at most two more elements, namely the subject of the moved verb (if there is one)
% and the deblocked subject of the predicate complex in case of object predicatives or AcI constructions.
% Note that the s_subcat that comes from the verb movement trace is ignored here.
% The s_subcat of the verbal trace is restricted to four elements, but once we
% know the verbal complex, we can be more restrictive than this (or less restrictive if we
% have argument adding predicates in the verbal complex).     16.02.2004

% reduced the number of edges for Es schien mir gestern nicht geregnet zu haben. from 1528 to 1358

(head_cluster_phrase,
 synsem:loc:cat:head:dsl:local,
 non_head_dtr:synsem:nonloc:slash:[]) *> (synsem:loc:cat:s_subcat:a_list_of_length_x_plus_two(Subcat),
                                          non_head_dtr:synsem:loc:cat:subcat:Subcat).

% The constraint above is linguistically correct. The following two are ad hoc restrictions,
% that rule out verbal complexes where several arguments are added (for instance by `helfen' and `lassen').

% If a verb is fronted we do not know anything about the valence till the trace is found.
(head_cluster_phrase,
 synsem:loc:cat:head:dsl:local,
 non_head_dtr:synsem:nonloc:slash:[cat:head:mod:none]) *> synsem:loc:cat:s_subcat:[_,_,_,_].


% either the SUBCAT list is instantiated then this is without effect, or
% there are fronted parts of the predicate complex. In this case we would not have
% any clou about the number of arguments and the restriction is very helpful.
(head_cluster_phrase,
 synsem:loc:cat:head:nonfin_verb) *> synsem:loc:cat:s_subcat:[_,_,_,_].

% add constraints on lexical rules that exclude imperatives on certain verb classes



% add constraints that excludes extraposition of elements that are added by the
% verb movement trace.


% there is no extraposition of prenominal modifiers
/*
(head_adjunct_phrase,
 synsem:loc:cat:head:noun,
 non_head_dtr:synsem:trace:extraposition) *> (synsem:loc:cat:spr:[_], % otherwise pronouns and other full NPs would project
                                              non_head_dtr:synsem:loc:cat:head:pre_modifier:minus).
*/

% PHON:ne_list
% Otherwise the extraposition trace combines with the extraction trace that is used for
%
% Schlafen_i wird er [morgen _i]
%
(head_adjunct_phrase,
 non_head_dtr:synsem:trace:extraposition) *> phon:ne_list.

% adjunct extraposition is treated via anchor percolation                                              
%                                              non_head_dtr:synsem:loc:cat:left_adj_poss:minus).  % attachment ambiguities of
                                                                                                  % relative clauses and PPs



% In the case of adjuncts in the MF that refer to fronted PVPs,
% We can have structures like
%
% Gelacht_i hat er [oft _i].
%
% where the adjunct modifies a trace. Since this is only possible in
% complex forming structures extraposition dependencies should be introduced
% after complex formation and not in projections of this non-finite trace.
%
% This rules out [_j oft _i] as could be imagined in but is ruled out by 'mssen':
%
% Sagen_i wird er [[_j oft _i] mssen] [da ...]_j.
%
% It also rules out: [_j [[oft _i] mssen]]
%
% Sagen_i wird er [_j [[oft _i] mssen]] [da ...]_j.
%
% This follows from the theory, but since the SUBCAT list of _i is not known locally
% the constraints that ensure that no element of the SUBCAT list of _i can be extraposed
% do not fire.
%
% The prefered structure is and this is enforced by constraints that 'mssen' places on the embedded verbal complex:
%
% [_j Sagen] wird er [[oft _i] mssen] [da ...]_j.
%
%
% 613 -> 609 edges needed a little bit more time, so I removed the constriant

% for `der nackt gelesene Aufsatz' we get 73 instead of 79 pedges

(head_adjunct_phrase,
 head_dtr:synsem:trace:extraction) *> synsem:(loc:cat:subcat:list_of_non_complex_forming_non_extra_synsems,
                                              phrase:minus).


% The following concerns the phrase:minus constraint

% If a adverb is combined with an extraction trace as needed for
%
% Schlafen_i wird er [morgen _i].
%
% the result is marked phrase:minus. This ensures that the resulting sign can be used
% in verbal complexes only. The projection cannot be used as argument.
% Without this constraint the trace could be assumed to be a zu-inf VP which would
% give a perfect argument.

% for `der nackt gelesene Aufsatz' we get 79 instead of 81 pedges

%%%%-----------------------------------------------------------



% If the verb is an auxiliary, do not introcue nonlocal dependencies for extraposition.
%(head_adjunct_phrase,
% non_head_dtr:synsem:trace:extraposition) *> synsem:loc:cont:key:main_event_rel.


% Head^(head_adjunct_phrase,
%       synsem:(loc:cat:head:Head,
%               nonloc:slash:[cat:head:Head])) *> synsem:(loc:cat:subcat:list_of_non_complex_forming_non_extra_synsems,
%                                                         phrase:minus).
