% -*-trale-prolog-*-
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%   $RCSfile: syntax.pl,v $
%%  $Revision: 2.15 $
%%      $Date: 2004/05/04 16:31:26 $
%%     Author: Stefan Mueller (Stefan.Mueller@cl.uni-bremen.de)
%%    Purpose: Contains types and macros used in phrase
%%             structure rules (rules.pl).
%%   Language: Trale
%      System: TRALE 2.3.7 (release ) under Sicstus 3.9.1
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



:- multifile macro/2.
:- multifile '*>'/2.
:- multifile ':='/2.
:- multifile if/2.
:- multifile fun/1.
:- discontiguous '*>'/2.
:- discontiguous macro/2.
:- discontiguous if/2.
:- discontiguous ':='/2.
:- discontiguous fun/1.


phrase *>
  ( synsem:(loc:cont:(gtop:GTop,
                      ltop:LTop,
                      ind:Index),
            trace:minus),
    c_cont:(gtop:GTop,
            ltop:LTop,
	    ind:Index)).

%% Headed phrases must obey the Head Feature Principle.

headed_phrase *>
   (synsem:loc:(cat:head:Head,
                cont:key:Key),
    head_dtr:synsem:loc:(cat:head:Head,
                         cont:key:Key)).

%% The head cannot be an extraposition trace
headed_phrase *>
   (head_dtr:synsem:trace:minus_or_extraction_or_vm).

%% the head can neither be extracted or extraposed
head_non_adjunct_phrase *>
   (head_dtr:synsem:trace:non_nonloc).

% in the case of PVP an adjunct can modify a trace:
% Helfen wird er ihm morgen.
(head_adjunct_phrase,
 head_dtr:synsem:trace:extraction) *> (synsem:loc:cat:head:nonfin_verb).



%% Binary Phrases
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
head_initial(Head,Nonhead) macro  ( 
    head_dtr:Head,
    non_head_dtr:Nonhead,
    dtrs:[Head,Nonhead]).

head_final(Head,Nonhead) macro (
    head_dtr:Head,
    non_head_dtr:Nonhead,
    dtrs:[Nonhead,Head]).

head_final_speed(Head,Nonhead) macro (
    @head_final(Head,Nonhead),
    non_head_dtr:(Nonhead,synsem:loc:cat:head:dsl:none)). % to make things more efficient

head_initial_ha(Head,Nonhead) macro
  (@head_initial(Head,Nonhead),
    head_dtr:synsem:loc:cat:head:initial:plus).

head_final_ha(Head,Nonhead) macro
  (@head_final(Head,Nonhead),
    head_dtr:synsem:loc:cat:head:initial:minus).



% phrases that do not indroduce additional
% semantic information
basic_binary_headed_phrase *> (synsem:loc:coord:minus,
                               c_cont:(liszt:(@e_diff_list),
                                       h_cons:(@e_diff_list))).



/*
basic_binary_headed_phrase *> (head_dtr:synsem:(%Spec,
                                                loc:cat:head:mod:Mod,
                                                phrase:Phrase
                                               ),
                               non_head_dtr:synsem:loc:cat:head:spec:(%Spec,
                                                                      loc:cat:head:mod:Mod,
                                                                      phrase:Phrase
                                                                     )).
*/


(basic_binary_headed_phrase,
 non_head_dtr:synsem:trace:extraction) *> (head_dtr:synsem:loc:cat:head:mod:none % adjuncts are islands
                                          ).

% in head cluster phrases adjunction has to be allowed since we have things like:
% Schn_i ist_j er nicht [_i _j].
% The cluster has to be build before adjunction. Therefore extraction
% cannot disable adjunction.
(head_non_cluster_phrase,
 non_head_dtr:synsem:trace:extraction) *> synsem:loc:cat:adjunction:minus.

% dieses Constraint scheint bei PVP nicht angewendet zu werden,
% es hngt dann immer noch ein Residuum rum.
% lesen wird er das buch.

% When we extract elements we mark the resulting structure as ADJUNCTION-.
% This ensures that elements are extracted after adjunction.

% The requirement of the head_dtr to be LEX+ ensures the introduction
% of the Nonlocal Dependency as early as possible.

% Adjuncts do not change the LEX value, therefore:
%
% Er schlief [ _ [gestern _V]].
%
% is possible.

% head_cluster_phrase -> LEX+
% head_adjunct_phrase -> LEX = head_dtr:LEX
% rest -> LEX-

% head_cluster_phrase -> PHRASE-
% head_adjunct_phrase -> PHRASE+/-
% rest -> PHRASE+

(head_argument_phrase,
 non_head_dtr:synsem:trace:extraction) *> synsem:max_:plus.
                                           %head_dtr:synsem:(%loc:cat:subcat:[_]    results in a combinatorial explosion
                                                                                 % since it unblocks delayed constraints
                                                            %lex:plus % to avoid spurious ambiguities
%                                                           )).

head_argument_phrase *> head_dtr:synsem:max_:minus.

(head_adjunct_phrase,
 non_head_dtr:synsem:trace:nonloc) *> head_dtr:synsem:lex:plus. % to avoid spurious ambiguities


% similar to the restriction above except that the adjunct island restriction does not hold.
% the specification of the SUBCAT list as one-element list ensures that there is a unique
% place for introduction of extraposed elements. The same was done for fronted elements. The
% difference is that fronted elements are extracted as low as possible while extraposed complements
% are extracted as high as possible. This is arbitray, but a difference has to be made, since
% in sentences like `er hat gesagt, da er kommt.' we have both a fronted and an extracted element
% and therefore we cannot require that both nonlocal dependencies are introduced with LEX+ head daughters.

% the requirement on PHON to be non-empty avoids the closure computation for verb-movement traces
% with adjuncts and stuff. There has to be one visible element before we can talk about extraposition.
% Note that in general this visible element is not necessarily a verb or a particle, it could be an argument
% of the verb movement trace: Er gab das Buch der Frau, das ich noch lesen wollte.
% However for head-argument-structures the verbal complex has to contain overt material.
% If we introduce the nonlocal dependency right after the cluster formation, we avoid
% spurious ambiguities.
(%head_argument_phrase,
 head_ad_ar_phrase,   % = adjunct or argument
 synsem:loc:cat:head:dsl:local,
 non_head_dtr:synsem:trace:extraposition) *> (phon:ne_list,
                                              head_dtr:head_cluster_phrase
                                             ).

(head_argument_phrase,
 synsem:loc:cat:head:dsl:none,
 non_head_dtr:synsem:trace:extraposition) *> (phon:ne_list,
                                              head_dtr:synsem:lex:plus
                                             ).

% the following does not hold for heads that are serialized initially:
% das [Argument _i], das jeder kennt, [da Rauchen schdlich ist]_i
(head_argument_phrase,
 synsem:loc:cat:head:initial:minus,
 non_head_dtr:synsem:trace:extraposition) *> synsem:loc:cat:adjunction:minus.



% we only allow extraction, when the head is a verb
% the restriction to be final rules out modification of the `moved' verb.

% extraction out of NPs is also excluded. This may not be right empirically
% but it is parallel to VM-Gram.

(head_adjunct_phrase,
 non_head_dtr:synsem:trace:extraction) *> (synsem:loc:cat:(head:(verb,
                                                                 initial:minus)
%                                                          ,xcomp:[]               % speed
                                                          )).

% This is to exclude spurious ambiguities in cases where PVP occures
% with adjunct extraposition.
%
% j_1 Schlafen_i wird der Mann [j_2 [morgen _i]]  mssen in der Schule.
%

Head^(head_adjunct_phrase,
      synsem:(loc:cat:head:Head,
              nonloc:slash:[cat:head:Head])) *> non_head_dtr:synsem:trace:minus.



      
% * Er schlft schlft.
%
(headed_phrase,
 head_dtr:(word,
           phon:[bot])) *> (head_dtr:synsem:loc:cat:head:dsl:none).

/*
% version with lists
unary_phrase *>
  ( synsem:(loc:cont:(liszt:ContentResult,
                      h_cons:SCResult),
            trace:Trace),
    c_cont: (liszt:ContentLast,
	     h_cons:SCLast ),
    dtrs:[( synsem:(loc:(cont:(liszt:ContentFirst,
                               h_cons:SCFirst) ),
                    trace:Trace)) ] )
 goal (append(ContentFirst,ContentLast,ContentResult),
       append(SCFirst,SCLast,SCResult)).

binary_phrase *>
  ( synsem:loc:cont: ( liszt:ContentResult,
			 h_cons:SCResult ),
    c_cont: (liszt:ContentLast,
	     h_cons:SCLast ),
    dtrs:[ ( syntactic_object,
             synsem:loc: (cont:(liszt:ContentMiddle1,
                                h_cons:SCMiddle1 ) )),
	   ( syntactic_object,
             synsem:loc: (cont:(liszt:ContentMiddle2,
                                h_cons:SCMiddle2 ) )) ])
goal ( append(ContentMiddle1,ContentMiddle2,ContentFirst),
       append(ContentFirst,ContentLast,ContentResult),
       append(SCMiddle1,SCMiddle2,SCFirst),
       append(SCFirst,SCLast,SCResult)
).

*/

% version with difference lists
unary_phrase *>
  ( synsem:(loc:cont:(liszt:(list:DContList,
                             last:CContLast),
                      h_cons:(list:DHConsList,
                              last:CHConsLast)),
            trace:Trace),
    c_cont: (liszt:(list:CContList,
                    last:CContLast),
	     h_cons:(list:CHConsList,
                     last:CHConsLast)),
    dtrs:[( synsem:(loc:(cont:(liszt:(list:DContList,
                                      last:CContList),
                               h_cons:(list:DHConsList,
                                       last:CHConsList))),
                    trace:Trace)) ] ).

/*
binary_phrase *>
  ( synsem:loc:cont:(liszt:(list:D1ContList,
                            last:CContLast),
                     h_cons:(list:D1HConsList,
                             last:CHConsLast)),
      c_cont: (liszt:(list:CContList,
                      last:CContLast)),
  	     h_cons:(list:CHConsList,
                      last:CHConsLast)),
    dtrs:[ ( syntactic_object,
             synsem:loc:cont:( liszt:(list:D1ContList,
                                      last:D2ContList)
                                h_cons:(list:D1HConsList,
                                       last:D2HConsList)
           )),
	   ( syntactic_object,
             synsem:loc:cont:(liszt:(list:D2ContList,
                                      last:CContList),
                               h_cons:(list:D2HConsList,
                                       last:CHConsList))) ]).

*/


binary_phrase *>
  ( synsem:loc:cont:(liszt:(list:CContList,
                            last:D2ContLast),
                     h_cons:(list:D1HConsList,
                             last:CHConsLast)),
      c_cont: (liszt:(list:CContList,
                      last:D1ContList),
                  h_cons:(list:CHConsList,
                          last:CHConsLast)),
    dtrs:[ ( syntactic_object,
             synsem:loc:cont:( liszt:(list:D1ContList,
                                      last:D2ContList),
                               h_cons:(list:D1HConsList,
                                       last:D2HConsList)
           )),
	   ( syntactic_object,
             synsem:loc:cont:(liszt:(list:D2ContList,
                                      last:D2ContLast),
                               h_cons:(list:D2HConsList,
                                       last:CHConsList))) ]).


unary_phrase *> (synsem:loc:coord:minus,
                 dtrs:[syntactic_object]).

head_compositional macro (headed_phrase,
   c_cont:(ltop:Hand,
           ind:Ind),
   head_dtr:synsem:loc:cont:(ltop:Hand,
                             ind:Ind)).

/*
arg_extra_intro_phrase(HeadDtr) :=
  (@nl_intro_phrase,
   head_only_phrase,
%   head_arg_cancelation_phrase,
   synsem:(loc:cat:(subcat:del((loc:(Loc,cat:head:(dsl:none,
                                                   vf:minus,
                                                   extrap:plus)),
                                nonloc:inert_extra:[Loc],
                                trace:plus),Subcat),
                    adjunction:minus),
           nonloc:(rel:Rel,
                   slash:Slash,
                   inert_extra:[Loc])),
    head_dtr:(HeadDtr,
              synsem:(loc:cat:subcat:Subcat,
                      nonloc:(rel:Rel,
                              slash:Slash,
                              @no_extra),
                      phrase:minus))).
*/


head_specifier_phrase *> (synsem:loc:cat:spr:Rest,
                          head_dtr:synsem:(Spec,
                                           loc:cat:spr:[First|Rest]),
%                                                cont:Cont),
%                                           nonloc:Nonloc),
                          non_head_dtr:synsem:(First,
                                               loc:cat:head:spec:Spec  % we are not afraid of cycles
                                                                       %(loc:cont:Cont,
                                                                       % nonloc:Nonloc)
                                              )).

head_non_specifier_phrase *> (synsem:loc:cat:spr:Spr,
                              head_dtr:synsem:loc:cat:spr:Spr).

spr_head_phrase(HeadDtr,NonheadDtr) macro
  (head_specifier_phrase,
   @head_compositional,
   @head_final(HeadDtr,NonheadDtr),
   non_head_dtr:synsem:(loc:cat:head:det,
                        trace:minus), % this should be replaced by a type constriant on the head of the trace
                                                    % they should be of type major
      head_dtr:synsem:loc:cat:(head:noun,
                               subcat:[])).

/*
% most oblique element first
% no scrambling
head_argument_phrase *> (synsem:loc:cat:subcat:Rest,
                         head_dtr:synsem:loc:cat:subcat:[First|Rest],
                         non_head_dtr:synsem:First).
*/

% any element from the list
% Since the list is variable in the case of the verb trace,
% del is delayed and no restrictions are imposed on NHead.
% Therefore the restrictions have to be specified in the schemata.
% See below.

% This treatment has the disadvantage that a verbal trace allows
% n elements to be combined with it. The del/3 is delayed until
% the arrity of the list is known. If we allwo extraction at every
% projection level, we get spurious ambiguities. If we don't

head_argument_phrase *> (synsem:loc:cat:subcat:del(NHead,Subcat),
                         head_dtr:synsem:loc:cat:subcat:Subcat,
                         non_head_dtr:synsem:(NHead,
                                              phrase:plus)). % excludes spurious ambiguities
                                                             % if intransitives are embedded
                                                             % in coherent constructions (phase verbs).

% in incoherent constructions, there must be material between the verbal complex
% and zu infinitive. This is not 100% correct since there are incoherent constructions
% that are marked intonationally, but are nevertheless adjacent to the verbal complex.
% But since we deal with written language, this is the only way to exclude spurious
% ambiguities.
% Of course extraposition traces can appear adjacent to the predicate complex since
% only incoherent constructions allow for extraposition and therefore spurious
% ambiguities are excluded.
(head_argument_phrase,
 non_head_dtr:synsem:(loc:cat:head:inf_verb,
                      trace:minus_or_extraction)) *> (head_dtr:synsem:phrase:plus).

% lex kann plus sein, weil die Adjunkte lex einfach weitergeben.
% auerdem ist "versucht wurde" in "den Wagen zu reparieren versucht wurde" lex+


% It also works with coordination of lexical verbs but just because PHRASE is
% not passed up to the mother node in coordinated phrases.
% This is a little bit hacky.  03.11.2003

%@non_complex_forming_synsem)).  
% cannot be added here to the non-head-dtr, since it would break coordination,
% where unsaturated material is allowed as argument, also melted prepositions,
% although a DP analysis would fix this

% However, we can impose the following restriction. Since coordinations are
% [x_conj_y X [h_arg Conj Y]], the head argument phrase plays a role in the
% combination of conjunction and second conjunct only. The result is a projection
% with an empty SUBCAT list.
% The following constraint rules out structures were del removes something from
% the SUBCAT list ignoring the complex predicate forming head that is also
% selected by the matrix element. Therefore the valence list reamains uninstantiated
% and del does not fire. The following constraint fires since the first element
% on SUBCAT is the complex forming element. Such elements are excluded by the follwing
% constraint.
% reduces the number of edges for "der ihn lesen mssende mann" from 150 to 139.
(head_argument_phrase,
 synsem:loc:cat:head:a_or_v) *> (head_dtr:synsem:loc:cat:subcat:list_of_non_complex_forming_synsems).

/*

This should work in general, but I guess it does not work since the information
that something is structural comes only after the verb in initial position is
found and then daughters in complex structures are not checked any more.

Example: Liebt Karl Maria.

It works for the head final case: Maria Karl liebt.

(head_argument_phrase,
 synsem:loc:cat:head:final_fin_verb,
 head_dtr:synsem:loc:cat:subcat:[loc:cat:head:case:case_type:str]) *>
(head_dtr:synsem:loc:cat:subcat:[loc:cat:head:case:syn_case:nom]).

*/



% this is wrong in case of fronted participles
% they can assign nominative (Zwei Mnner erschossen wurden am Wochenende).
(head_argument_phrase,  
 synsem:loc:cat:head:nonfin_verb,
 non_head_dtr:synsem:loc:cat:head:case:case_type:str) *>
(non_head_dtr:synsem:loc:cat:head:case:syn_case:acc).



%head_non_argument_non_cluster_phrase
head_ad_e_f_s_phrase*> (synsem:loc:cat:subcat:Subcat,
                                         head_dtr:synsem:loc:cat:subcat:Subcat).


% the only difference between head_arguent_structures
% and head_cluster_structures is that a head_cluster_structure
% is phrase:minus and lex:plus to allow recursion on predicate
% complexes. 02.11.2003
head_cluster_phrase *> (synsem:(loc:cat:subcat:Rest,
%                                phrase:minus, like with intransitive verbs,
                                % clusters might function as maximal projections
                                lex:plus),
                         head_dtr:synsem:(%word,                        not word, since modals may be coordinated
                                          %                             and function as complex heads
                                          loc:cat:subcat:[First|Rest]),
                         non_head_dtr:synsem:First).

% that's not right, since adjuncts that belong to the lower verbs may be extraposed
%
%                                              nonloc:(@no_extra))).       % check when we come to third construction 

% in the case of incomplete category fronting
% the valence list of the head cluster structure is undetermined.
% To reduce the desasteros effect, the constraint that comes in
% from the fronted element is added here by this type constraint
% explicitely.
% This also excludes the fronting of the particle of phase verbs in coherent constructions.
% This is an unclean side effect, but I leave it, since the particle frontings together
% with coherent constructions are very marked anyway:
%
% * An fing es zu regnen.
% * An fing er zu schlafen.
%
% 04.11.2003
%

% The constraint on non-extraposability is used when a non-head is extracted in head-cluster structures
% The attracted arguments are blocked from extraposition. Extraposition is admitted from
% the fronted element only.
%
% [_i stolz] wird er sein [auf ihn]_i.
%
% * stolz wird er _i sein [auf ihn]_i.
%
% 19.02.2004

% This does not capture
%
% * Arbeiten_i wird er _j [nicht _i] mssen [an diesem Projekt]_j.

(head_cluster_phrase,
 non_head_dtr:synsem:trace:extraction) *> (synsem:loc:cat:subcat:list_of_non_complex_forming_non_extra_synsems).


% There is a similar problem with verb movment traces: If drfen combines with a verb movement trace
% the constraints on raised arguments are not enforced immedeately.
%
% 12.02.2004

head_cluster_phrase *> (non_head_dtr:synsem:loc:cat:subcat:list_of_non_complex_forming_synsems).


% The following is a speed constraint. It rules out
% [CL _Ex [CL geliebt _VM]]
% without it, the valence list of the combination of the verb movement trace and
% the participle would be unconstraint.
% It is not possible to impose this constraint on all SUBCAT lists in head_cluster_structurs
% since there are coherently constructing particle verbs like anfangen, that have two
% cluster elements on their SUBCAT list.

(head_cluster_phrase,
 non_head_dtr:synsem:loc:cat:head:verb) *> (synsem:loc:cat:subcat:list_of_non_complex_forming_synsems).


% The following is a speed constraint.
% It rules out [ ist [ _Ex _VM]] as a maximal projection.
%
% It cannot be used, since we need such structures for:
%
% Schulfrei ist schon oft gewesen.
%
%(head_cluster_phrase,
% non_head_dtr:synsem:(loc:cat:head:prd_adj,
%                      trace:extraction)) *> (non_head_dtr:synsem:loc:cat:head:subj:ne_list).

%head_non_adjunct_non_cluster_phrase
head_ar_e_f_s_phrase *> (synsem:lex:minus).

head_adjunct_phrase *> (synsem:lex:Lex,
                        head_dtr:synsem:lex:Lex).

% extraposition of other N' adjuncts is done via anchor percolation
(head_adjunct_phrase,
 non_head_dtr:synsem:trace:extraposition) *>

    synsem:loc:(cat:head:(verb,
                          initial:minus), % speed 
                cont:key:main_event_rel). % speed
                                          % If the verb is an auxiliary,
                                          % do not introcue nonlocal dependencies for extraposition.

                                          %  Er ist gestorben: 128 -> 121 edges



% *> -> cons => is handled as an ale constriant = faster

head_filler_phrase *>
  (Mother,
   synsem:(nonloc:slash:[],
           v2:plus),
           
   head_dtr:(synsem:(loc:(cat:(head:initial_fin_verb,
                               subcat:[])),
                     nonloc:(slash:[Slash],
                             @no_extra),
                     v2:minus)
             ),
   non_head_dtr:(phon:ne_list,                % this is needed once we have an extraposition trace,
                                              % since the extraposition trace can be combined with
                                              % the verb movement trace, yielding something that is
                                              % trace:minus.
                                              % topic drop has to be done by a differen rule.
                 synsem:(loc:Slash,
                         nonloc:(rel:[],
                                 slash:[]     % Extraposition from the filler is possible
                                )
% see constraint on phon above                        
%                       trace:minus           % speed and an ad hoc restriction
                                              % as far as extraction is concerned, this is excluded
                                              % by the specification of slash anyway
                                              % but trace:minus excludes also the verb movement trace with nothing else
                                              % while permitting projections of the trace.
                                              % _V errang Clark 1965 die Weltmeisterschaft zum zweiten Mal.


                                                        % strangely enough this does not yield a speed up 27.10.2003
                                                        
                       )),
      dtrs:[LDtr,RDtr])
goal
  (que(LDtr,RDtr,Mother),
   rel(LDtr,RDtr,Mother),
   extra(LDtr,RDtr,Mother),
   anchors(LDtr,RDtr,Mother)).


head_ad_ar_c_s_phrase *> (Mother,
                           synsem:v2:V2,
                           head_dtr:synsem:v2:V2,
                           dtrs:[LDtr,RDtr])
goal nfp(LDtr,RDtr,Mother).

head_non_filler_phrase *> (synsem:v2:V2,
                           head_dtr:synsem:v2:V2).

% non-head-dtrs are never verb traces except in head-filler-structures (speed)
%...
% and head_argument_structures :-(
%b_h_non_filler_phrase *>
%  (non_head_dtr:synsem:loc:cat:head:dsl:none).


% this ensures that all extraposeable elements are immedeately extraposed
% i.e. introduction of the extraposed argument
%      binding off of the extraposed element -> empty extra lists
%      saturation of further arguments
%
%(head_argument_phrase,
% synsem:loc:cat:head:verb) *> head_dtr:synsem:nonloc: @no_extra.

% everything that is common in argument extraposition and adjunct extraposition
general_head_extra_phrase :=
 (head_extra_phrase,

  % This is like requesting the head_dtr to be subcat:[], since max:plus constituents
  % do not enter in head_argument_structures.
  % The difference is that the SUBCAT list of the projection actually may contain elements,
  % as would be the case in PVP examples like:
  % Fragen, ob er es liest, wirst du ihn mssen.
  %
  % max:plus means `Does not project further' not cannot project further (i.e. SUBCAT:[])
  %
  % This excludes spurious ambiguities for cases like
  % Diesen Mann fragen, ob er das Buch liest, wirst du wohl mssen.
  synsem:(max_:plus,


          % similarly we rule out adjunction on top of extraposition to exclude spurious ambiguities for
          % Jetzt diesen Mann fragen, ob er das Buch liest, wirst du wohl mssen.
          loc:cat:adjunction:minus
         ),
  head_dtr:(phon:ne_list,
            synsem:loc:cat:(head:dsl:none, % linguistically not right since projections
                                                       % of the verbal trace in the Vorfeld could be landing sites,
                                                       % see also comments on verb movement LR
                            spr:[]
                           )),
   non_head_dtr:(phon:ne_list,                         % see filler_head_rule above
                 synsem:(loc:cat:(head:dsl:none,
                                  subcat:[]),          % only maximal projections (speed)
                        nonloc:(rel:[],
                                @no_extra
                               )
%                        trace:minus                   % speed and an ad hoc restriction
                                                       % as far as extraction is concerned, this is excluded
                                                       % by the specification of extra anyway
                       ))).

head_extra_phrase :=
   (@general_head_extra_phrase,
    anchors(LDtr,RDtr),
    synsem:nonloc:(rel:[],
                   slash:nl(SlashH,SlashNH),
                   @no_extra),
    head_dtr:(LDtr,
              synsem:nonloc:(slash:SlashH,
                             active_extra:[Extra]
                            %,inert_extra:[]           % should not exist anyway, since there is a restriction on length one
                           )),
    non_head_dtr:(RDtr,
                  synsem:(loc:Extra,
                          nonloc:slash:SlashNH))).



head_adjunct_extra_phrase :=
   (@general_head_extra_phrase,
    nfp(LDtr,RDtr),
    head_dtr:LDtr,

% This would exclude:
% Den Mann hat Peter gesagt, da eine Frau ausbilden will, die ...
% Den Mann hat Peter gesagt, will eine Frau ausbilden, die ...
%
%              synsem:nonloc:slash:[]),   % all anchors are percolated to the top, we choose one there
%

% for some reason this seems to have no effect here, I put it as attachement to the
% rule in rules.pl 22.02.2004
%              synsem:active_anchors:contains((handle:Handel,ind:Ind)),
    non_head_dtr:(RDtr,
                  synsem:loc:cat:head:(extrap:plus,
                                       mod:loc:cat:head:noun)       % without this specification verbal adjuncts could attach here
                                                                    % they are treated as properly extraposed elements via EXTRA (passive von-PP)
                 )).
%                                       mod:loc:cont:(ltop:Handel,
%                                                     ind:Ind)))),
                          



unary_headed_phrase(HeadDtr) macro
  (unary_phrase,
   head_dtr:HeadDtr,
   dtrs:[HeadDtr]).

binary_headed_phrase(HeadDtr,NonheadDtr) macro
  (head_dtr:HeadDtr,
   non_head_dtr:NonheadDtr).


head_argument_phrase(HeadDtr,NonheadDtr) macro
  (head_argument_phrase,
   @head_compositional,
   @head_initial_ha(HeadDtr,NonheadDtr)).

argument_head_phrase(HeadDtr,NonheadDtr) macro
  (head_argument_phrase,
   @head_compositional,
   @head_final_ha(HeadDtr,NonheadDtr),
   @head_final_speed(HeadDtr,NonheadDtr),
%   head_dtr:synsem:loc:cat:xcomp:[],       % Kombination of `kann' and `und will' is done by a coordination schema
                                           % not ling. necessary but reduces the number of edges from 68 to 48
                                           % for "Du wirst geschlafen haben."

   non_head_dtr:synsem:(@argument_synsem)).


% breaks coordination
%  non_head_dtr:synsem:(@saturated_synsem)). % not linguistically necessary
                                               % reduces the number of pedges from 360 to 260
                                               % for "Du wirst geschlafen haben."


% the restriction of the head values is linguistically not necessary, but computationally it is.
% for four word sentence we got a speed up of 29!
%(6) der Mann, der schlft  % np
% ==> 291.010 s CPU time.        1 solution (ok); residues: 0
%(6) der Mann, der schlft      % np
% ==> 10.330 s CPU time.        1 solution (ok); residues: 0

general_head_cluster_phrase_speed :=
  (
    % could be made more restrictive by saying that if there is something in xcomp
    % the non_head_dtr has to be a particle. Test later with higher ambiguity.
    
    % excludes phase verbs with particle (anfangen)
    % synsem:loc:cat:xcomp:[],    % wrong for vorkommen + adjective
                                           % reduces the number of pedges from 398 to 360
                                           % for "Du wirst geschlafen haben."

    
    
   head_dtr:synsem:(loc:cat:head:a_or_v,
                    phrase:minus),
   non_head_dtr:synsem:(% The following constraint does not affect multiple frontings
                        % since these are licensed by the lexical rule without traces.

                        loc:cat:head:part_or_prd_adj_or_prd_prep_or_nonfin_verb,
                        
%                                 xcomp:[]), % speed to exclude combination of verb trace with
                                            % auxiliaries [haben + e], cleaner way would be to specify
                                            % this in the trace.
% this is wrong, because of resultative constructions
% and `halten fr' and so on.
% fix! later
                        phrase:minus % speed, not tested since h_cl rule was uncommented in general
%                        ,trace:minus         % this excludes PVP but otheriwse the system is too slow!
%                       , trace:non_vm    does not restrict anything
                       )).

% only for aux flip
head_cluster_phrase(HeadDtr,NonheadDtr) macro
  (head_cluster_phrase,
   @general_head_cluster_phrase_speed,
   @head_compositional,
   @head_initial_ha(HeadDtr,NonheadDtr),
   head_dtr:synsem:loc:cat:head:verb).     % speed


cluster_head_phrase(HeadDtr,NonheadDtr) macro
  (head_cluster_phrase,
   @general_head_cluster_phrase_speed,
   @head_compositional,
      %(
        non_head_dtr:synsem:loc:cat:head:dsl:none
      ,
      % ;(non_head_dtr:synsem:loc:cat:head:dsl:local,
      %  non_head_dtr:synsem:trace:extraction)),
   @head_final_ha(HeadDtr,NonheadDtr)).


% The complex has to be formed before adjunction to ensure proper scoping.
% Therefore the valence list of the sign (which is identical to the one
% of the head-daughter in head-adjunct-structurs) must not contain unsaturated
% preds or PHRASE- preds or PRD+.

% left_adj_poss is - for PPs and relative clauses
% adjectives require their head to be left_adj_poss +
% thereby it is ensured that adjectives combine with nouns
% before PPs and RCs.

head_adjunct_phrase *>
  (synsem:loc:cat:(subcat:list_of_non_complex_forming_synsems,
                   left_adj_poss:LA),
   head_dtr:synsem:(Synsem,
                    loc:cat:adjunction:plus),             % after extraction the value is set to minus to reduce ambiguity
   non_head_dtr:synsem:(@saturated_synsem,                % if you use complete_synsem here, adjunct extraction is excluded.
                        loc:cat:(head:mod:Synsem,
                                 left_adj_poss:LA),
                        nonloc:rel:[])).


% The following does not hold for head_cluster_phrases, they are phrase:plus.
% For head_adjunct_phrases we do not determine the phrase value.
% This allows adjuncts to attach to verbal projections. The resulting
% verbal projection has an underspecified phrase value and is therefore
% admitted in coherent constructions were a phrase+ value is required.
% We therefore can parse (1) in two ways:
%
% (1) Er darf nicht an dieser Sache arbeiten.
%
% Er darf_i [nicht an dieser Sache arbeiten] _i.      narrow scope
% Er darf_i [nicht [an dieser Sache arbeiten _i]].    wide   scope
%
% Note that a storage mechanism that stores semantic indices for later attachment
% does not help, since we have cases were we have to constrain syntactic properties
% of the modified verb. For instance if the von phrase that expresses the agent
% in passive constructions is treated as an adjunct that requires the modified
% participle to have an element in the DA list, this syntactic information has to be
% availible. In the analysis of (2) "von Karl" has to attach to (a projection of) "geschenkt".
%
% (2) Er hat von Karl ein Buch geschenkt bekommen.
%

%head_non_adjunct_non_cluster_phrase
head_ar_e_f_s_phrase *>
  (synsem:phrase:plus).

% Part of the semantics principle
% Key is percolated for all headed structures from the head daughter
head_non_adjunct_phrase *>
  (synsem:loc:(cat:left_adj_poss:LA,
               cont:ind:Ind),
   head_dtr:synsem:loc:(cat:left_adj_poss:LA,
                        cont:ind:Ind)).


% LTop comes from the semantic head not from the syntactic head
general_head_adjunct_phrase(HeadDtr,NonheadDtr) macro
(head_adjunct_phrase,
   @binary_headed_phrase(HeadDtr,NonheadDtr),
   c_cont:(ltop:Top,
           ind:Ind),
   head_dtr:synsem:loc:cont:ind:Ind,
   non_head_dtr:synsem:loc:cont:ltop:Top).

head_adjunct_phrase(HeadDtr,NonheadDtr) macro
  (@general_head_adjunct_phrase(HeadDtr,NonheadDtr),
   @head_initial(HeadDtr,NonheadDtr),
   non_head_dtr:synsem:(loc:cat:head:pre_modifier:minus
                       ,trace:minus_or_extraposition    % speed of course adjuncts that modify verbs
                                                        % have to preceede them, but for traces we do not know
                                                        % that they would be preceeding modifiers
                       ),
   head_dtr:synsem:loc:cat:head:noun                    % speed??
                                                        % this excludes verb movement traces, that would not be
                                                        % possible anyway.
                                                        % strangely enough this does not yield a speed up (27.10.2003),
                                                        % but it helps with the chart display
  ).

adjunct_head_phrase(HeadDtr,NonheadDtr) macro
  (@general_head_adjunct_phrase(HeadDtr,NonheadDtr),
   @head_final_speed(HeadDtr,NonheadDtr),
   non_head_dtr:synsem:loc:cat:head:pre_modifier:plus).

filler_head_phrase(HeadDtr,NonheadDtr) macro
  (head_filler_phrase,
   @head_compositional,
   @head_final(HeadDtr,NonheadDtr)).

head_extra_phrase(HeadDtr,NonheadDtr) macro
  (@head_extra_phrase,
   @head_compositional,
   @head_initial(HeadDtr,NonheadDtr)).

head_adjunct_extra_phrase(HeadDtr,NonheadDtr) macro
  (@head_adjunct_extra_phrase,
   @head_compositional,
   @head_initial(HeadDtr,NonheadDtr)).


% Unfortunately the following is not just a speed constraint. Without it
% den Aufsatz, den lesen er will would be permitted

% And despite of this hack the problem is not solved entirely, since there
% still are spurious ambiguities since the coherent construction + PVP
% licences an unwanted reading for das Buch, das zu lesen er versuchte
% 14.02.2004

(basic_binary_headed_phrase,
 synsem:loc:cat:head:prd_adj_or_bse_or_ppp_verb) *> (synsem:nonloc:rel:[]).




rel_or_w_clause :=
  (@complete_sign,
      synsem:(loc:(cont:(ltop:Top,
                         ind:VInd,
                         key:Key),     
                   coord:minus),
              nonloc:que:[],              % relative clauses may contain w-Words but the information is not percolated
              active_anchors:[],
              inert_anchors:[],
              phrase:plus,
              v2:minus),
      c_cont:(liszt:(@e_diff_list),
              h_cons:(@e_diff_list)),
      dtrs:[(@saturated_sign,   % for speed
             synsem:(loc:Loc,
                     nonloc:(slash:[],
                             @no_extra))   % Is there extraposition from the relative phrase?
                                          % would be something like:
                                          % *der Mann, an dessen Freundin er denkt, die ich kenne
             ),
            (@saturated_sign,
             synsem:(loc:(cat:head:(fin_verb,
                                    initial:minus,
                                    dsl:none,
                                    extrap:minus),
                          cont:(ltop:Top,
                                ind:VInd,
                                key:Key)),
                     nonloc:(rel:[], % should follow from constraints on verb arguments
                             slash:[Loc],
                             @no_extra % the slash element can come from the extraposed material
                                              % extraposed constituents have to be bound off first
                            ),
                     trace:minus) % follows from the theory, since Loc can never be
                                        % a finite verb, but the specification is needed
                                        % here for trace elemination in the rule compilation.
            )]).

rc(RelDtr,VDtr) :=
  (rc_phrase,
   @rel_or_w_clause,
      synsem:loc:cat:(head:(rc,
                            mod:(@n_bar(Ind,Handle)),
                            rp_head:Head),
                      left_adj_poss:minus),
      dtrs:[(RelDtr,
             synsem:(loc:cat:head:Head,
                     nonloc:rel:[Ind])
             ),
             (VDtr,
              synsem:loc:cont:ltop:Handle)]).

w_clause(WDtr,VDtr) :=
  (w_phrase,
   @rel_or_w_clause,
      synsem:loc:cat:head:w_clause,
      dtrs:[(WDtr,
             synsem:nonloc:que:[_Ind]),
            VDtr]).


free_rc(Dtr) :=
  (@complete_sign,
   free_rc_phrase,
   synsem:(loc:(cat:head:free_rc_head(RCHead),
                cont:ltop:Top),
           nonloc:que:[],
           active_anchors:[],
           inert_anchors:[]),
   c_cont:(ind:Ind,
           ltop:Top,
           liszt:(list:[(udef_rel,
                         lbl:Top,
                         bv:Ind,
                         restr:Restr)|LLast],
                  last:LLast),
           h_cons:(list:[(qeq,
                          sc_arg:Restr,
                          outscpd:Top)|HLast],
                   last:HLast)),
      dtrs:[(Dtr,
% test later             @complete_sign, % speed
% test later             phrase,         % speed
             synsem:loc:cat:head:(rp_head:RCHead,
                                  mod:loc:cont:ind:Ind))]).

%% Unnary Phrases
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

general_empty_det_phrase(HeadDtr) macro
 (@saturated_sign,
  @unary_headed_phrase(HeadDtr),
   empty_det_phrase,
   synsem:(nonloc:Nonloc,
           active_anchors:AA,
           inert_anchors:IA,
           lex:minus,
           phrase:plus,
           v2:V2),
   c_cont:(ind:Ind,
           liszt:(list:[(udef_rel,
                         bv:Ind,
                         restr:Restr)|LLast],
                  last:LLast),
           h_cons:(list:[(qeq,
                          sc_arg:Restr,
                          outscpd:LTop)|HLast],
                   last:HLast)),
   head_dtr:synsem:(loc:(cat:(head:(noun,
                                    lpe:minus), % an Vizepraesident Davignon -> PP -> N' -\> N''
                              spr:[(@det_synsem,
                                    loc:(cat:(head:dtype:weak,
                                              subcat:[])))],
                              subcat:[]),
                         cont:(ltop:LTop,
                               ind:Ind),
                         coord:minus),
                    nonloc:(Nonloc,
                            rel:[],
                            slash:[]),            % extraposition of relative clauses is okay
                                                  % ich habe Argumente dagegen gehrt, da ... 
                    active_anchors:AA,
                    inert_anchors:IA,
                    v2:V2)).


empty_det_phrase(HeadDtr) macro
 (@general_empty_det_phrase(HeadDtr),

     
% first case: determiner is marked as dropable (drop_det:plus
%             This is the case for proper nouns and for mass nouns
%
     
   head_dtr:synsem:loc:((cat:spr:[(loc:drop_det:plus)],
                         cont:ind:num:sg)

% second case: noun is plural
                       ; cont:ind:num:pl
                       )).
/*
%    Head:pvp <=> m,

    Spec isa ref_noun_synsem,                      % keine mod. Genitive ohne Det. muss noch implementiert werden
    Spec:loc:cont <=> INoun,

    CompSynSem:loc:inds <=> [],          % Das schliesst die Projektion von 'usa' aus
                                                % im template von USA wird inds <=> [_|_] spezifiziert


     */
   
     

% The Phrase value is taken over from the bse form.
% Currently it is unspecified in the lexicon.
% Important in the case of intransitive verbs in incoherent constructions.

inf_zu(Zu,Verb) :=
 (%infl_word, should be infl_word, but dtrs is introduced for phrase
  synsem:(loc:(cat:(head:(inf_verb,
                          mod:Mod,
                          subj:Subj,
                          da:DA,
                          aux:Aux,
                          flip:Flip),
                    subcat:Subcat),
               cont:Cont),
          nonloc:Nonloc,
          active_anchors:AA,
          inert_anchors:IA,
          lex:plus,
          phrase:Phrase),
     dtrs:[(non_derived_word,                       % otherwise we get preps with extracted r-pronoun
            Zu,
            phon:[(a_ zu)],
            synsem:loc:cat:head:comp_prep),
           (Verb,
            word,
            synsem:(loc:(cat:(head:(bse_verb,
                                    mod:Mod,
                                    subj:Subj,
                                    da:DA,
                                    aux:Aux,
                                    flip:Flip),
                              subcat:Subcat),
                         cont:Cont),
                    nonloc:Nonloc,
                    active_anchors:AA,
                    inert_anchors:IA,
                    lex:plus,
                    phrase:Phrase,
                    trace:minus))]).


genitive_phrase *> (Mother,
                    dtrs:[LDtr,RDtr])
goal nfp(LDtr,RDtr,Mother).


genitive(HeadDtr,NonHeadDtr) :=
  (genitive_phrase,
   synsem:(loc:(cat:Cat,
                coord:minus),
           phrase:plus,
           lex:minus),
   c_cont:(ind:Ind,
           ltop:Top,
           liszt:(list:[(poss_rel,
                         lbl:Hand,
                         arg1:Ind2,
                         arg2:Ind)|Last],
                  last:Last),
           h_cons:(@e_diff_list)),              % aus VM
   head_dtr:HeadDtr,
   dtrs:[(HeadDtr,
          synsem:(@n_bar(Ind),                    % N' sonst waere 'er seiner Tochter' moeglich
                  loc:(cat:Cat,
                       cont:(ltop:Top,
                             ind:Ind,
                             key:(pred_rel,       % excludes "Karl seiner Tochter" since Karl has a named_rel          
                                  lbl:Hand))),
                  nonloc:(@no_extra),             % if something is extraposed, the trace originates higher.
                                                  % otherwise one would get spurious ambiguities with relative clause
                                                  % extraposition traces attaching in the middle of N and NP[gen]
                  lex:plus,
                  trace:minus)),
          (NonHeadDtr,
           @saturated_comp_sign,
           synsem:(@lex_ref_comp_np_synsem(gen),
                   loc:cont:(ltop:Top,
                             ind:Ind2),
                   nonloc:(rel:[],
                           slash:[]),             % extraposition of relative clauses (and of the genitive itself) is okay     
                   lex:minus))]).                 % this excludes pronouns "*die Frau seiner"


% type constraint or macro ??
% I see no other way than requiring that the phonology be non-empty.
% otherwise a combination of extraction trace and verb movement trace
% would be possible in the first slot.
% In the second slot this combination is ruled out by the specification
% of the conjunction, which requires a non-dsl complement. 10/2003
coord_phrase :=
  (coord_phrase,
   synsem:inert_anchors:[],
   dtrs:[(phon:[_|_],
          synsem:trace:minus),
          synsem:trace:minus]).

x_conj_y_coord_phrase(Dtr1,Dtr2) :=
  (@coord_phrase,
   synsem:(loc:(cat:Cat,
                coord:Coord),
           nonloc:Nonloc,
           v2:V2),
   coord_sem_and_anchors(Coord,C1,C2),
   dtrs:[(Dtr1,
          synsem:(Spec,
                  loc:(cat:Cat,
                       cont:C1),
                  nonloc:Nonloc,
                  v2:V2)),
         
         (Dtr2,
          synsem:loc:(cat:(head:(spec:Spec,
                                 coordform:Coord),
                           subcat:[]),
                      cont:C2))]).

% x [ y conj z ]

x_y_conj_z_coord_phrase(Dtr1,Dtr2) :=
  (@coord_phrase,
   synsem:(loc:(cat:Cat,
                coord:Coord),
           nonloc:Nonloc,
           v2:V2),
   coord_sem_and_anchors(Coord,C1,C2),
   dtrs:[(Dtr1,
          synsem:(loc:(cat:(Cat,
                            head:dsl:none),    % TRALE loops without this restriction (cyclic structures???)
                       cont:C1),
                  nonloc:Nonloc,
                  v2:V2,
                  trace:minus)),
         
         (Dtr2,
          synsem:(loc:(cat:Cat,
                       cont:C2,
                       coord:(Coord,
                              coord_rel)),
                  nonloc:Nonloc,
                  v2:V2,
                  phrase:plus))]).


conj_x_conj_y_phrase(Dtr1,Dtr2) :=
(@coord_phrase,
   synsem:(loc:(cat:Cat,
                coord:minus),
           nonloc:Nonloc,
           v2:V2),
   coord_sem_and_anchors(Coord1,Coord2,C1,C2),
   dtrs:[(Dtr1,
          synsem:(loc:(cat:(head:(coord,
                                  coordform:Coord1,
                                  spec:(loc:cat:Cat,
                                        nonloc:Nonloc,
                                        v2:V2)),
                            subcat:[]),
                       cont:C1),
                  trace:minus)),
         (Dtr2,
          synsem:(loc:(cat:(head:(coord,
                                  coordform:Coord2,
                                  spec:(loc:cat:Cat,
                                        nonloc:Nonloc,
                                        v2:V2)),
                            subcat:[]),
                       cont:C2),
                  phrase:plus))]).



% add constraints that rule out final imperatives
% rules out
% da du mir ihn gib.
%
% there could be constraints in the complementizer that rule out
% this sentence, but the constraint below avoids all the unnecessary projections.

% for strange reasons this does not apply to lexical entries.
% if it did, we used head_dtr

% The constraint has to mention synsem, since otherwise constraints are delayed
% for non-used MOD values of stem entries for adjectives.

% The neccessary restrictions cannot be enforced in the lexical entries since
% lexical entries for finte verbs are input to the verb movement rule.

% having the head_dtr here reduced the loading time of the lexicon by 10 seconds
(head_dtr:synsem:loc:cat:head:(fin_verb,
                               initial:minus,
                               dsl:none)) *> (synsem:loc:cont:ind:temo:ind_conj).




%% Type constraint for verb movement
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
     
/*
ne_verb_argument_list *> (hd:(@verb_argument),
                          tl:verb_argument_list).

ne_list_of_syntactic_objects *> (hd:syntactic_object,
                              tl:list_of_syntactic_objects).

*/


% Detmar suggested the following

/*
fun fin_verb_argument_list(-).
fin_verb_argument_list(L) if
   when( (L=(e_list;ne_list)),
         undelayed_fin_verb_argument_list(L) ).

undelayed_fin_verb_argument_list([]) if true.
undelayed_fin_verb_argument_list([@fin_verb_argument_synsem|T]) if
   fin_verb_argument_list(T).

*/


fun non_blocked_list(-).
non_blocked_list(L) if
   when( (L=(e_list;ne_list)),
         undelayed_non_blocked_list(L) ).

undelayed_non_blocked_list([]) if true.
undelayed_non_blocked_list([blocked:minus]) if true.


%% Root Nodes
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

root macro
 (@complete_sign,
  word,
  synsem:loc:cat:head:root:plus).

decl macro
 (@complete_sign,
   synsem:(loc:cat:head:initial_fin_verb,
           (v2:plus,
            loc:cont:ind:temo:ind_conj
           ;loc:cont:ind:temo:pres_imp))).

interrog macro
 (@complete_sign,
   synsem:loc:cat:head:initial_fin_verb).
